@@ -19,13 +19,9 @@
 package org.apache.jmeter.assertions;
 
 import org.apache.jmeter.samplers.SampleResult;
-import org.apache.jmeter.threads.JMeterContext;
-import org.apache.jmeter.threads.JMeterContextService;
-import org.apache.jmeter.threads.JMeterVariables;
 import org.apache.jmeter.util.BeanShellInterpreter;
 import org.apache.jmeter.util.BeanShellTestElement;
 import org.apache.jorphan.logging.LoggingManager;
-import org.apache.jorphan.util.JOrphanUtils;
 import org.apache.log.Logger;
 
 /**
@@ -87,14 +83,6 @@ public class BeanShellAssertion extends BeanShellTestElement implements Assertio
             return result;
         }
         try {
-            String request = getScript();
-            String fileName = getFilename();
-
-            bshInterpreter.set("FileName", getFilename());//$NON-NLS-1$
-            // Set params as a single line
-            bshInterpreter.set("Parameters", getParameters()); // $NON-NLS-1$
-            bshInterpreter.set("bsh.args",//$NON-NLS-1$
-                    JOrphanUtils.split(getParameters(), " "));//$NON-NLS-1$
 
             // Add SamplerData for consistency with BeanShell Sampler
             bshInterpreter.set("SampleResult", response); //$NON-NLS-1$
@@ -113,21 +101,7 @@ public class BeanShellAssertion extends BeanShellTestElement implements Assertio
             bshInterpreter.set("FailureMessage", "");//$NON-NLS-1$ //$NON-NLS-2$
             bshInterpreter.set("Failure", false);//$NON-NLS-1$
 
-            // Add variables for access to context and variables
-            JMeterContext jmctx = JMeterContextService.getContext();
-            JMeterVariables vars = jmctx.getVariables();
-            bshInterpreter.set("ctx", jmctx);//$NON-NLS-1$
-            bshInterpreter.set("vars", vars);//$NON-NLS-1$
-
-            // Object bshOut;
-
-            if (fileName.length() == 0) {
-                // bshOut =
-                bshInterpreter.eval(request);
-            } else {
-                // bshOut =
-                bshInterpreter.source(fileName);
-            }
+            processFileOrScript(bshInterpreter);
 
             result.setFailureMessage(bshInterpreter.get("FailureMessage").toString());//$NON-NLS-1$
             result.setFailure(Boolean.valueOf(bshInterpreter.get("Failure") //$NON-NLS-1$
