@@ -24,7 +24,6 @@ import java.text.MessageFormat;
 import org.apache.jmeter.samplers.SampleResult;
 import org.apache.jmeter.testelement.AbstractScopedAssertion;
 import org.apache.jmeter.testelement.property.IntegerProperty;
-import org.apache.jmeter.testelement.property.LongProperty;
 import org.apache.jmeter.util.JMeterUtils;
 
 //@see org.apache.jmeter.assertions.SizeAssertionTest for unit tests
@@ -35,7 +34,7 @@ import org.apache.jmeter.util.JMeterUtils;
  */
 public class SizeAssertion extends AbstractScopedAssertion implements Serializable, Assertion {
 
-    private static final long serialVersionUID = 233L;
+    private static final long serialVersionUID = 241L;
 
     // * Static int to signify the type of logical comparitor to assert
     public final static int EQUAL = 1;
@@ -54,6 +53,18 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
     private static final String SIZE_KEY = "SizeAssertion.size"; // $NON-NLS-1$
 
     private static final String OPERATOR_KEY = "SizeAssertion.operator"; // $NON-NLS-1$
+    
+    private final static String TEST_FIELD = "Assertion.test_field";  // $NON-NLS-1$
+
+    private final static String RESPONSE_NETWORK_SIZE = "SizeAssertion.response_network_size"; // $NON-NLS-1$
+
+    private final static String RESPONSE_HEADERS = "SizeAssertion.response_headers"; // $NON-NLS-1$
+
+    private final static String RESPONSE_BODY = "SizeAssertion.response_data"; // $NON-NLS-1$
+
+    private final static String RESPONSE_CODE = "SizeAssertion.response_code"; // $NON-NLS-1$
+
+    private final static String RESPONSE_MESSAGE = "SizeAssertion.response_message"; // $NON-NLS-1$
 
     /**
      * Returns the result of the Assertion. 
@@ -73,6 +84,14 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
                 result.setFailureMessage("Error parsing variable name: "+variableName+" value: "+value);
                 return result;
             }
+        } else if (isTestFieldResponseHeaders()) {
+            resultSize = response.getHeadersSize();
+        }  else if (isTestFieldResponseBody()) {
+            resultSize = response.getBodySize();
+        } else if (isTestFieldResponseCode()) {
+            resultSize = response.getResponseCode().length();
+        } else if (isTestFieldResponseMessage()) {
+            resultSize = response.getResponseMessage().length();
         } else {
             resultSize = response.getBytes();
         }
@@ -80,7 +99,7 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
         final String msg = compareSize(resultSize);
         if (msg.length() > 0) {
             result.setFailure(true);
-            Object[] arguments = { new Long(resultSize), msg, new Long(getAllowedSize()) };
+            Object[] arguments = { Long.valueOf(resultSize), msg, Long.valueOf(getAllowedSize()) };
             String message = MessageFormat.format(JMeterUtils.getResString("size_assertion_failure"), arguments); //$NON-NLS-1$
             result.setFailureMessage(message);
         }
@@ -90,8 +109,8 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
     /**
      * Returns the size in bytes to be asserted.
      */
-    public long getAllowedSize() {
-        return getPropertyAsLong(SIZE_KEY);
+    public String getAllowedSize() {
+        return getPropertyAsString(SIZE_KEY);
     }
 
     /***************************************************************************
@@ -114,23 +133,14 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
     /**
      * Set the size that shall be asserted.
      * 
-     * @param size -
-     *            a number of bytes. Is not allowed to be negative. Use
-     *            Long.MAX_VALUE to indicate illegal or empty inputs. This will
-     *            result in not checking the assertion.
-     * 
-     * @throws IllegalArgumentException
-     *             If <code>size</code> is negative.
+     * @param size a number of bytes. 
      */
-    public void setAllowedSize(long size) throws IllegalArgumentException {
-        if (size < 0L) {
-            throw new IllegalArgumentException(JMeterUtils.getResString("argument_must_not_be_negative")); //$NON-NLS-1$
-        }
-        if (size == Long.MAX_VALUE) {
-            setProperty(new LongProperty(SIZE_KEY, 0));
-        } else {
-            setProperty(new LongProperty(SIZE_KEY, size));
-        }
+    public void setAllowedSize(String size) {
+            setProperty(SIZE_KEY, size);
+    }
+
+    public void setAllowedSize(long size) {
+        setProperty(SIZE_KEY, Long.toString(size));
     }
 
     /**
@@ -143,31 +153,32 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
      */
     private String compareSize(long resultSize) {
         String comparatorErrorMessage;
+        long allowedSize = Long.parseLong(getAllowedSize());
         boolean result = false;
         int comp = getCompOper();
         switch (comp) {
         case EQUAL:
-            result = (resultSize == getAllowedSize());
+            result = (resultSize == allowedSize);
             comparatorErrorMessage = JMeterUtils.getResString("size_assertion_comparator_error_equal"); //$NON-NLS-1$
             break;
         case NOTEQUAL:
-            result = (resultSize != getAllowedSize());
+            result = (resultSize != allowedSize);
             comparatorErrorMessage = JMeterUtils.getResString("size_assertion_comparator_error_notequal"); //$NON-NLS-1$
             break;
         case GREATERTHAN:
-            result = (resultSize > getAllowedSize());
+            result = (resultSize > allowedSize);
             comparatorErrorMessage = JMeterUtils.getResString("size_assertion_comparator_error_greater"); //$NON-NLS-1$
             break;
         case LESSTHAN:
-            result = (resultSize < getAllowedSize());
+            result = (resultSize < allowedSize);
             comparatorErrorMessage = JMeterUtils.getResString("size_assertion_comparator_error_less"); //$NON-NLS-1$
             break;
         case GREATERTHANEQUAL:
-            result = (resultSize >= getAllowedSize());
+            result = (resultSize >= allowedSize);
             comparatorErrorMessage = JMeterUtils.getResString("size_assertion_comparator_error_greaterequal"); //$NON-NLS-1$
             break;
         case LESSTHANEQUAL:
-            result = (resultSize <= getAllowedSize());
+            result = (resultSize <= allowedSize);
             comparatorErrorMessage = JMeterUtils.getResString("size_assertion_comparator_error_lessequal"); //$NON-NLS-1$
             break;
         default:
@@ -177,4 +188,53 @@ public class SizeAssertion extends AbstractScopedAssertion implements Serializab
         }
         return result ? "" : comparatorErrorMessage;
     }
+    
+    private void setTestField(String testField) {
+        setProperty(TEST_FIELD, testField);
+    }
+
+    public void setTestFieldNetworkSize(){
+        setTestField(RESPONSE_NETWORK_SIZE);
+    }
+    
+    public void setTestFieldResponseHeaders(){
+        setTestField(RESPONSE_HEADERS);
+    }
+    
+    public void setTestFieldResponseBody(){
+        setTestField(RESPONSE_BODY);
+    }
+    
+    public void setTestFieldResponseCode(){
+        setTestField(RESPONSE_CODE);
+    }
+    
+    public void setTestFieldResponseMessage(){
+        setTestField(RESPONSE_MESSAGE);
+    }
+
+    public String getTestField() {
+        return getPropertyAsString(TEST_FIELD);
+    }
+
+    public boolean isTestFieldNetworkSize(){
+        return RESPONSE_NETWORK_SIZE.equals(getTestField());
+    }
+
+    public boolean isTestFieldResponseHeaders(){
+        return RESPONSE_HEADERS.equals(getTestField());
+    }
+    
+    public boolean isTestFieldResponseBody(){
+        return RESPONSE_BODY.equals(getTestField());
+    }
+
+    public boolean isTestFieldResponseCode(){
+        return RESPONSE_CODE.equals(getTestField());
+    }
+
+    public boolean isTestFieldResponseMessage(){
+        return RESPONSE_MESSAGE.equals(getTestField());
+    }
+
 }
