@@ -86,6 +86,8 @@ public class CSVDataSet extends ConfigTestElement implements TestBean, LoopItera
     private transient String alias;
 
     private transient String shareMode;
+    
+    private boolean firstLineIsNames = false;
 
     private Object readResolve(){
         recycle = true;
@@ -121,6 +123,7 @@ public class CSVDataSet extends ConfigTestElement implements TestBean, LoopItera
                 String header = server.reserveFile(_fileName, getFileEncoding(), alias, true);
                 try {
                     vars = CSVSaveService.csvSplitString(header, getDelimiter().charAt(0));
+                    firstLineIsNames = true;
                 } catch (IOException e) {
                     log.warn("Could not split CSV header line",e);
                 }
@@ -129,7 +132,6 @@ public class CSVDataSet extends ConfigTestElement implements TestBean, LoopItera
                 vars = JOrphanUtils.split(names, ","); // $NON-NLS-1$
             }
         }
-        try {
             String delim = getDelimiter();
             if (delim.equals("\\t")) { // $NON-NLS-1$
                 delim = "\t";// Make it easier to enter a Tab // $NON-NLS-1$
@@ -139,13 +141,22 @@ public class CSVDataSet extends ConfigTestElement implements TestBean, LoopItera
             }
             // TODO: fetch this once as per vars above?
             JMeterVariables threadVars = context.getVariables();
-            String line = server.readLine(alias,getRecycle());
+            String line = null;
+            try {
+                line = server.readLine(alias, getRecycle(), firstLineIsNames);
+            } catch (IOException e) { // treat the same as EOF
+                log.error(e.toString());
+            }
             if (line!=null) {// i.e. not EOF
-                String[] lineValues = getQuotedData() ?
-                        CSVSaveService.csvSplitString(line, delim.charAt(0))
-                        : JOrphanUtils.split(line, delim, false);
-                for (int a = 0; a < vars.length && a < lineValues.length; a++) {
-                    threadVars.put(vars[a], lineValues[a]);
+                try {
+                    String[] lineValues = getQuotedData() ?
+                            CSVSaveService.csvSplitString(line, delim.charAt(0))
+                            : JOrphanUtils.split(line, delim, false);
+                            for (int a = 0; a < vars.length && a < lineValues.length; a++) {
+                                threadVars.put(vars[a], lineValues[a]);
+                            }
+                } catch (IOException e) { // Should only happen for quoting errors
+                   log.error("Unexpected error splitting '"+line+"' on '"+delim.charAt(0)+"'");
                 }
                 // TODO - report unused columns?
                 // TODO - provide option to set unused variables ?
@@ -157,9 +168,6 @@ public class CSVDataSet extends ConfigTestElement implements TestBean, LoopItera
                     threadVars.put(vars[a], EOFVALUE);
                 }
             }
-        } catch (IOException e) {// TODO - should the error be indicated in the variables?
-            log.error(e.toString());
-        }
     }
 
     /**
