@@ -26,6 +26,9 @@ import java.io.InputStream;
 import java.util.Iterator;
 import java.util.LinkedList;
 
+import org.apache.jmeter.testelement.TestPlan;
+import org.apache.jmeter.control.TestFragmentController;
+
 import org.apache.jmeter.gui.tree.JMeterTreeNode;
 import org.apache.jmeter.save.SaveService;
 import org.apache.jmeter.services.FileServer;
@@ -69,13 +72,13 @@ public class IncludeController extends GenericController implements ReplaceableC
         clone.setIncludePath(this.getIncludePath());
         if (this.SUBTREE != null) {
             if (this.SUBTREE.keySet().size() == 1) {
-                Iterator<TestElement> itr = this.SUBTREE.keySet().iterator();
+                Iterator<Object> itr = this.SUBTREE.keySet().iterator();
                 while (itr.hasNext()) {
-                    this.SUB = itr.next();
+                    this.SUB = (TestElement) itr.next();
                 }
             }
             clone.SUBTREE = (HashTree)this.SUBTREE.clone();
-            clone.SUB = (TestElement)this.SUB.clone();
+            clone.SUB = this.SUB==null ? null : (TestElement) this.SUB.clone();
         }
         return clone;
     }
@@ -105,6 +108,10 @@ public class IncludeController extends GenericController implements ReplaceableC
         return SUBTREE;
     }
 
+    public TestElement getReplacementElement() {
+        return SUB;
+    }
+
     public void resolveReplacementSubTree(JMeterTreeNode context) {
         this.SUBTREE = this.loadIncludedElements();
     }
@@ -135,6 +142,8 @@ public class IncludeController extends GenericController implements ReplaceableC
                 
                 reader = new FileInputStream(file);
                 tree = SaveService.loadTree(reader);
+                // filter the tree for a TestFragment.
+                tree = getProperBranch(tree);
                 removeDisabledItems(tree);
                 return tree;
             } catch (NoClassDefFoundError ex) // Allow for missing optional jars
@@ -164,10 +173,32 @@ public class IncludeController extends GenericController implements ReplaceableC
         return tree;
     }
 
-    private void removeDisabledItems(HashTree tree) {
-        Iterator<TestElement> iter = new LinkedList<TestElement>(tree.list()).iterator();
+    private HashTree getProperBranch(HashTree tree) {
+        Iterator<Object> iter = new LinkedList<Object>(tree.list()).iterator();
         while (iter.hasNext()) {
-            TestElement item = iter.next();
+            TestElement item = (TestElement) iter.next();
+
+            //if we found a TestPlan, then we are on our way to the TestFragment
+            if (item instanceof TestPlan)
+            {
+                return getProperBranch(tree.getTree(item));
+            }
+
+            if (item instanceof TestFragmentController)
+            {
+                return tree.getTree(item);
+            }
+        }
+        //return the tree since we didn't find a TestFragment.  This will mimic the 
+        //old behavior to import an exact node.
+        return tree;
+    }
+
+
+    private void removeDisabledItems(HashTree tree) {
+        Iterator<Object> iter = new LinkedList<Object>(tree.list()).iterator();
+        while (iter.hasNext()) {
+            TestElement item = (TestElement) iter.next();
             if (!item.isEnabled()) {
                 //log.info("Removing "+item.toString());
                 tree.remove(item);
