@@ -54,11 +54,13 @@ import org.apache.jmeter.visualizers.gui.AbstractVisualizer;
  */
 public class GraphVisualizer extends AbstractVisualizer implements ImageVisualizer, ItemListener, Clearable {
 
+    private static final long serialVersionUID = 240L;
+
     private static final String ZERO = "0";  //$NON-NLS-1$
 
     private NumberFormat nf = NumberFormat.getInstance(); // OK, because used in synchronised method
 
-    private SamplingStatCalculator model;
+    private CachingStatCalculator model;
 
     private JTextField maxYField = null;
 
@@ -94,7 +96,7 @@ public class GraphVisualizer extends AbstractVisualizer implements ImageVisualiz
      * Constructor for the GraphVisualizer object.
      */
     public GraphVisualizer() {
-        model = new SamplingStatCalculator("Graph");
+        model = new CachingStatCalculator("Graph");
         graph = new Graph(model);
         init();
     }
@@ -160,6 +162,7 @@ public class GraphVisualizer extends AbstractVisualizer implements ImageVisualiz
         repaint();
     }
 
+    @Override
     public String toString() {
         return "Show the samples analysis as dot plots";
     }
