@@ -23,8 +23,13 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
+import java.lang.Thread.UncaughtExceptionHandler;
 import java.net.Authenticator;
+import java.net.DatagramPacket;
+import java.net.DatagramSocket;
+import java.net.InetAddress;
 import java.net.MalformedURLException;
+import java.net.SocketException;
 import java.text.SimpleDateFormat;
 import java.util.Collection;
 import java.util.Date;
@@ -35,6 +40,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Properties;
 import java.util.StringTokenizer;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apache.commons.cli.avalon.CLArgsParser;
 import org.apache.commons.cli.avalon.CLOption;
@@ -87,6 +93,8 @@ public class JMeter implements JMeterPlugin {
 
     private static final Logger log = LoggingManager.getLoggerForClass();
 
+    public static final int UDP_PORT_DEFAULT = 4445; // needed for ShutdownClient
+
     public static final String HTTP_PROXY_PASS = "http.proxyPass"; // $NON-NLS-1$
 
     public static final String HTTP_PROXY_USER = "http.proxyUser"; // $NON-NLS-1$
@@ -127,10 +135,6 @@ public class JMeter implements JMeterPlugin {
 
 
 
-
-
-
-
     /**
      * Define the understood options. Each CLOptionDescriptor contains:
      * <ul>
@@ -207,7 +211,7 @@ public class JMeter implements JMeterPlugin {
 
     private Properties remoteProps; // Properties to be sent to remote servers
 
-    private boolean remoteStop; // should remote engines be stopped at end of GUI test?
+    private boolean remoteStop; // should remote engines be stopped at end of non-GUI test?
 
     /**
      * Starts up JMeter in GUI mode
@@ -250,6 +254,8 @@ public class JMeter implements JMeterPlugin {
     /**
      * Takes the command line arguments and uses them to determine how to
      * startup JMeter.
+     * 
+     * Called reflectively by {@link NewDriver#main(String[])}
      */
     public void start(String[] args) {
 
@@ -257,10 +263,11 @@ public class JMeter implements JMeterPlugin {
         String error = parser.getErrorString();
         if (error == null){// Check option combinations
             boolean gui = parser.getArgumentById(NONGUI_OPT)==null;
-            boolean remoteStart = parser.getArgumentById(REMOTE_OPT)!=null
-                               || parser.getArgumentById(REMOTE_OPT_PARAM)!=null;
-            if (gui && remoteStart) {
-                error = "-r and -R are only valid in non-GUI mode";
+            boolean nonGuiOnly = parser.getArgumentById(REMOTE_OPT)!=null
+                               || parser.getArgumentById(REMOTE_OPT_PARAM)!=null
+                               || parser.getArgumentById(REMOTE_STOP)!=null;
+            if (gui && nonGuiOnly) {
+                error = "-r and -R and -X are only valid in non-GUI mode";
             }
         }
         if (null != error) {
@@ -283,6 +290,15 @@ public class JMeter implements JMeterPlugin {
                         , "org.apache.commons.logging.impl.LogKitLogger"); // $NON-NLS-1$
             }
 
+            Thread.setDefaultUncaughtExceptionHandler(new UncaughtExceptionHandler() {                
+                public void uncaughtException(Thread t, Throwable e) {
+                    if (!(e instanceof ThreadDeath)) {
+                        log.error("Uncaught exception: ", e);
+                        System.err.println("Uncaught Exception " + e + ". See log file for details.");
+                    }
+                }
+            });
+
             log.info(JMeterUtils.getJMeterCopyright());
             log.info("Version " + JMeterUtils.getJMeterVersion());
             logProperty("java.version"); //$NON-NLS-1$
@@ -328,7 +344,13 @@ public class JMeter implements JMeterPlugin {
                 System.out.println(JMeterUtils.getResourceFileAsText("org/apache/jmeter/help.txt"));// $NON-NLS-1$
             } else if (parser.getArgumentById(SERVER_OPT) != null) {
                 // Start the server
-                startServer(JMeterUtils.getPropDefault("server_port", 0));// $NON-NLS-1$
+                try {
+                    RemoteJMeterEngineImpl.startServer(JMeterUtils.getPropDefault("server_port", 0)); // $NON-NLS-1$
+                } catch (Exception ex) {
+                    System.err.println("Server failed to start: "+ex);
+                    log.error("Giving up, as server failed with:", ex);
+                    throw ex;
+                }
                 startOptionalServers();
             } else {
                 String testFile=null;
@@ -365,7 +387,7 @@ public class JMeter implements JMeterPlugin {
                 e.printStackTrace();
             }
             System.out.println("An error occurred: " + e.getMessage());
-            System.exit(1);
+            System.exit(1); // TODO - could this be return?
         }
     }
 
@@ -663,16 +685,6 @@ public class JMeter implements JMeterPlugin {
         return jmlogfile;
     }
 
-    private void startServer(int port) {
-        try {
-            RemoteJMeterEngineImpl.startServer(port);
-        } catch (Exception ex) {
-            log.error("Giving up, as server failed with:", ex);
-            System.err.println("Server failed to start: "+ex);
-            System.exit(1);// Give up
-        }
-    }
-
     private void startNonGui(String testFile, String logFile, CLOption remoteStart)
             throws IllegalUserActionException {
         // add a system property so samplers can check to see if JMeter
@@ -696,11 +708,7 @@ public class JMeter implements JMeterPlugin {
         if (testFile == null) {
             throw new IllegalUserActionException("Non-GUI runs require a test plan");
         }
-        if (logFile == null) {
-            driver.runNonGui(testFile, null, remoteStart != null,remote_hosts_string);
-        } else {
-            driver.runNonGui(testFile, logFile, remoteStart != null,remote_hosts_string);
-        }
+        driver.runNonGui(testFile, logFile, remoteStart != null, remote_hosts_string);
     }
 
     // run test in batch mode
@@ -712,7 +720,7 @@ public class JMeter implements JMeterPlugin {
                 println("Could not open " + testFile);
                 return;
             }
-            FileServer.getFileServer().setBasedir(f.getAbsolutePath());
+            FileServer.getFileServer().setBaseForScript(f);
 
             reader = new FileInputStream(f);
             log.info("Loading file: " + f);
@@ -773,23 +781,33 @@ public class JMeter implements JMeterPlugin {
                     String el = (String) st.nextElement();
                     println("Configuring remote engine for " + el);
                     log.info("Configuring remote engine for " + el);
-                    engines.add(doRemoteInit(el.trim(), tree));
+                    JMeterEngine eng = doRemoteInit(el.trim(), tree);
+                    if (null != eng) {
+                        engines.add(eng);
+                    } else {
+                        println("Failed to configure "+el);
+                    }
+                }
+                if (engines.isEmpty()) {
+                    println("No remote engines were started.");
+                    return;
                 }
                 println("Starting remote engines");
+                log.info("Starting remote engines");
                 long now=System.currentTimeMillis();
                 println("Starting the test @ "+new Date(now)+" ("+now+")");
                 Iterator<JMeterEngine> iter = engines.iterator();
                 while (iter.hasNext()) {
                     engine = iter.next();
-                    if (engine != null){
-                        engine.runTest();
-                    }
+                    engine.runTest();
                 }
                 println("Remote engines have been started");
+                log.info("Remote engines have been started");
             }
+            startUdpDdaemon(engine);
         } catch (Exception e) {
             System.out.println("Error in NonGUIDriver " + e.toString());
-            log.error("", e);
+            log.error("Error in NonGUIDriver", e);
         } finally {
             JOrphanUtils.closeQuietly(reader);
         }
@@ -871,8 +889,8 @@ public class JMeter implements JMeterPlugin {
         try {
             engine = new ClientJMeterEngine(hostName);
         } catch (Exception e) {
-            log.fatalError("Failure connecting to remote host", e);
-            System.err.println("Failure connecting to remote host"+e);
+            log.fatalError("Failure connecting to remote host: "+hostName, e);
+            System.err.println("Failure connecting to remote host: "+hostName+" "+e);
             return null;
         }
         engine.configure(testTree);
@@ -885,25 +903,24 @@ public class JMeter implements JMeterPlugin {
     /*
      * Listen to test and handle tidyup after non-GUI test completes.
      * If running a remote test, then after waiting a few seconds for listeners to finish files,
-     * it calls System.exit to deal with the Naming Timer Thread.
+     * it calls ClientJMeterEngine.tidyRMI() to deal with the Naming Timer Thread.
      */
     private static class ListenToTest implements TestListener, Runnable, Remoteable {
-        private int started = 0; // keep track of remote tests
+        private AtomicInteger started = new AtomicInteger(0); // keep track of remote tests
 
         //NOT YET USED private JMeter _parent;
 
-        private List<JMeterEngine> engines;
+        private final List<JMeterEngine> engines;
 
         public ListenToTest(JMeter parent, List<JMeterEngine> engines) {
             //_parent = parent;
             this.engines=engines;
         }
 
-        public synchronized void testEnded(String host) {
-            started--;
+        public void testEnded(String host) {
             long now=System.currentTimeMillis();
             log.info("Finished remote host: " + host + " ("+now+")");
-            if (started <= 0) {
+            if (started.decrementAndGet() <= 0) {
                 Thread stopSoon = new Thread(this);
                 stopSoon.start();
             }
@@ -915,8 +932,8 @@ public class JMeter implements JMeterPlugin {
             println("... end of run");
         }
 
-        public synchronized void testStarted(String host) {
-            started++;
+        public void testStarted(String host) {
+            started.incrementAndGet();
             long now=System.currentTimeMillis();
             log.info("Started remote host:  " + host + " ("+now+")");
         }
@@ -935,14 +952,9 @@ public class JMeter implements JMeterPlugin {
          */
         public void run() {
             long now = System.currentTimeMillis();
-            println("Tidying up ...    @ "+new Date(now)+" ("+now+")");
-            /*
-             * Note: although it should not be necessary to call System.exit here, in the case
-             * of a remote test, a Timer thread seems to be generated by the Naming.lookup()
-             * method, and it does not die.
-             */
+            println("Tidying up remote @ "+new Date(now)+" ("+now+")");
             if (engines!=null){ // it will be null unless remoteStop = true
-                System.out.println("Exitting remote servers");
+                println("Exitting remote servers");
                 Iterator<JMeterEngine> it = engines.iterator();
                 while(it.hasNext()){
                     JMeterEngine e = it.next();
@@ -953,8 +965,8 @@ public class JMeter implements JMeterPlugin {
                 Thread.sleep(5000); // Allow listeners to close files
             } catch (InterruptedException ignored) {
             }
+            ClientJMeterEngine.tidyRMI(log);
             println("... end of run");
-            System.exit(0);
         }
 
         /**
@@ -1032,4 +1044,68 @@ public class JMeter implements JMeterPlugin {
     private void logProperty(String prop,String separator){
         log.info(prop+separator+System.getProperty(prop));//$NON-NLS-1$
     }
+
+    private static void startUdpDdaemon(final JMeterEngine engine) {
+        int port = JMeterUtils.getPropDefault("jmeterengine.nongui.port", UDP_PORT_DEFAULT); // $NON-NLS-1$
+        int maxPort = JMeterUtils.getPropDefault("jmeterengine.nongui.maxport", 4455); // $NON-NLS-1$
+        if (port > 1000){
+            final DatagramSocket socket = getSocket(port, maxPort);
+            if (socket != null) {
+                Thread waiter = new Thread("UDP Listener"){
+                    @Override
+                    public void run() {
+                        waitForSignals(engine, socket);
+                    }
+                };
+                waiter.setDaemon(true);
+                waiter.start();
+            } else {
+                System.out.println("Failed to create UDP port");
+            }
+        }
+    }
+
+    private static void waitForSignals(final JMeterEngine engine, DatagramSocket socket) {
+        byte[] buf = new byte[80];
+        System.out.println("Waiting for possible shutdown message on port "+socket.getLocalPort());
+        DatagramPacket request = new DatagramPacket(buf, buf.length);
+        try {
+            while(true) {
+                socket.receive(request);
+                InetAddress address = request.getAddress();
+                // Only accept commands from the local host
+                if (address.isLoopbackAddress()){
+                    String command = new String(request.getData(), request.getOffset(), request.getLength(),"ASCII");
+                    System.out.println("Command: "+command+" received from "+address);
+                    log.info("Command: "+command+" received from "+address);
+                    if (command.equals("StopTestNow")){
+                        engine.stopTest(true);
+                    } else if (command.equals("Shutdown")) {
+                        engine.stopTest(false);
+                    } else {
+                        System.out.println("Command: "+command+" not recognised ");
+                    }
+                }
+            }
+        } catch (Exception e) {
+            System.out.println(e);
+        } finally {
+            socket.close();
+        }
+    }
+
+    private static DatagramSocket getSocket(int udpPort, int udpPortMax) {
+        DatagramSocket socket = null;
+        int i = udpPort;
+        while (i<= udpPortMax) {
+            try {
+                socket = new DatagramSocket(i);
+                break;
+            } catch (SocketException e) {
+                i++;
+            }            
+        }
+
+        return socket;
+    }
 }
\ No newline at end of file
