@@ -181,7 +181,15 @@ public class GenericController extends AbstractTestElement implements Controller
      * @throws NextIsNullException
      */
     protected Sampler nextIsAController(Controller controller) throws NextIsNullException {
-        Sampler sampler = controller.next();
+        Sampler sampler = null;
+        try {
+            sampler = controller.next();
+        } catch (StackOverflowError soe) {
+            // See bug 50618  Catches a StackOverflowError when a condition returns 
+            // always false (after at least one iteration with return true)
+            log.warn("StackOverflowError detected"); // $NON-NLS-1$
+            throw new NextIsNullException();
+        }
         if (sampler == null) {
             currentReturnedNull(controller);
             sampler = next();
@@ -215,6 +223,31 @@ public class GenericController extends AbstractTestElement implements Controller
         return null;
     }
 
+    /**
+     * Called to re-initialize a index of controller's elements (Bug 50032)
+     * 
+     */
+    protected void reInitializeSubController() {
+        boolean wasFlagSet = getThreadContext().setIsReinitializingSubControllers();
+        try {
+            TestElement currentElement = getCurrentElement();
+            if (currentElement != null) {
+                if (currentElement instanceof Sampler) {
+                    nextIsASampler((Sampler) currentElement);
+                } else { // must be a controller
+                    if (nextIsAController((Controller) currentElement) != null) {
+                        reInitializeSubController();
+                    }
+                }
+            }
+        } catch (NextIsNullException e) {
+        } finally {
+            if (wasFlagSet) {
+                getThreadContext().unsetIsReinitializingSubControllers();
+            }
+        }
+    }
+    
     /**
      * If the controller is done, remove it from the list,
      * otherwise increment to next entry in list.
@@ -305,6 +338,20 @@ public class GenericController extends AbstractTestElement implements Controller
          */
         iterationListeners.addFirst(lis);
     }
+    
+    /**
+     * Remove listener
+     */
+    public void removeIterationListener(LoopIterationListener iterationListener) {
+        for (Iterator<LoopIterationListener> iterator = iterationListeners.iterator(); iterator.hasNext();) {
+            LoopIterationListener listener = iterator.next();
+            if(listener == iterationListener)
+            {
+                iterator.remove();
+                break; // can only match once
+            }
+        }
+    }
 
     protected void fireIterEvents() {
         if (isFirst()) {
