@@ -27,24 +27,29 @@ import org.apache.log.Logger;
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.Scriptable;
 
-/*******************************************************************************
+/**
  *
  *
  * This is a Conditional Controller; it will execute the set of statements
  * (samplers/controllers, etc) while the 'condition' is true.
+ * <p>
  * In a programming world - this is equivalant of :
+ * <pre>
  * if (condition) {
  *          statements ....
  *          }
- * In JMeter you may have : Thread-Group (set to loop a number of times or indefinitely,
+ * </pre>
+ * In JMeter you may have :
+ * <pre> 
+ * Thread-Group (set to loop a number of times or indefinitely,
  *    ... Samplers ... (e.g. Counter )
  *    ... Other Controllers ....
  *    ... IfController ( condition set to something like - ${counter}<10)
  *       ... statements to perform if condition is true
  *       ...
  *    ... Other Controllers /Samplers }
- *
- ******************************************************************************/
+ * </pre>
+ */
 
 // for unit test code @see TestIfController
 
@@ -92,7 +97,7 @@ public class IfController extends GenericController implements Serializable {
     /**
      * evaluate the condition clause log error if bad condition
      */
-    private static boolean evaluateCondition(String cond) {
+    private boolean evaluateCondition(String cond) {
         logger.debug("    getCondition() : [" + cond + "]");
 
         String resultStr = "";
@@ -117,7 +122,7 @@ public class IfController extends GenericController implements Serializable {
 
             logger.debug("    >> evaluate Condition -  [ " + cond + "] results is  [" + result + "]");
         } catch (Exception e) {
-            logger.error(e.getMessage(), e);
+            logger.error(getName()+": error while processing "+ "[" + cond + "]\n", e);
         } finally {
             Context.exit();
         }
@@ -168,7 +173,9 @@ public class IfController extends GenericController implements Serializable {
         if (result) {
             return super.next();
         }
+        // If-test is false, need to re-initialize indexes
         try {
+            reInitializeSubController(); // Bug 50032 - reinitialize current index element for all sub controller
             return nextIsNull();
         } catch (NextIsNullException e1) {
             return null;
