@@ -188,11 +188,14 @@ public class TransactionController extends GenericController implements SampleLi
                 if (pack == null) {
                     log.warn("Could not fetch SamplePackage");
                 } else {
-                    SampleEvent event = new SampleEvent(res, threadContext.getThreadGroup().getName(),threadVars);
+                    SampleEvent event = new SampleEvent(res, threadContext.getThreadGroup().getName(),threadVars, true);
                     // We must set res to null now, before sending the event for the transaction,
                     // so that we can ignore that event in our sampleOccured method
                     res = null;
-                    lnf.notifyListeners(event, pack.getSampleListeners());
+                    // bug 50032 
+                    if (!getThreadContext().isReinitializingSubControllers()) {
+                        lnf.notifyListeners(event, pack.getSampleListeners());
+                    }
                 }
             }
         }
@@ -207,7 +210,7 @@ public class TransactionController extends GenericController implements SampleLi
     public void sampleOccurred(SampleEvent se) {
         if (!isParent()) {
             // Check if we are still sampling our children
-            if(res != null) {
+            if(res != null && !se.isTransactionSampleEvent()) {
                 SampleResult sampleResult = se.getResult();
                 res.setThreadName(sampleResult.getThreadName());
                 res.setBytes(res.getBytes() + sampleResult.getBytes());
