@@ -18,6 +18,7 @@
 
 package org.apache.jmeter.engine;
 
+import java.io.File;
 import java.net.MalformedURLException;
 import java.rmi.Naming;
 import java.rmi.NotBoundException;
@@ -26,8 +27,10 @@ import java.rmi.RemoteException;
 import java.rmi.server.RemoteObject;
 import java.util.Properties;
 
+import org.apache.jmeter.services.FileServer;
 import org.apache.jmeter.testelement.TestListener;
 import org.apache.jmeter.threads.JMeterContextService;
+import org.apache.jmeter.util.JMeterUtils;
 import org.apache.jorphan.collections.HashTree;
 import org.apache.jorphan.collections.SearchByClass;
 import org.apache.jorphan.logging.LoggingManager;
@@ -36,7 +39,7 @@ import org.apache.log.Logger;
 /**
  * Class to run remote tests from the client JMeter and collect remote samples
  */
-public class ClientJMeterEngine implements JMeterEngine, Runnable {
+public class ClientJMeterEngine implements JMeterEngine {
     private static final Logger log = LoggingManager.getLoggerForClass();
 
     private static final Object LOCK = new Object();
@@ -75,17 +78,10 @@ public class ClientJMeterEngine implements JMeterEngine, Runnable {
     }
 
     /** {@inheritDoc} */
-    public void runTest() {
-        log.info("about to run remote test on "+host);
-        new Thread(this).start();
-        log.info("done initiating run command");
-    }
-
-    /** {@inheritDoc} */
-    public void stopTest() {
-        log.info("about to stop remote test on "+host);
+    public void stopTest(boolean now) {
+        log.info("about to "+(now ? "stop" : "shutdown")+" remote test on "+host);
         try {
-            remote.stopTest();
+            remote.rstopTest(now);
         } catch (Exception ex) {
             log.error("", ex); // $NON-NLS-1$
         }
@@ -95,18 +91,18 @@ public class ClientJMeterEngine implements JMeterEngine, Runnable {
     public void reset() {
         try {
             try {
-                remote.reset();
+                remote.rreset();
             } catch (java.rmi.ConnectException e) {
+                log.info("Retry reset after: "+e);
                 remote = getEngine(host);
-                remote.reset();
+                remote.rreset();
             }
         } catch (Exception ex) {
-            log.error("", ex); // $NON-NLS-1$
+            log.error("Failed to reset remote engine", ex); // $NON-NLS-1$
         }
     }
 
-    /** {@inheritDoc} */
-    public void run() {
+    public void runTest() throws JMeterEngineException {
         log.info("running clientengine run method");
         SearchByClass<TestListener> testListeners = new SearchByClass<TestListener>(TestListener.class);
         ConvertListeners sampleListeners = new ConvertListeners();
@@ -126,31 +122,55 @@ public class ClientJMeterEngine implements JMeterEngine, Runnable {
              * 
              * See https://issues.apache.org/bugzilla/show_bug.cgi?id=48350
             */
+            File baseDirRelative = FileServer.getFileServer().getBaseDirRelative();
             synchronized(LOCK)
             {
-                remote.configure(testTree, host);
+                remote.rconfigure(testTree, host, baseDirRelative);
             }
-            log.info("sent test to " + host);
+            log.info("sent test to " + host + " basedir='"+baseDirRelative+"'"); // $NON-NLS-1$
             if (savep != null){
                 log.info("Sending properties "+savep);
                 try {
-                    remote.setProperties(savep);
+                    remote.rsetProperties(savep);
                 } catch (RemoteException e) {
                     log.warn("Could not set properties: " + e.toString());
                 }
             }
-            remote.runTest();
+            remote.rrunTest();
             log.info("sent run command to "+ host);
+        } catch (IllegalStateException ex) {
+            log.error("Error in run() method "+ex); // $NON-NLS-1$
+            tidyRMI(log);
+            throw ex; // Don't wrap this error - display it as is
         } catch (Exception ex) {
-            log.error("", ex); // $NON-NLS-1$
+            log.error("Error in run() method "+ex); // $NON-NLS-1$
+            tidyRMI(log);
+            throw new JMeterEngineException("Error in run() method "+ex, ex); // $NON-NLS-1$
+        }
+    }
+
+    /**
+     * Tidy up RMI access to allow JMeter client to exit.
+     * Currently just interrups the "RMI Reaper" thread.
+     * @param logger where to log the information
+     */
+    public static void tidyRMI(Logger logger) {
+        for(Thread t : Thread.getAllStackTraces().keySet()){
+            String reaperRE = JMeterUtils.getPropDefault("rmi.thread.name", "^RMI Reaper$");
+            String name = t.getName();
+            if (name.matches(reaperRE)) {
+                logger.info("Interrupting "+name);
+                t.interrupt();
+            }
         }
     }
 
     /** {@inheritDoc} */
+    // Called by JMeter ListenToTest if remoteStop is true
     public void exit() {
         log.info("about to exit remote server on "+host);
         try {
-            remote.exit();
+            remote.rexit();
         } catch (RemoteException e) {
             log.warn("Could not perform remote exit: " + e.toString());
         }
@@ -162,4 +182,8 @@ public class ClientJMeterEngine implements JMeterEngine, Runnable {
         savep = p;
         // Sent later
     }
+
+    public boolean isActive() {
+        return true;
+    }
 }
