@@ -18,22 +18,26 @@
 
 package org.apache.jmeter.engine;
 
+import java.io.File;
 import java.rmi.Remote;
 import java.rmi.RemoteException;
 import java.util.Properties;
 
 import org.apache.jorphan.collections.HashTree;
 
+/**
+ * This is the interface for the RMI server engine, i.e. {@link RemoteJMeterEngineImpl}
+ */
 public interface RemoteJMeterEngine extends Remote {
-    void configure(HashTree testTree, String host) throws RemoteException;
+    void rconfigure(HashTree testTree, String host, File jmxBase) throws RemoteException;
 
-    void runTest() throws RemoteException, JMeterEngineException;
+    void rrunTest() throws RemoteException, JMeterEngineException;
 
-    void stopTest() throws RemoteException;
+    void rstopTest(boolean now) throws RemoteException;
 
-    void reset() throws RemoteException;
+    void rreset() throws RemoteException;
 
-    void setProperties(Properties p) throws RemoteException;
+    void rsetProperties(Properties p) throws RemoteException;
 
-    void exit() throws RemoteException;
+    void rexit() throws RemoteException;
 }
