@@ -18,13 +18,16 @@
 
 package org.apache.jmeter.engine;
 
+import java.io.File;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
+import java.rmi.NotBoundException;
 import java.rmi.RemoteException;
 import java.rmi.registry.LocateRegistry;
 import java.rmi.registry.Registry;
 import java.util.Properties;
 
+import org.apache.jmeter.services.FileServer;
 import org.apache.jmeter.util.JMeterUtils;
 import org.apache.jorphan.collections.HashTree;
 import org.apache.jorphan.logging.LoggingManager;
@@ -40,7 +43,9 @@ public class RemoteJMeterEngineImpl extends java.rmi.server.UnicastRemoteObject
 
     static final String JMETER_ENGINE_RMI_NAME = "JMeterEngine"; // $NON-NLS-1$
 
-    private JMeterEngine backingEngine;
+    private transient JMeterEngine backingEngine;
+    
+    private transient Thread ownerThread;
 
     public static final int DEFAULT_RMI_PORT =
         JMeterUtils.getPropDefault("server.rmi.port", 1099); // $NON-NLS-1$
@@ -53,22 +58,28 @@ public class RemoteJMeterEngineImpl extends java.rmi.server.UnicastRemoteObject
             System.out.println("Using local port: "+DEFAULT_LOCAL_PORT);
         }
     }
+
     // Should we create our own copy of the RMI registry?
     private static final boolean createServer =
         JMeterUtils.getPropDefault("server.rmi.create", true); // $NON-NLS-1$
 
-    private RemoteJMeterEngineImpl(int port) throws RemoteException {
-        super(port); // Create this object using the specified port (0 means anonymous)
+    private final Object LOCK = new Object();
+
+    private final int rmiPort;
+    
+    private RemoteJMeterEngineImpl(int localPort, int rmiPort) throws RemoteException {
+        super(localPort); // Create this object using the specified port (0 means anonymous)
+        this.rmiPort = rmiPort;
         System.out.println("Created remote object: "+this.getRef().remoteToString());
     }
 
-    public static void startServer(int port) throws RemoteException {
-        RemoteJMeterEngineImpl engine = new RemoteJMeterEngineImpl(DEFAULT_LOCAL_PORT);
-        engine.init(port == 0 ? DEFAULT_RMI_PORT : port);
+    public static void startServer(int rmiPort) throws RemoteException {
+        RemoteJMeterEngineImpl engine = new RemoteJMeterEngineImpl(DEFAULT_LOCAL_PORT, rmiPort == 0 ? DEFAULT_RMI_PORT : rmiPort);
+        engine.init();
     }
 
-    private void init(int port) throws RemoteException {
-        log.info("Starting backing engine on " + port);
+    private void init() throws RemoteException {
+        log.info("Starting backing engine on " + this.rmiPort);
         InetAddress localHost=null;
         try {
             // Bug 47980
@@ -90,7 +101,7 @@ public class RemoteJMeterEngineImpl extends java.rmi.server.UnicastRemoteObject
         if (createServer){
             log.info("Creating RMI registry (server.rmi.create=true)");
             try {
-                LocateRegistry.createRegistry(port);
+                LocateRegistry.createRegistry(this.rmiPort);
             } catch (RemoteException e){
                 String msg="Problem creating registry: "+e;
                 log.warn(msg);
@@ -99,9 +110,9 @@ public class RemoteJMeterEngineImpl extends java.rmi.server.UnicastRemoteObject
             }
         }
         try {
-            Registry reg = LocateRegistry.getRegistry(port);
+            Registry reg = LocateRegistry.getRegistry(this.rmiPort);
             reg.rebind(JMETER_ENGINE_RMI_NAME, this);
-            log.info("Bound to registry on port " + port);
+            log.info("Bound to registry on port " + this.rmiPort);
         } catch (Exception ex) {
             log.error("rmiregistry needs to be running to start JMeter in server " + "mode\n\t" + ex.toString());
             // Throw an Exception to ensure caller knows ...
@@ -116,33 +127,82 @@ public class RemoteJMeterEngineImpl extends java.rmi.server.UnicastRemoteObject
      * @param testTree
      *            the feature to be added to the ThreadGroup attribute
      */
-    public void configure(HashTree testTree, String host) throws RemoteException {
-        log.info("Creating JMeter engine on host "+host);
-        backingEngine = new StandardJMeterEngine(host);
-        backingEngine.configure(testTree);
+    public void rconfigure(HashTree testTree, String host, File jmxBase) throws RemoteException {
+        log.info("Creating JMeter engine on host "+host+" base '"+jmxBase+"'");
+        synchronized(LOCK) { // close window where another remote client might jump in
+            if (backingEngine != null && backingEngine.isActive()) {
+                log.warn("Engine is busy - cannot create JMeter engine");
+                throw new IllegalStateException("Engine is busy - please try later");
+            }
+            ownerThread = Thread.currentThread();
+            backingEngine = new StandardJMeterEngine(host);
+            backingEngine.configure(testTree); // sets active = true
+        }
+        FileServer.getFileServer().setBase(jmxBase);
     }
 
-    public void runTest() throws RemoteException, JMeterEngineException {
-        log.info("running test");
+    public void rrunTest() throws RemoteException, JMeterEngineException, IllegalStateException {
+        log.info("Running test");
+        checkOwner("runTest");
         backingEngine.runTest();
     }
 
-    public void reset() throws RemoteException {
-        log.info("Reset");
-        backingEngine.reset();
+    public void rreset() throws RemoteException, IllegalStateException {
+        // Mail on userlist reported NPE here - looks like only happens if there are network errors, but check anyway
+        if (backingEngine != null) {
+            log.info("Reset");
+            checkOwner("reset");
+            backingEngine.reset();
+        } else {
+            log.warn("Backing engine is null, ignoring reset");
+        }
     }
 
-    public void stopTest() throws RemoteException {
-        log.info("Stopping test");
-        backingEngine.stopTest();// TODO: askThreadsToStop() instead?
+    public void rstopTest(boolean now) throws RemoteException {
+        if (now) {
+            log.info("Stopping test ...");
+        } else {
+            log.info("Shutting test ...");
+        }
+        backingEngine.stopTest(now);
+        log.info("... stopped");
     }
 
-    public void exit() throws RemoteException {
+    /*
+     * Called by:
+     * - ClientJMeterEngine.exe() which is called on remoteStop 
+     */
+    public void rexit() throws RemoteException {
         log.info("Exitting");
         backingEngine.exit();
+        // Tidy up any objects we created
+        Registry reg = LocateRegistry.getRegistry(this.rmiPort);        
+        try {
+            reg.unbind(JMETER_ENGINE_RMI_NAME);
+        } catch (NotBoundException e) {
+            log.warn(JMETER_ENGINE_RMI_NAME+" is not bound",e);
+        }
+        log.info("Unbound from registry");
+        // Help with garbage control
+        System.gc();
+        System.runFinalization();
     }
 
-    public void setProperties(Properties p) throws RemoteException {
+    public void rsetProperties(Properties p) throws RemoteException, IllegalStateException {
+        checkOwner("setProperties");
         backingEngine.setProperties(p);
     }
+
+    /**
+     * Check if the caller owns the engine.
+     * @param methodName the name of the method for the log message
+     * @throws IllegalStateException if the caller is not the owner.
+     */
+    private void checkOwner(String methodName) throws IllegalStateException {
+        if (ownerThread != null && ownerThread != Thread.currentThread()){
+            String msg = "The engine is not owned by this thread - cannot call "+methodName;
+            log.warn(msg);
+            throw new IllegalStateException(msg);            
+        }
+    }
 }
