@@ -20,16 +20,13 @@ package org.apache.jmeter.engine;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;
-import java.net.DatagramPacket;
-import java.net.DatagramSocket;
-import java.net.InetAddress;
 import java.util.ArrayList;
 import java.util.Date;
-import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Properties;
 import java.util.concurrent.ConcurrentHashMap;
 
@@ -45,6 +42,8 @@ import org.apache.jmeter.threads.JMeterThreadMonitor;
 import org.apache.jmeter.threads.ListenerNotifier;
 import org.apache.jmeter.threads.TestCompiler;
 import org.apache.jmeter.threads.AbstractThreadGroup;
+import org.apache.jmeter.threads.SetupThreadGroup;
+import org.apache.jmeter.threads.PostThreadGroup;
 import org.apache.jmeter.util.JMeterUtils;
 import org.apache.jorphan.collections.HashTree;
 import org.apache.jorphan.collections.ListedHashTree;
@@ -53,17 +52,14 @@ import org.apache.jorphan.logging.LoggingManager;
 import org.apache.log.Logger;
 
 /**
+ * Runs JMeter tests, either directly for local GUI and non-GUI invocations, 
+ * or started by {@link RemoteJMeterEngineImpl} when running in server mode.
  */
 public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor, Runnable {
     private static final Logger log = LoggingManager.getLoggerForClass();
 
-    private static final long serialVersionUID = 233L; // Remember to change this when the class changes ...
-
     private static final long WAIT_TO_DIE = JMeterUtils.getPropDefault("jmeterengine.threadstop.wait", 5 * 1000); // 5 seconds
 
-    /** UDP port used in non-GUI runs. Disabled if <=1000. */
-    private static final int UDP_PORT = JMeterUtils.getPropDefault("jmeterengine.nongui.port", 4445);
-
     // Should we exit at end of the test? (only applies to server, because host is non-null)
     private static final boolean exitAfterTest =
         JMeterUtils.getPropDefault("server.exitaftertest", false);  // $NON-NLS-1$
@@ -91,15 +87,21 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
      */
     private static final List<TestListener> testList = new ArrayList<TestListener>();
 
+    /** Whether to call System.exit(0) in exit after stopping RMI */
+    private static final boolean REMOTE_SYSTEM_EXIT = JMeterUtils.getPropDefault("jmeterengine.remote.system.exit", false);
+
+    /** Whether to call System.exit(1) if threads won't stop */
+    private static final boolean SYSTEM_EXIT_ON_STOP_FAIL = JMeterUtils.getPropDefault("jmeterengine.stopfail.system.exit", true);
+
     /** JMeterThread => its JVM thread */
     private final Map<JMeterThread, Thread> allThreads;
 
-    /** flag to show that groups are still being created, i.e test plan is not complete */
-    private volatile boolean startingGroups;
-
     /** Flag to show whether test is running. Set to false to stop creating more threads. */
     private volatile boolean running = false;
 
+    /** Flag to show whether engine is active. Set to false at end of test. */
+    private volatile boolean active = false;
+
     /** Thread Groups run sequentially */
     private volatile boolean serialized = false;
 
@@ -137,27 +139,21 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
         if (engine == null) {
             return false;// e.g. not yet started
         }
-        JMeterThread thrd=null;
-        synchronized (engine.allThreads) { // Protect iterator
-            Iterator<JMeterThread> iter = engine.allThreads.keySet().iterator();
-            while(iter.hasNext()){
-                thrd = iter.next();
-                if (thrd.getThreadName().equals(threadName)){
-                    break; // Found matching thread
+        // ConcurrentHashMap does not need synch. here
+        for(Entry<JMeterThread, Thread> entry : engine.allThreads.entrySet()){
+            JMeterThread thrd = entry.getKey();
+            if (thrd.getThreadName().equals(threadName)){
+                thrd.stop();
+                thrd.interrupt();
+                if (now) {
+                    Thread t = entry.getValue();
+                    if (t != null) {
+                        t.interrupt();
+                    }
                 }
+                return true;
             }
         }
-        if (thrd != null) {
-            thrd.stop();
-            thrd.interrupt();
-            if (now) {
-                Thread t = engine.allThreads.get(thrd);
-                if (t != null) {
-                    t.interrupt();
-                }
-            }
-            return true;
-        }
         return false;
     }
 
@@ -175,87 +171,30 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
     }
 
     public void configure(HashTree testTree) {
+        active = true;
         test = testTree;
     }
 
-    // TODO: in Java1.5, perhaps we can use Thread.setUncaughtExceptionHandler() instead
-    private static class MyThreadGroup extends java.lang.ThreadGroup{
-        public MyThreadGroup(String s) {
-            super(s);
-          }
-
-          @Override
-        public void uncaughtException(Thread t, Throwable e) {
-            if (!(e instanceof ThreadDeath)) {
-                log.error("Uncaught exception: ", e);
-                System.err.println("Uncaught Exception " + e + ". See log file for details.");
-            }
-          }
-    }
-
     public void runTest() throws JMeterEngineException {
         if (host != null){
             long now=System.currentTimeMillis();
             System.out.println("Starting the test on host " + host + " @ "+new Date(now)+" ("+now+")");
         }
         try {
-            Thread runningThread = new Thread(new MyThreadGroup("JMeterThreadGroup"),this);
+            Thread runningThread = new Thread(this, "StandardJMeterEngine");
             runningThread.start();
-            if (JMeter.isNonGUI() && UDP_PORT > 1000){
-                Thread waiter = new Thread(){
-                    @Override
-                    public void run() {
-                        waitForSignals();
-                    }
-                };
-                waiter.setDaemon(true);
-                waiter.start();
-            }
         } catch (Exception err) {
             stopTest();
             StringWriter string = new StringWriter();
             PrintWriter writer = new PrintWriter(string);
             err.printStackTrace(writer);
-            throw new JMeterEngineException(string.toString());
+            throw new JMeterEngineException(err);
         }
     }
 
-    private void waitForSignals() {
-        byte[] buf = new byte[80];
-        DatagramSocket socket = null;
-        System.out.println("Waiting for possible shutdown message on port "+UDP_PORT);
-        try {
-            socket = new DatagramSocket(UDP_PORT);
-            DatagramPacket request = new DatagramPacket(buf, buf.length);
-            while(true) {
-                socket.receive(request);
-                InetAddress address = request.getAddress();
-                // Only accept commands from the local host
-                if (address.isLoopbackAddress()){
-                    String command = new String(request.getData(), request.getOffset(), request.getLength(),"ASCII");
-                    System.out.println("Command: "+command+" received from "+address);
-                    log.info("Command: "+command+" received from "+address);
-                    if (command.equals("StopTestNow")){
-                        stopTest();
-                    } else if (command.equals("Shutdown")) {
-                        askThreadsToStop();
-                    } else {
-                    }
-                }
-            }
-        } catch (Exception e) {
-            e.printStackTrace();
-        } finally {
-            if (socket != null) {
-                socket.close();
-            }
-        }
-
-    }
-
     private void removeThreadGroups(List<?> elements) {
         Iterator<?> iter = elements.iterator();
-        while (iter.hasNext()) {
+        while (iter.hasNext()) { // Can't use for loop here because we remove elements
             Object item = iter.next();
             if (item instanceof AbstractThreadGroup) {
                 iter.remove();
@@ -267,9 +206,7 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
 
     @SuppressWarnings("deprecation") // Deliberate use of deprecated method
     private void notifyTestListenersOfStart(SearchByClass<TestListener> testListeners) {
-        Iterator<TestListener> iter = testListeners.getSearchResults().iterator();
-        while (iter.hasNext()) {
-            TestListener tl = iter.next();
+        for (TestListener tl : testListeners.getSearchResults()) {
             if (tl instanceof TestBean) {
                 TestBeanHelper.prepare((TestElement) tl);
             }
@@ -283,9 +220,7 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
 
     private void notifyTestListenersOfEnd(SearchByClass<TestListener> testListeners) {
         log.info("Notifying test listeners of end of test");
-        Iterator<TestListener> iter = testListeners.getSearchResults().iterator();
-        while (iter.hasNext()) {
-            TestListener tl = iter.next();
+        for (TestListener tl : testListeners.getSearchResults()) {
             try {
                 if (host == null) {
                     tl.testEnded();
@@ -296,14 +231,16 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
                 log.warn("Error encountered during shutdown of "+tl.toString(),e);
             }
         }
-        log.info("Test has ended");
+        log.info("Test has ended on host "+host);
         if (host != null) {
             long now=System.currentTimeMillis();
-            System.out.println("Finished the test on host " + host + " @ "+new Date(now)+" ("+now+")");
+            System.out.println("Finished the test on host " + host + " @ "+new Date(now)+" ("+now+")"
+            +(exitAfterTest ? " - exit requested." : ""));
             if (exitAfterTest){
                 exit();
             }
         }
+        active=false;
     }
 
     private ListedHashTree cloneTree(ListedHashTree tree) {
@@ -322,15 +259,6 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
     public synchronized void threadFinished(JMeterThread thread) {
         log.info("Ending thread " + thread.getThreadName());
         allThreads.remove(thread);
-        if (!startingGroups && allThreads.size() == 0 ) {// All threads have exitted
-            new Thread(){// Ensure that the current sampler thread can exit cleanly
-                @Override
-                public void run() {
-                    log.info("Stopping test");
-                    notifyTestListenersOfEnd(testListenersSave);
-                }
-            }.start();
-        }
     }
 
     public synchronized void stopTest() {
@@ -352,28 +280,30 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
         public void run() {
             running = false;
             engine = null;
-            boolean stopped = false;
             if (now) {
                 tellThreadsToStop();
                 pause(10 * allThreads.size());
-                stopped = verifyThreadsStopped();
-                if (!stopped) {
+                boolean stopped = verifyThreadsStopped();
+                if (!stopped) {  // we totally failed to stop the test
                     if (JMeter.isNonGUI()) {
-                        exit();
+                        // TODO should we call test listeners? That might hang too ...
+                        log.fatalError(JMeterUtils.getResString("stopping_test_failed"));
+                        if (SYSTEM_EXIT_ON_STOP_FAIL) { // default is true
+                            log.fatalError("Exitting");
+                            System.out.println("Fatal error, could not stop test, exitting");
+                            System.exit(1);
+                        } else {
+                            System.out.println("Fatal error, could not stop test");                            
+                        }
                     } else {
                         JMeterUtils.reportErrorToUser(
                                 JMeterUtils.getResString("stopping_test_failed"),
                                 JMeterUtils.getResString("stopping_test_title"));
-                        // TODO - perhaps allow option to stop them?
                     }
                 } // else will be done by threadFinished()
             } else {
                 stopAllThreads();
             }
-            //  for TGs which run consecutively or when thread don't stop 
-            if (serialized || !stopped) {
-                notifyTestListenersOfEnd(testListenersSave);
-            }
         }
     }
 
@@ -421,13 +351,49 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
 
         List<?> testLevelElements = new LinkedList<Object>(test.list(test.getArray()[0]));
         removeThreadGroups(testLevelElements);
+
+        SearchByClass<SetupThreadGroup> setupSearcher = new SearchByClass<SetupThreadGroup>(SetupThreadGroup.class);
         SearchByClass<AbstractThreadGroup> searcher = new SearchByClass<AbstractThreadGroup>(AbstractThreadGroup.class);
+        SearchByClass<PostThreadGroup> postSearcher = new SearchByClass<PostThreadGroup>(PostThreadGroup.class);
+
+        test.traverse(setupSearcher);
         test.traverse(searcher);
+        test.traverse(postSearcher);
+        
         TestCompiler.initialize();
         // for each thread group, generate threads
         // hand each thread the sampler controller
         // and the listeners, and the timer
+        Iterator<SetupThreadGroup> setupIter = setupSearcher.getSearchResults().iterator();
         Iterator<AbstractThreadGroup> iter = searcher.getSearchResults().iterator();
+        Iterator<PostThreadGroup> postIter = postSearcher.getSearchResults().iterator();
+
+        ListenerNotifier notifier = new ListenerNotifier();
+
+        int groupCount = 0;
+        JMeterContextService.clearTotalThreads();
+        
+        if (setupIter.hasNext()) {
+            log.info("Starting setup thread groups");
+            while (running && setupIter.hasNext()) {//for each setup thread group
+                AbstractThreadGroup group = setupIter.next();
+                groupCount++;
+                log.info("Starting Setup Thread: " + groupCount);
+                String groupName = startThreadGroup(group, groupCount, setupSearcher, testLevelElements, notifier);
+                if (serialized && setupIter.hasNext()) {
+                    log.info("Waiting for setup thread group: "+groupName+" to finish before starting next setup group");
+                    while (running && allThreads.size() > 0) {
+                        pause(1000);
+                    }
+                }
+            }    
+            log.info("Waiting for all setup thread groups To Exit");
+            //wait for all Setup Threads To Exit
+            waitThreadsStopped();
+            log.info("All Setup Threads have ended");
+            groupCount=0;
+            JMeterContextService.clearTotalThreads();
+        }
 
         /*
          * Here's where the test really starts. Run a Full GC now: it's no harm
@@ -436,20 +402,67 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
          */
         System.gc();
 
-        ListenerNotifier notifier = new ListenerNotifier();
-
         JMeterContextService.getContext().setSamplingStarted(true);
-        int groupCount = 0;
-        JMeterContextService.clearTotalThreads();
-        startingGroups = true;
         while (running && iter.hasNext()) {// for each thread group
-            groupCount++;
             AbstractThreadGroup group = iter.next();
+            //ignore Setup and Post here.  We could have filtered the searcher. but then
+            //future Thread Group objects wouldn't execute.
+            if (group instanceof SetupThreadGroup)
+                continue;
+            if (group instanceof PostThreadGroup)
+                continue;
+            groupCount++;
+            String groupName=startThreadGroup(group, groupCount, searcher, testLevelElements, notifier);
+            if (serialized && iter.hasNext()) {
+                log.info("Waiting for thread group: "+groupName+" to finish before starting next group");
+                while (running && allThreads.size() > 0) {
+                    pause(1000);
+                }
+            }
+        } // end of thread groups
+        if (groupCount == 0){ // No TGs found
+            log.info("No enabled thread groups found");
+        } else {
+            if (running) {
+                log.info("All threads have been started");
+            } else {
+                log.info("Test stopped - no more threads will be started");
+            }
+        }
+
+        //wait for all Test Threads To Exit
+        waitThreadsStopped();
+
+        if (postIter.hasNext()){
+            groupCount = 0;
+            JMeterContextService.clearTotalThreads();
+            log.info("Starting post thread groups");
+            while (running && postIter.hasNext()) {//for each setup thread group
+                AbstractThreadGroup group = postIter.next();
+                groupCount++;
+                log.info("Starting Post Thread: " + groupCount);
+                String groupName = startThreadGroup(group, groupCount, postSearcher, testLevelElements, notifier);
+                if (serialized && postIter.hasNext()) {
+                    log.info("Waiting for post thread group: "+groupName+" to finish before starting next post group");
+                    while (running && allThreads.size() > 0) {
+                        pause(1000);
+                    }
+                }
+            }
+            waitThreadsStopped(); // wait for Post threads to stop
+        }
+
+        notifyTestListenersOfEnd(testListenersSave);
+    }
+
+    private String startThreadGroup(AbstractThreadGroup group, int groupCount, SearchByClass<?> searcher, List<?> testLevelElements, ListenerNotifier notifier)
+    {
             int numThreads = group.getNumThreads();
             JMeterContextService.addTotalThreads(numThreads);
             boolean onErrorStopTest = group.getOnErrorStopTest();
             boolean onErrorStopTestNow = group.getOnErrorStopTestNow();
             boolean onErrorStopThread = group.getOnErrorStopThread();
+            boolean onErrorStartNextLoop = group.getOnErrorStartNextLoop();
             String groupName = group.getName();
             log.info("Starting " + numThreads + " threads for group " + groupName + ".");
 
@@ -459,6 +472,8 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
                 log.info("Test will stop abruptly on error");
             } else if (onErrorStopThread) {
                 log.info("Thread will stop on error");
+            } else if (onErrorStartNextLoop) {
+                log.info("Thread will start next loop on error");
             } else {
                 log.info("Thread will continue on error");
             }
@@ -475,6 +490,7 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
                 jmeterThread.setOnErrorStopTest(onErrorStopTest);
                 jmeterThread.setOnErrorStopTestNow(onErrorStopTestNow);
                 jmeterThread.setOnErrorStopThread(onErrorStopThread);
+                jmeterThread.setOnErrorStartNextLoop(onErrorStartNextLoop);
 
                 group.scheduleThread(jmeterThread);
 
@@ -483,62 +499,59 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
                 allThreads.put(jmeterThread, newThread);
                 newThread.start();
             } // end of thread startup for this thread group
-            if (serialized && iter.hasNext()) {
-                log.info("Waiting for thread group: "+groupName+" to finish before starting next group");
-                while (running && allThreads.size() > 0) {
-                    pause(1000);
-                }
-            }
-        } // end of thread groups
-        startingGroups = false;
-        if (groupCount == 0){ // No TGs found
-            log.info("No enabled thread groups found");
-            notifyTestListenersOfEnd(testListenersSave);
-        } else {
-            if (running) {
-                log.info("All threads have been started");
-            } else {
-                log.info("Test stopped - no more threads will be started");
-            }
-        }
+            return groupName;
     }
 
     private boolean verifyThreadsStopped() {
         boolean stoppedAll = true;
-        List<Thread> threadsToCheck = new ArrayList<Thread>(allThreads.size());
-        synchronized (allThreads) { // Protect iterator
-            Iterator<JMeterThread> iter = allThreads.keySet().iterator();
-            while (iter.hasNext()) {
-                Thread t = allThreads.get(iter.next());
-                if (t != null) {
-                    threadsToCheck.add(t); // Do work later to reduce time in synch block.
-                }
-            }
-        }
-        for(int i=0; i < threadsToCheck.size(); i++) {
-            Thread t = threadsToCheck.get(i);
-            if (t.isAlive()) {
-                try {
-                    t.join(WAIT_TO_DIE);
-                } catch (InterruptedException e) {
-                }
+        // ConcurrentHashMap does not need synch. here
+        for (Thread t : allThreads.values()) {
+            if (t != null) {
                 if (t.isAlive()) {
-                    stoppedAll = false;
-                    log.warn("Thread won't exit: " + t.getName());
+                    try {
+                        t.join(WAIT_TO_DIE);
+                    } catch (InterruptedException e) {
+                    }
+                    if (t.isAlive()) {
+                        stoppedAll = false;
+                        log.warn("Thread won't exit: " + t.getName());
+                    }
                 }
             }
         }
         return stoppedAll;
     }
 
+    private void waitThreadsStopped() {
+        // ConcurrentHashMap does not need synch. here
+        for (Thread t : allThreads.values()) {
+            if (t != null) {
+                while (t.isAlive()) {
+                    try {
+                        t.join(WAIT_TO_DIE);
+                    } catch (InterruptedException e) {
+                    }
+                }
+            }
+        }
+    }
+
+    /**
+     * For each thread, invoke:
+     * <ul> 
+     * <li>{@link JMeterThread#stop()} - set stop flag</li>
+     * <li>{@link JMeterThread#interrupt()} - interrupt sampler</li>
+     * <li>{@link Thread#interrupt()} - interrupt JVM thread</li>
+     * </ul> 
+     */
     private void tellThreadsToStop() {
-        synchronized (allThreads) { // Protect iterator
-            Iterator<JMeterThread> iter = new HashSet<JMeterThread>(allThreads.keySet()).iterator();
-            while (iter.hasNext()) {
-                JMeterThread item = iter.next();
-                item.stop(); // set stop flag
-                item.interrupt(); // interrupt sampler if possible
-                Thread t = allThreads.get(item);
+        // ConcurrentHashMap does not need protecting
+        for (Entry<JMeterThread, Thread> entry : allThreads.entrySet()) {
+            JMeterThread item = entry.getKey();
+            item.stop(); // set stop flag
+            item.interrupt(); // interrupt sampler if possible
+            Thread t = entry.getValue();
+            if (t != null ) { // Bug 49734
                 t.interrupt(); // also interrupt JVM thread
             }
         }
@@ -550,30 +563,40 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
         }
     }
 
+    /**
+     * For each thread, invoke:
+     * <ul> 
+     * <li>{@link JMeterThread#stop()} - set stop flag</li>
+     * </ul> 
+     */
     private void stopAllThreads() {
-        synchronized (allThreads) {// Protect iterator
-            Iterator<JMeterThread> iter = new HashSet<JMeterThread>(allThreads.keySet()).iterator();
-            while (iter.hasNext()) {
-                JMeterThread item = iter.next();
-                item.stop(); // This is quick
-            }
+        // ConcurrentHashMap does not need synch. here
+        for (JMeterThread item : allThreads.keySet()) {
+            item.stop();
         }
     }
 
     // Remote exit
+    // Called by RemoteJMeterEngineImpl.rexit()
+    // and by notifyTestListenersOfEnd() iff exitAfterTest is true;
+    // in turn that is called by the run() method and the StopTest class
+    // also called
     public void exit() {
-        // Needs to be run in a separate thread to allow RMI call to return OK
-        Thread t = new Thread() {
-            @Override
-            public void run() {
-                // log.info("Pausing");
-                pause(1000); // Allow RMI to complete
-                log.info("Bye");
-                System.exit(0);
-            }
-        };
-        log.info("Starting Closedown");
-        t.start();
+        ClientJMeterEngine.tidyRMI(log); // This should be enough to allow server to exit.
+        if (REMOTE_SYSTEM_EXIT) { // default is false
+            log.warn("About to run System.exit(0) on "+host);
+            // Needs to be run in a separate thread to allow RMI call to return OK
+            Thread t = new Thread() {
+                @Override
+                public void run() {
+                    pause(1000); // Allow RMI to complete
+                    log.info("Bye from "+host);
+                    System.out.println("Bye from "+host);
+                    System.exit(0);
+                }
+            };
+            t.start();
+        }
     }
 
     private void pause(long ms){
@@ -587,4 +610,8 @@ public class StandardJMeterEngine implements JMeterEngine, JMeterThreadMonitor,
         log.info("Applying properties "+p);
         JMeterUtils.getJMeterProperties().putAll(p);
     }
+    
+    public boolean isActive() {
+        return active;
+    }
 }
