@@ -21,9 +21,12 @@ package org.apache.jmeter.exceptions;
 /**
  */
 public class IllegalUserActionException extends Exception {
+    private static final long serialVersionUID = 240L;
+
     /**
      * @deprecated - use IllegalUserActionException(String)
      */
+    @Deprecated // Needed for serialisation testing
     public IllegalUserActionException() {
         super();
     }
