@@ -22,7 +22,11 @@ import java.awt.Component;
 import java.awt.event.MouseEvent;
 import java.beans.Introspector;
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 
 import javax.swing.JOptionPane;
@@ -92,10 +96,10 @@ public final class GuiPackage implements LocaleChangeListener {
     private boolean currentNodeUpdated = false;
 
     /** The model for JMeter's test tree. */
-    private JMeterTreeModel treeModel;
+    private final JMeterTreeModel treeModel;
 
     /** The listener for JMeter's test tree. */
-    private JMeterTreeListener treeListener;
+    private final JMeterTreeListener treeListener;
 
     /** The main JMeter frame. */
     private MainFrame mainFrame;
@@ -104,14 +108,16 @@ public final class GuiPackage implements LocaleChangeListener {
      * Private constructor to permit instantiation only from within this class.
      * Use {@link #getInstance()} to retrieve a singleton instance.
      */
-    private GuiPackage() {
+    private GuiPackage(JMeterTreeModel treeModel, JMeterTreeListener treeListener) {
+        this.treeModel = treeModel;
+        this.treeListener = treeListener;
         JMeterUtils.addLocaleChangeListener(this);
     }
 
     /**
      * Retrieve the singleton GuiPackage instance.
      *
-     * @return the GuiPackage instance
+     * @return the GuiPackage instance (may be null, e.g in non-Gui mode)
      */
     public static GuiPackage getInstance() {
         return guiPack;
@@ -130,9 +136,7 @@ public final class GuiPackage implements LocaleChangeListener {
      */
     public static GuiPackage getInstance(JMeterTreeListener listener, JMeterTreeModel treeModel) {
         if (guiPack == null) {
-            guiPack = new GuiPackage();
-            guiPack.setTreeListener(listener);
-            guiPack.setTreeModel(treeModel);
+            guiPack = new GuiPackage(treeModel, listener);
         }
         return guiPack;
     }
@@ -391,6 +395,7 @@ public final class GuiPackage implements LocaleChangeListener {
                 JMeterGUIComponent comp = getGui(currentNode.getTestElement());
                 TestElement el = currentNode.getTestElement();
                 comp.modifyTestElement(el);
+                currentNode.nameChanged(); // Bug 50221 - ensure label is updated
             }
             // The current node is now updated
             currentNodeUpdated = true;
@@ -471,16 +476,6 @@ public final class GuiPackage implements LocaleChangeListener {
         return treeModel;
     }
 
-    /**
-     * Set the model for JMeter's test tree.
-     *
-     * @param newTreeModel
-     *            the new JMeter tree model
-     */
-    public void setTreeModel(JMeterTreeModel newTreeModel) {
-        treeModel = newTreeModel;
-    }
-
     /**
      * Get a ValueReplacer for the test tree.
      *
@@ -510,16 +505,6 @@ public final class GuiPackage implements LocaleChangeListener {
         return mainFrame;
     }
 
-    /**
-     * Set the listener for JMeter's test tree.
-     *
-     * @param newTreeListener
-     *            the new JMeter test tree listener
-     */
-    public void setTreeListener(JMeterTreeListener newTreeListener) {
-        treeListener = newTreeListener;
-    }
-
     /**
      * Get the listener for JMeter's test tree.
      *
@@ -598,6 +583,8 @@ public final class GuiPackage implements LocaleChangeListener {
 
     private String testPlanFile;
 
+    private final List<Stoppable> stoppables = Collections.synchronizedList(new ArrayList<Stoppable>());
+
     /**
      * Sets the filepath of the current test plan. It's shown in the main frame
      * title and used on saving.
@@ -665,4 +652,36 @@ public final class GuiPackage implements LocaleChangeListener {
         });
 
     }
+
+    /**
+     * Unregister stoppable
+     * @param stoppable Stoppable
+     */
+    public void unregister(Stoppable stoppable) {
+        for (Iterator<Stoppable> iterator = stoppables .iterator(); iterator.hasNext();) {
+            Stoppable stopable = iterator.next();
+            if(stopable == stoppable)
+            {
+                iterator.remove();
+            }
+        }
+    }
+    
+    /**
+     * Register process to stop on reload
+     * @param stoppable
+     */
+    public void register(Stoppable stoppable) {
+        stoppables.add(stoppable);
+    }
+
+    /**
+     * 
+     * @return List<IStoppable> Copy of IStoppable
+     */
+    public List<Stoppable> getStoppables() {
+        ArrayList<Stoppable> list = new ArrayList<Stoppable>();
+        list.addAll(stoppables);
+        return list;
+    }
 }
\ No newline at end of file
