@@ -91,6 +91,8 @@ public class Load implements Command {
     }
 
     static void loadProjectFile(ActionEvent e, File f, boolean merging) {
+        ActionRouter.getInstance().doActionNow(new ActionEvent(e.getSource(), e.getID(), ActionNames.STOP_THREAD));
+
         GuiPackage guiPackage = GuiPackage.getInstance();
         InputStream reader = null;
         try {
@@ -101,7 +103,7 @@ public class Load implements Command {
                     log.info("Merging file: " + f);
                 } else {
                     log.info("Loading file: " + f);
-                    FileServer.getFileServer().setBasedir(f.getAbsolutePath());
+                    FileServer.getFileServer().setBaseForScript(f);
                 }
                 reader = new FileInputStream(f);
                 HashTree tree = SaveService.loadTree(reader);
