@@ -60,6 +60,10 @@ public class Paste extends AbstractAction {
     @Override
     public void doAction(ActionEvent e) {
         JMeterTreeNode draggedNodes[] = Copy.getCopiedNodes();
+        if (draggedNodes == null) {
+            Toolkit.getDefaultToolkit().beep();
+            return;
+        }
         JMeterTreeListener treeListener = GuiPackage.getInstance().getTreeListener();
         JMeterTreeNode currentNode = treeListener.getCurrentNode();
         if (MenuFactory.canAddTo(currentNode, draggedNodes)) {
