@@ -20,6 +20,7 @@ package org.apache.jmeter.gui.util;
 
 import java.awt.Component;
 import java.io.IOException;
+import java.io.Serializable;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
@@ -66,6 +67,8 @@ public final class MenuFactory {
      *  and also for resource lookup in messages.properties
     */
     public static final String THREADS = "menu_threads"; //$NON-NLS-1$
+    
+    public static final String FRAGMENTS = "menu_fragments"; //$NON-NLS-1$
 
     public static final String TIMERS = "menu_timer"; //$NON-NLS-1$
 
@@ -93,7 +96,6 @@ public final class MenuFactory {
     // MENU_ADD_xxx - controls which items are in the ADD menu
     // MENU_PARENT_xxx - controls which items are in the Insert Parent menu
     private static final String[] MENU_ADD_CONTROLLER = new String[] {
-        MenuFactory.THREADS,
         MenuFactory.CONTROLLERS,
         MenuFactory.CONFIG_ELEMENTS,
         MenuFactory.TIMERS,
@@ -119,12 +121,13 @@ public final class MenuFactory {
     private static final String[] MENU_PARENT_SAMPLER = new String[] {
         MenuFactory.CONTROLLERS };
 
-    private static final List<MenuInfo> timers, controllers, samplers, threads,
-        configElements, assertions, listeners, nonTestElements,
+    private static final List<MenuInfo> timers, controllers, samplers, threads, 
+        fragments,configElements, assertions, listeners, nonTestElements,
         postProcessors, preProcessors;
 
     static {
         threads = new LinkedList<MenuInfo>();
+        fragments = new LinkedList<MenuInfo>();
         timers = new LinkedList<MenuInfo>();
         controllers = new LinkedList<MenuInfo>();
         samplers = new LinkedList<MenuInfo>();
@@ -135,6 +138,7 @@ public final class MenuFactory {
         preProcessors = new LinkedList<MenuInfo>();
         nonTestElements = new LinkedList<MenuInfo>();
         menuMap.put(THREADS, threads);
+        menuMap.put(FRAGMENTS, fragments);
         menuMap.put(TIMERS, timers);
         menuMap.put(ASSERTIONS, assertions);
         menuMap.put(CONFIG_ELEMENTS, configElements);
@@ -223,6 +227,8 @@ public final class MenuFactory {
         }
         menu.add(enabled);
         menu.add(disabled);
+        JMenuItem toggle = makeMenuItemRes("toggle", ActionNames.TOGGLE, KeyStrokes.TOGGLE);// $NON-NLS-1$
+        menu.add(toggle);
         addSeparator(menu);
         menu.add(makeMenuItemRes("help", ActionNames.HELP));// $NON-NLS-1$
     }
@@ -465,6 +471,9 @@ public final class MenuFactory {
                 if (categories.contains(THREADS)) {
                     threads.add(new MenuInfo(item, name));
                 }
+                if (categories.contains(FRAGMENTS)) {
+                    fragments.add(new MenuInfo(item, name));
+                }
                 if (categories.contains(TIMERS)) {
                     timers.add(new MenuInfo(item, name));
                 }
@@ -549,6 +558,14 @@ public final class MenuFactory {
             return false;
         }
         TestElement parent = parentNode.getTestElement();
+
+        // Force TestFragment to only be pastable under a Test Plan
+        if (foundClass(nodes, new Class[]{org.apache.jmeter.control.TestFragmentController.class})){
+            if (parent instanceof TestPlan)
+                return true;
+            return false;
+        }
+
         if (parent instanceof WorkBench) {// allow everything else
             return true;
         }
@@ -645,10 +662,11 @@ public final class MenuFactory {
     /**
      * Menu sort helper class
      */
-    private static class MenuInfoComparator implements Comparator<MenuInfo> {
-       public int compare(MenuInfo o1, MenuInfo o2) {
-          return o1.getLabel().compareTo(o2.getLabel());
-}
+    private static class MenuInfoComparator implements Comparator<MenuInfo>, Serializable {
+        private static final long serialVersionUID = 1L;
+        public int compare(MenuInfo o1, MenuInfo o2) {
+              return o1.getLabel().compareTo(o2.getLabel());
+        }
     }
 
     /**
