@@ -46,6 +46,7 @@ import org.apache.jmeter.samplers.SampleResult;
 import org.apache.jmeter.samplers.SampleSaveConfiguration;
 import org.apache.jmeter.save.CSVSaveService;
 import org.apache.jmeter.save.SaveService;
+import org.apache.jmeter.services.FileServer;
 import org.apache.jmeter.testelement.TestElement;
 import org.apache.jmeter.testelement.TestListener;
 import org.apache.jmeter.testelement.property.BooleanProperty;
@@ -375,6 +376,7 @@ public class ResultCollector extends AbstractListenerElement implements SampleLi
         if (filename == null || filename.length() == 0) {
             return null;
         }
+        filename = FileServer.resolveBaseRelativeName(filename);
         FileEntry fe = files.get(filename);
         PrintWriter writer = null;
         boolean trimmed = true;
