@@ -43,7 +43,7 @@ import org.apache.log.Logger;
  */
 public class SampleResult implements Serializable {
 
-    private static final long serialVersionUID = 233L;
+    private static final long serialVersionUID = 241L;
 
     // Needs to be accessible from Test code
     static final Logger log = LoggingManager.getLoggerForClass();
@@ -93,6 +93,15 @@ public class SampleResult implements Serializable {
     private static final SampleResult[] EMPTY_SR = new SampleResult[0];
 
     private static final AssertionResult[] EMPTY_AR = new AssertionResult[0];
+    
+    private static final boolean GETBYTES_BODY_REALSIZE = 
+        JMeterUtils.getPropDefault("sampleresult.getbytes.body_real_size", true); // $NON-NLS-1$
+
+    private static final boolean GETBYTES_HEADERS_SIZE = 
+        JMeterUtils.getPropDefault("sampleresult.getbytes.headers_size", true); // $NON-NLS-1$
+    
+    private static final boolean GETBYTES_NETWORK_SIZE = 
+        GETBYTES_HEADERS_SIZE && GETBYTES_BODY_REALSIZE ? true : false;
 
     private SampleSaveConfiguration saveConfig;
 
@@ -160,12 +169,6 @@ public class SampleResult implements Serializable {
     private String dataEncoding;// (is this really the character set?) e.g.
                                 // ISO-8895-1, UTF-8
 
-    // a reference time from the nanosecond clock
-    private static final long referenceTimeNsClock = sampleNsClockInMs();
-
-    // a reference time from the millisecond clock
-    private static final long referenceTimeMsClock = System.currentTimeMillis();
-
     /** elapsed time */
     private long time = 0;
 
@@ -187,6 +190,10 @@ public class SampleResult implements Serializable {
     private int sampleCount = 1;
 
     private int bytes = 0; // Allows override of sample size in case sampler does not want to store all the data
+    
+    private int headersSize = 0;
+    
+    private int bodySize = 0;
 
     /** Currently active threads in this thread group */
     private volatile int groupThreads = 0;
@@ -199,6 +206,10 @@ public class SampleResult implements Serializable {
     private static final boolean startTimeStamp
         = JMeterUtils.getPropDefault("sampleresult.timestamp.start", false);  // $NON-NLS-1$
 
+    // Allow read-only access from test code
+    static final boolean USENANOTIME
+    = JMeterUtils.getPropDefault("sampleresult.useNanoTime", true);  // $NON-NLS-1$
+
     static {
         if (startTimeStamp) {
             log.info("Note: Sample TimeStamps are START times");
@@ -206,10 +217,33 @@ public class SampleResult implements Serializable {
             log.info("Note: Sample TimeStamps are END times");
         }
         log.info("sampleresult.default.encoding is set to " + DEFAULT_ENCODING);
+        log.info("sampleresult.useNanoTime="+USENANOTIME);
+    }
+
+    // Allow read access by test code
+    transient final long nanoTimeOffset;
+
+    transient final boolean useNanoTime; // Allow test code to change the default
+    
+    private long initOffset(){
+        if (useNanoTime){
+            return System.currentTimeMillis() - sampleNsClockInMs();
+        } else {
+            return Long.MIN_VALUE;
+        }
     }
 
     public SampleResult() {
         time = 0;
+        useNanoTime = USENANOTIME;
+        nanoTimeOffset = initOffset();
+    }
+
+    // Allow test code to change the default useNanoTime setting
+    SampleResult(boolean nanoTime) {
+        time = 0;
+        useNanoTime = nanoTime;
+        nanoTimeOffset = initOffset();
     }
 
     /**
@@ -218,6 +252,8 @@ public class SampleResult implements Serializable {
      * @param res existing sample result
      */
     public SampleResult(SampleResult res) {
+        useNanoTime = USENANOTIME;
+        nanoTimeOffset = initOffset();
         allThreads = res.allThreads;//OK
         assertionResults = res.assertionResults;// TODO ??
         bytes = res.bytes;
@@ -270,7 +306,9 @@ public class SampleResult implements Serializable {
      *            create the sample finishing now, else starting now
      */
     protected SampleResult(long elapsed, boolean atend) {
-        long now = currentTimeInMs();
+        useNanoTime = USENANOTIME;
+        nanoTimeOffset = initOffset();
+        long now = currentTimeInMillis();
         if (atend) {
             setTimes(now - elapsed, now);
         } else {
@@ -304,7 +342,7 @@ public class SampleResult implements Serializable {
      *            desired elapsed time
      */
     public static SampleResult createTestSample(long elapsed) {
-        long now = currentTimeInMs();
+        long now = System.currentTimeMillis();
         return createTestSample(now, now + elapsed);
     }
 
@@ -319,6 +357,8 @@ public class SampleResult implements Serializable {
      * @param elapsed
      */
     public SampleResult(long stamp, long elapsed) {
+        useNanoTime = USENANOTIME;
+        nanoTimeOffset = initOffset();
         stampAndTime(stamp, elapsed);
     }
 
@@ -327,9 +367,14 @@ public class SampleResult implements Serializable {
     }
 
     // Helper method to get 1 ms resolution timing.
-    public static long currentTimeInMs() {
-        long elapsedInMs = sampleNsClockInMs() - referenceTimeNsClock;
-        return referenceTimeMsClock + elapsedInMs;
+    public long currentTimeInMillis() {
+        if (useNanoTime){
+            if (nanoTimeOffset == Long.MIN_VALUE){
+                throw new RuntimeException("Invalid call; nanoTimeOffset as not been set");
+            }
+            return sampleNsClockInMs() + nanoTimeOffset;            
+        }
+        return System.currentTimeMillis();
     }
 
     // Helper method to maintain timestamp relationships
@@ -493,7 +538,7 @@ public class SampleResult implements Serializable {
         subResult.setThreadName(tn); // TODO is this really necessary?
 
         // Extend the time to the end of the added sample
-        setEndTime(Math.max(getEndTime(), subResult.getEndTime()));
+        setEndTime(Math.max(getEndTime(), subResult.getEndTime() + nanoTimeOffset - subResult.nanoTimeOffset)); // Bug 51855
         // Include the byte count for the added sample
         setBytes(getBytes() + subResult.getBytes());
         addRawSubResult(subResult);
@@ -568,7 +613,7 @@ public class SampleResult implements Serializable {
             responseData = response.getBytes(getDataEncodingWithDefault());
         } catch (UnsupportedEncodingException e) {
             log.warn("Could not convert string, using default encoding. "+e.getLocalizedMessage());
-            responseData = response.getBytes();
+            responseData = response.getBytes(); // N.B. default charset is used deliberately here
         }
     }
 
@@ -587,7 +632,7 @@ public class SampleResult implements Serializable {
         } catch (UnsupportedEncodingException e) {
             log.warn("Could not convert string using '"+encodeUsing+
                     "', using default encoding: "+DEFAULT_CHARSET,e);
-            responseData = response.getBytes();
+            responseData = response.getBytes(); // N.B. default charset is used deliberately here
             setDataEncoding(DEFAULT_CHARSET);
         }
     }
@@ -890,7 +935,7 @@ public class SampleResult implements Serializable {
         }
     }
 
-    protected void setEndTime(long end) {
+    public void setEndTime(long end) {
         endTime = end;
         if (!startTimeStamp) {
             timeStamp = endTime;
@@ -923,7 +968,7 @@ public class SampleResult implements Serializable {
      */
     public void sampleStart() {
         if (startTime == 0) {
-            setStartTime(currentTimeInMs());
+            setStartTime(currentTimeInMillis());
         } else {
             log.error("sampleStart called twice", new Throwable("Invalid call sequence"));
         }
@@ -935,7 +980,7 @@ public class SampleResult implements Serializable {
      */
     public void sampleEnd() {
         if (endTime == 0) {
-            setEndTime(currentTimeInMs());
+            setEndTime(currentTimeInMillis());
         } else {
             log.error("sampleEnd called twice", new Throwable("Invalid call sequence"));
         }
@@ -949,7 +994,7 @@ public class SampleResult implements Serializable {
         if (pauseTime != 0) {
             log.error("samplePause called twice", new Throwable("Invalid call sequence"));
         }
-        pauseTime = currentTimeInMs();
+        pauseTime = currentTimeInMillis();
     }
 
     /**
@@ -960,7 +1005,7 @@ public class SampleResult implements Serializable {
         if (pauseTime == 0) {
             log.error("sampleResume without samplePause", new Throwable("Invalid call sequence"));
         }
-        idleTime += currentTimeInMs() - pauseTime;
+        idleTime += currentTimeInMillis() - pauseTime;
         pauseTime = 0;
     }
 
@@ -1005,6 +1050,8 @@ public class SampleResult implements Serializable {
      * Returns the count of errors.
      *
      * @return 0 - or 1 if the sample failed
+     * 
+     * TODO do we need allow for nested samples?
      */
     public int getErrorCount(){
         return success ? 0 : 1;
@@ -1048,6 +1095,14 @@ public class SampleResult implements Serializable {
      * @return byte count
      */
     public int getBytes() {
+        if (GETBYTES_NETWORK_SIZE) {
+            int tmpSum = this.getHeadersSize() + this.getBodySize();
+            return tmpSum == 0 ? bytes : tmpSum;
+        } else if (GETBYTES_HEADERS_SIZE) {
+            return this.getHeadersSize();
+        } else if (GETBYTES_BODY_REALSIZE) {
+            return this.getBodySize();
+        }
         return bytes == 0 ? responseData.length : bytes;
     }
 
@@ -1063,7 +1118,7 @@ public class SampleResult implements Serializable {
      *
      */
     public void latencyEnd() {
-        latency = currentTimeInMs() - startTime - idleTime;
+        latency = currentTimeInMillis() - startTime - idleTime;
     }
 
     /**
@@ -1158,4 +1213,37 @@ public class SampleResult implements Serializable {
     public void removeSubResults() {
         this.subResults = null;
     }
+    
+    /**
+     * Set the headers size in bytes
+     * 
+     * @param size
+     */
+    public void setHeadersSize(int size) {
+        this.headersSize = size;
+    }
+    
+    /**
+     * Get the headers size in bytes
+     * 
+     * @return the headers size
+     */
+    public int getHeadersSize() {
+        return headersSize;
+    }
+
+    /**
+     * @return the body size in bytes
+     */
+    public int getBodySize() {
+        return bodySize == 0 ? responseData.length : bodySize;
+    }
+
+    /**
+     * @param bodySize the body size to set
+     */
+    public void setBodySize(int bodySize) {
+        this.bodySize = bodySize;
+    }
+
 }
