@@ -40,6 +40,8 @@ public class SampleSenderFactory {
 
     private static final String MODE_STRIPPED_BATCH = "StrippedBatch"; // $NON-NLS-1$
 
+    private static final String MODE_ASYNCH = "Asynch"; // $NON-NLS-1$
+
     // Support original property name
     private static final boolean holdSamples = JMeterUtils.getPropDefault("hold_samples", false); // $NON-NLS-1$
 
@@ -70,6 +72,8 @@ public class SampleSenderFactory {
             return new DataStrippingSampleSender(new BatchSampleSender(listener));
         } else if(type.equalsIgnoreCase(MODE_STRIPPED)){
             return new DataStrippingSampleSender(listener);
+        } else if(type.equalsIgnoreCase(MODE_ASYNCH)){
+            return new AsynchSampleSender(listener);
         } else {
             // should be a user provided class name
             SampleSender s = null;
@@ -80,7 +84,7 @@ public class SampleSenderFactory {
             } catch (Exception e) {
                 // houston we have a problem !!
                 log.error("Unable to create a sample sender from class "+type);
-                throw new IllegalArgumentException(e.getMessage());
+                throw new IllegalArgumentException(e.getMessage(), e);
             }
 
             return s;
