@@ -55,12 +55,19 @@ public class StatisticalSampleSender implements SampleSender, Serializable {
 
     private final List<SampleEvent> sampleStore = new ArrayList<SampleEvent>();
 
+    //@GuardedBy("sampleStore") TODO perhaps use ConcurrentHashMap ?
     private final Map<String, StatisticalSampleResult> sampleTable = new HashMap<String, StatisticalSampleResult>();
 
     private int sampleCount; // maintain separate count of samples for speed
 
     private long batchSendTime = -1;
 
+    static {
+        log.info("Using statistical sampling for this run." + " Thresholds: num="
+                + NUM_SAMPLES_THRESHOLD + ", time=" + TIME_THRESHOLD_MS
+                + ". Key uses ThreadName: " + KEY_ON_THREADNAME);        
+    }
+
     /**
      * @deprecated only for use by test code
      */
@@ -70,7 +77,6 @@ public class StatisticalSampleSender implements SampleSender, Serializable {
         listener = null;
     }
 
-
     /**
      * Constructor
      *
@@ -78,9 +84,6 @@ public class StatisticalSampleSender implements SampleSender, Serializable {
      */
     StatisticalSampleSender(RemoteSampleListener listener) {
         this.listener = listener;
-        log.info("Using statistical sampling for this run." + " Thresholds: num="
-                + NUM_SAMPLES_THRESHOLD + ", time=" + TIME_THRESHOLD_MS
-                + ". Key uses ThreadName: " + KEY_ON_THREADNAME);
     }
 
     /**
