@@ -176,8 +176,15 @@ public class SaveService {
     }
 
     // Helper method to simplify alias creation from properties
-    private static void makeAlias(String alias, String clazz) {
-        aliasToClass.setProperty(alias,clazz);
+    private static void makeAlias(String aliasList, String clazz) {
+        String aliases[]=aliasList.split(","); // Can have multiple aliases for same target classname
+        String alias=aliases[0];
+        for (String a : aliases){
+            Object old = aliasToClass.setProperty(a,clazz);
+            if (old != null){
+                log.error("Duplicate class detected for "+alias+": "+clazz+" & "+old);                
+            }
+        }
         Object oldval=classToAlias.setProperty(clazz,alias);
         if (oldval != null) {
             log.error("Duplicate alias detected for "+clazz+": "+alias+" & "+oldval);
@@ -389,6 +396,24 @@ public class SaveService {
         return true; // SaveService.FILEVERSION.equals(SaveService.fileVersion);
     }
 
+    // Allow test code to check for spurious class references
+    static boolean checkClasses(){
+        boolean OK = true;
+        for (Object clazz : classToAlias.keySet()) {
+            String name = (String) clazz;
+            if (name.endsWith("JMSConfigGui")) { // deliberately kept
+                continue;
+            }
+            try {
+                Class.forName(name, false, SaveService.class.getClassLoader());
+            } catch (ClassNotFoundException e) {
+                log.error(e.toString());
+                OK = false;
+            }
+        }
+        return OK;
+    }
+
     static boolean checkVersions() {
         versionsOK = true;
         // Disable converter version checks as they are more of a nuisance than helpful
