@@ -36,7 +36,9 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Random;
 
+import org.apache.commons.collections.ArrayStack;
 import org.apache.jmeter.gui.JMeterFileFilter;
+import org.apache.jmeter.util.JMeterUtils;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.log.Logger;
 
@@ -54,33 +56,61 @@ import org.apache.log.Logger;
  * test plans to execute on unknown boxes that only have Java installed.
  */
 public class FileServer {
+
     private static final Logger log = LoggingManager.getLoggerForClass();
 
-    private static final String DEFAULT_BASE = System.getProperty("user.dir");
+    /**
+     * The default base used for resolving relative files, i.e.<br/>
+     * {@code System.getProperty("user.dir")}
+     */
+    private static final String DEFAULT_BASE = System.getProperty("user.dir");// $NON-NLS-1$
+
+    /** Default base prefix: {@value} */
+    private static final String BASE_PREFIX_DEFAULT = "~/"; // $NON-NLS-1$
+
+    private static final String BASE_PREFIX = 
+        JMeterUtils.getPropDefault("jmeter.save.saveservice.base_prefix", // $NON-NLS-1$
+                BASE_PREFIX_DEFAULT);
 
     //@GuardedBy("this")
     private File base;
 
-    //@GuardedBy("this")
+    //@GuardedBy("this") TODO perhaps use ConcurrentHashMap
     private final Map<String, FileEntry> files = new HashMap<String, FileEntry>();
 
     private static final FileServer server = new FileServer();
 
     private final Random random = new Random();
 
+    // Cannot be instantiated
     private FileServer() {
         base = new File(DEFAULT_BASE);
-        log.info("Default base="+DEFAULT_BASE);
+        log.info("Default base='"+DEFAULT_BASE+"'");
     }
 
+    /**
+     * @return the singleton instance of the server.
+     */
     public static FileServer getFileServer() {
         return server;
     }
 
-    public void resetBase() throws IOException{
-        setBasedir(DEFAULT_BASE);
+    /**
+     * Resets the current base to {@link #DEFAULT_BASE}.
+     */
+    public void resetBase() {
+        base = new File(DEFAULT_BASE);
+        log.info("Reset base to'"+base+"'");
     }
 
+    /**
+     * Sets the current base directory for relative file names from the provided path.
+     * If the path does not refer to an existing directory, then its parent is used.
+     * Normally the provided path is a file, so using the parent directory is appropriate.
+     * 
+     * @param basedir the path to set, or {@code null} if the GUI is being cleared
+     * @throws IOException if there is a problem resolving the file name
+     */
     public synchronized void setBasedir(String basedir) throws IOException {
         if (filesOpen()) {
             throw new IOException("Files are still open, cannot change base directory");
@@ -91,14 +121,87 @@ public class FileServer {
             if (!base.isDirectory()) {
                 base = base.getParentFile();
             }
-            log.info("Set new base="+base);
+            log.info("Set new base='"+base+"'");
         }
     }
 
+    /**
+     * Sets the current base directory for relative file names from the provided script file.
+     * The parameter is assumed to be the path to a JMX file, so the base directory is derived
+     * from its parent.
+     * 
+     * @param scriptPath the path of the script file; must be not be {@code null}
+     * @throws IllegalStateException if files are still open
+     * @throws IllegalArgumentException if scriptPath parameter is null
+     */
+    public synchronized void setBaseForScript(File scriptPath) {
+        if (scriptPath == null){
+            throw new IllegalArgumentException("scriptPath must not be null");
+        }
+        if (filesOpen()) {
+            throw new IllegalStateException("Files are still open, cannot change base directory");
+        }
+        files.clear();
+        // getParentFile() may not work on relative paths
+        base = scriptPath.getAbsoluteFile().getParentFile();
+        log.info("Set new base '"+base+"'");
+    }
+
+    /**
+     * Sets the current base directory for relative file names.
+     * 
+     * @param jmxBase the path of the script file base directory
+     * @throws IllegalStateException if files are still open
+     * @throws IllegalArgumentException if {@code basepath} is null
+     */
+    public synchronized void setBase(File jmxBase) {
+        if (jmxBase == null) {
+            throw new IllegalArgumentException("jmxBase must not be null");
+        }
+        if (filesOpen()) {
+            throw new IllegalStateException("Files are still open, cannot change base directory");
+        }
+        files.clear();
+        // getParentFile() may not work on relative paths
+        base = jmxBase;
+        log.info("Set new base='"+base+"'");
+    }
     public synchronized String getBaseDir() {
         return base.getAbsolutePath();
     }
 
+    public static String getDefaultBase(){
+        return DEFAULT_BASE;
+    }
+
+    /**
+     * Calculates the relative path from {@link #DEFAULT_BASE} to the current base,
+     * which must be the same as or a child of the default.
+     * 
+     * @return the relative path, or {@code "."} if the path cannot be determined
+     */
+    public synchronized File getBaseDirRelative() {
+        // Must first convert to absolute path names to ensure parents are available
+        File parent = new File(DEFAULT_BASE).getAbsoluteFile();
+        File f = base.getAbsoluteFile();
+        ArrayStack l = new ArrayStack();
+        while (f != null) { 
+            if (f.equals(parent)){
+                if (l.isEmpty()){
+                    break;
+                }
+                File rel = new File((String) l.pop());
+                while(!l.isEmpty()) {
+                    rel = new File(rel, (String) l.pop());
+                }
+                return rel;
+            }
+            l.push(f.getName());
+            f = f.getParentFile(); 
+        }
+        return new File(".");
+    }
+
     /**
      * Creates an association between a filename and a File inputOutputObject,
      * and stores it for later use - unless it is already stored.
@@ -181,15 +284,28 @@ public class FileServer {
       return readLine(filename, true);
     }
 
-   /**
-     * Get the next line of the named file.
+    /**
+     * Get the next line of the named file, first line is name to false
      *
      * @param filename
      * @param recycle - should file be restarted at EOF?
      * @return String containing the next line in the file (null if EOF reached and not recycle)
      * @throws IOException
      */
-    public synchronized String readLine(String filename, boolean recycle) throws IOException {
+    public String readLine(String filename, boolean recycle) throws IOException {
+        return readLine(filename, recycle, false);
+    }
+   /**
+     * Get the next line of the named file.
+     *
+     * @param filename
+     * @param recycle - should file be restarted at EOF?
+     * @param firstLineIsNames - 1st line is fields names
+     * @return String containing the next line in the file (null if EOF reached and not recycle)
+     * @throws IOException
+     */
+    public synchronized String readLine(String filename, boolean recycle, 
+            boolean firstLineIsNames) throws IOException {
         FileEntry fileEntry = files.get(filename);
         if (fileEntry != null) {
             if (fileEntry.inputOutputObject == null) {
@@ -203,6 +319,10 @@ public class FileServer {
                 reader.close();
                 reader = createBufferedReader(fileEntry, filename);
                 fileEntry.inputOutputObject = reader;
+                if (firstLineIsNames) {
+                    // read first line and forget
+                    reader.readLine();
+                }
                 line = reader.readLine();
             }
             if (log.isDebugEnabled()) { log.debug("Read:"+line); }
@@ -328,4 +448,21 @@ public class FileServer {
             charSetEncoding=e;
         }
     }
+    
+    /**
+     * Resolve a file name that may be relative to the base directory.
+     * If the name begins with the value of the JMeter property
+     * "jmeter.save.saveservice.base_prefix" 
+     * - default "~/" - then the name is assumed to be relative to the basename.
+     * 
+     * @param relativeName
+     * @return the updated file
+     */
+    public static String resolveBaseRelativeName(String relativeName) {
+        if (relativeName.startsWith(BASE_PREFIX)){
+            String newName = relativeName.substring(BASE_PREFIX.length());
+            return new File(getFileServer().getBaseDir(),newName).getAbsolutePath();
+        }
+        return relativeName;
+    }
 }
