@@ -57,7 +57,7 @@ import org.apache.log.Logger;
  * attribute, so that it can be used for further localization. TestBeanGUI, for
  * example, uses it to obtain the group's display names from properties <b><i>groupName</i>.displayName</b>.
  *
- * @version $Revision: 915405 $
+ * @version $Revision: 1044360 $
  */
 public abstract class BeanInfoSupport extends SimpleBeanInfo {
 
@@ -193,10 +193,10 @@ public abstract class BeanInfoSupport extends SimpleBeanInfo {
             log.debug("Getting property for: " + names[i]);
             PropertyDescriptor p = property(names[i]);
             p.setValue(GenericTestBeanCustomizer.GROUP, group);
-            p.setValue(GenericTestBeanCustomizer.ORDER, new Integer(i));
+            p.setValue(GenericTestBeanCustomizer.ORDER, Integer.valueOf(i));
         }
         numCreatedGroups++;
-        getBeanDescriptor().setValue(GenericTestBeanCustomizer.ORDER(group), new Integer(numCreatedGroups));
+        getBeanDescriptor().setValue(GenericTestBeanCustomizer.ORDER(group), Integer.valueOf(numCreatedGroups));
     }
 
     /** {@inheritDoc} */
