@@ -557,7 +557,7 @@ public class GenericTestBeanCustomizer extends JPanel implements SharedCustomize
         private Integer groupOrder(String group) {
             Integer order = (Integer) beanInfo.getBeanDescriptor().getValue(ORDER(group));
             if (order == null) {
-                order = new Integer(0);
+                order = Integer.valueOf(0);
             }
             return order;
         }
@@ -571,7 +571,7 @@ public class GenericTestBeanCustomizer extends JPanel implements SharedCustomize
         private Integer propertyOrder(PropertyDescriptor d) {
             Integer order = (Integer) d.getValue(ORDER);
             if (order == null) {
-                order = new Integer(0);
+                order = Integer.valueOf(0);
             }
             return order;
         }
