@@ -86,6 +86,15 @@ public abstract class AbstractTestElement implements TestElement, Serializable {
         propMap.clear();
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * Default implementation - does nothing
+     */
+    public void clearTestElementChildren(){
+        // NOOP
+    }
+
     /**
      * {@inheritDoc}
      */
