@@ -21,7 +21,7 @@ package org.apache.jmeter.testelement.property;
 import org.apache.jmeter.testelement.TestElement;
 
 /**
- * @version $Revision: 908219 $
+ * @version $Revision: 1044360 $
  */
 public class LongProperty extends NumberProperty {
     private static final long serialVersionUID = 240L;
@@ -86,7 +86,7 @@ public class LongProperty extends NumberProperty {
      * @see JMeterProperty#getObjectValue()
      */
     public Object getObjectValue() {
-        return new Long(value);
+        return Long.valueOf(value);
     }
 
     /**
