@@ -23,6 +23,7 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
+import java.util.concurrent.locks.ReentrantLock;
 
 import org.apache.jmeter.assertions.Assertion;
 import org.apache.jmeter.assertions.AssertionResult;
@@ -68,6 +69,12 @@ public class JMeterThread implements Runnable, Interruptible {
 
     public static final String LAST_SAMPLE_OK = "JMeterThread.last_sample_ok"; // $NON-NLS-1$
 
+    private static final String TRUE = Boolean.toString(true); // i.e. "true"
+
+    /** How often to check for shutdown during ramp-up, default 1000ms */
+    private static final int RAMPUP_GRANULARITY =
+            JMeterUtils.getPropDefault("jmeterthread.rampup.granularity", 1000); // $NON-NLS-1$
+
     private final Controller controller;
 
     private final HashTree testTree;
@@ -117,8 +124,12 @@ public class JMeterThread implements Runnable, Interruptible {
 
     private volatile boolean onErrorStopThread;
 
+    private volatile boolean onErrorStartNextLoop;
+
     private volatile Sampler currentSampler;
 
+    private final ReentrantLock interruptLock = new ReentrantLock(); // ensure that interrupt cannot overlap with shutdown
+
     public JMeterThread(HashTree test, JMeterThreadMonitor monitor, ListenerNotifier note) {
         this.monitor = monitor;
         threadVars = new JMeterVariables();
@@ -198,9 +209,23 @@ public class JMeterThread implements Runnable, Interruptible {
     private void startScheduler() {
         long delay = (startTime - System.currentTimeMillis());
         if (delay > 0) {
-            try {
-                Thread.sleep(delay);
-            } catch (Exception e) {
+            long start = System.currentTimeMillis();
+            long end = start + delay;
+            long now=0;
+            long pause = RAMPUP_GRANULARITY;
+            while(running && (now = System.currentTimeMillis()) < end) {
+                long togo = end - now;
+                if (togo < pause) {
+                    pause = togo;
+                }
+                try {
+                    Thread.sleep(pause); // delay between checks
+                } catch (InterruptedException e) {
+                    if (running) { // Don't bother reporting stop test interruptions
+                        log.warn("startScheduler delay for "+threadName+" was interrupted. Waited "+(now - start)+" milli-seconds out of "+delay);
+                    }
+                    break;
+                }
             }
         }
     }
@@ -235,12 +260,43 @@ public class JMeterThread implements Runnable, Interruptible {
     public void run() {
         // threadContext is not thread-safe, so keep within thread
         JMeterContext threadContext = JMeterContextService.getContext();
+        LoopIterationListener iterationListener=null;
+
         try {
-            initRun(threadContext);
+            iterationListener = initRun(threadContext);
             while (running) {
-                Sampler sam;
-                while (running && (sam = controller.next()) != null) {
-                    process_sampler(sam, null, threadContext);
+                Sampler firstSampler = controller.next();
+                Sampler sam = firstSampler;
+                while (running && sam != null) {
+                    if (onErrorStartNextLoop) { // if the threadGroup option is to start next loop when it fails
+                        // special case: TC as parent and last subsampler is not Ok
+                        if (!TRUE.equals(threadContext.getVariables().get(LAST_SAMPLE_OK)) && sam instanceof TransactionSampler) {
+                            TransactionSampler ts = (TransactionSampler) sam;
+                            while (!ts.isTransactionDone()) { // go to last subsampler
+                                sam = controller.next();
+                                ts = (TransactionSampler) sam;
+                            }
+                            // process now for close transaction (not sampling)
+                            process_sampler(sam, null, threadContext);
+                        }
+                        
+                        // normal case: process sampler and get next
+                        if (TRUE.equals(threadContext.getVariables().get(LAST_SAMPLE_OK))) {
+                            process_sampler(sam, null, threadContext);
+                            sam = controller.next();
+                        } else {
+                            // Last not ok. start get the begining of the tree
+                            sam = controller.next(); // need perfom a until loop for special case (tc as parent)
+                            while (sam != null && !sam.equals(firstSampler)) { // while the thread is NOT on the begining of the tree
+                                sam = controller.next();
+                            }
+                            // At this point: begining tree, thus Last must Ok
+                            threadContext.getVariables().put(LAST_SAMPLE_OK, TRUE);
+                        }
+                    } else {
+                        process_sampler(sam, null, threadContext);
+                        sam = controller.next();
+                    }
                 }
                 if (controller.isDone()) {
                     running = false;
@@ -264,11 +320,18 @@ public class JMeterThread implements Runnable, Interruptible {
         } catch (Error e) {// Make sure errors are output to the log file
             log.error("Test failed!", e);
         } finally {
-            threadContext.clear();
-            log.info("Thread finished: " + threadName);
-            threadFinished();
-            monitor.threadFinished(this); // Tell the engine we are done
-            JMeterContextService.removeContext(); // Remove the ThreadLocal entry
+            currentSampler = null; // prevent any further interrupts
+            try {
+                interruptLock.lock();  // make sure current interrupt is finished, prevent another starting yet
+                threadContext.clear();
+                log.info("Thread finished: " + threadName);
+                threadFinished(iterationListener);
+                monitor.threadFinished(this); // Tell the engine we are done
+                JMeterContextService.removeContext(); // Remove the ThreadLocal entry
+            }
+            finally {
+                interruptLock.unlock(); // Allow any pending interrupt to complete (OK because currentSampler == null)
+            }
         }
     }
 
@@ -437,12 +500,13 @@ public class JMeterThread implements Runnable, Interruptible {
 
     /**
      * @param threadContext
+     * @return 
      *
      */
-    private void initRun(JMeterContext threadContext) {
+    private IterationListener initRun(JMeterContext threadContext) {
         threadContext.setVariables(threadVars);
         threadContext.setThreadNum(getThreadNum());
-        threadContext.getVariables().put(LAST_SAMPLE_OK, "true");
+        threadContext.getVariables().put(LAST_SAMPLE_OK, TRUE);
         threadContext.setThread(this);
         threadContext.setThreadGroup(threadGroup);
         threadContext.setEngine(engine);
@@ -463,11 +527,13 @@ public class JMeterThread implements Runnable, Interruptible {
             threadContext.setSamplingStarted(true);
         }
         controller.initialize();
-        controller.addIterationListener(new IterationListener());
+        IterationListener iterationListener = new IterationListener();
+        controller.addIterationListener(iterationListener);
         if (!startEarlier) {
             threadContext.setSamplingStarted(true);
         }
         threadStarted();
+        return iterationListener;
     }
 
     private void threadStarted() {
@@ -481,7 +547,7 @@ public class JMeterThread implements Runnable, Interruptible {
         testTree.traverse(startup); // call ThreadListener.threadStarted()
     }
 
-    private void threadFinished() {
+    private void threadFinished(LoopIterationListener iterationListener) {
         ThreadListenerTraverser shut = new ThreadListenerTraverser(false);
         testTree.traverse(shut); // call ThreadListener.threadFinished()
         JMeterContextService.decrNumberOfThreads();
@@ -490,6 +556,9 @@ public class JMeterThread implements Runnable, Interruptible {
         if (gp != null){// check there is a GUI
             gp.getMainFrame().updateCounts();
         }
+        if (iterationListener != null) { // probably not possible, but check anyway
+            controller.removeIterationListener(iterationListener);
+        }
     }
 
     private static class ThreadListenerTraverser implements HashTreeTraverser {
@@ -528,20 +597,25 @@ public class JMeterThread implements Runnable, Interruptible {
 
     /** {@inheritDoc} */
     public boolean interrupt(){
-        Sampler samp = currentSampler; // fetch once
-        if (samp instanceof Interruptible){
-            log.warn("Interrupting: " + threadName + " sampler: " +samp.getName());
-            try {
-                boolean found = ((Interruptible)samp).interrupt();
-                if (!found) {
-                    log.warn("No operation pending");
+        try {
+            interruptLock.lock();
+            Sampler samp = currentSampler; // fetch once; must be done under lock
+            if (samp instanceof Interruptible){ // (also protects against null)
+                log.warn("Interrupting: " + threadName + " sampler: " +samp.getName());
+                try {
+                    boolean found = ((Interruptible)samp).interrupt();
+                    if (!found) {
+                        log.warn("No operation pending");
+                    }
+                    return found;
+                } catch (Exception e) {
+                    log.warn("Caught Exception interrupting sampler: "+e.toString());
                 }
-                return found;
-            } catch (Exception e) {
-                log.warn("Caught Exception interrupting sampler: "+e.toString());
+            } else if (samp != null){
+                log.warn("Sampler is not Interruptible: "+samp.getName());
             }
-        } else if (samp != null){
-            log.warn("Sampler is not Interruptible: "+samp.getName());
+        } finally {
+            interruptLock.unlock();            
         }
         return false;
     }
@@ -675,7 +749,7 @@ public class JMeterThread implements Runnable, Interruptible {
         }
     }
 
-    private void notifyTestListeners() {
+    void notifyTestListeners() {
         threadVars.incIteration();
         Iterator<TestListener> iter = testListeners.iterator();
         while (iter.hasNext()) {
@@ -705,11 +779,22 @@ public class JMeterThread implements Runnable, Interruptible {
     private void rampUpDelay() {
         if (initialDelay > 0) {
             long start = System.currentTimeMillis();
-            try {
-                Thread.sleep(initialDelay);
-            } catch (InterruptedException e) {
-                long actual = System.currentTimeMillis() - start;
-                log.warn("RampUp delay for "+threadName+" was interrupted. Waited "+actual+" milli-seconds out of "+initialDelay);
+            long end = start + initialDelay;
+            long now=0;
+            long pause = RAMPUP_GRANULARITY;
+            while(running && (now = System.currentTimeMillis()) < end) {
+                long togo = end - now;
+                if (togo < pause) {
+                    pause = togo;
+                }
+                try {
+                    Thread.sleep(pause); // delay between checks
+                } catch (InterruptedException e) {
+                    if (running) { // Don't bother reporting stop test interruptions
+                        log.warn("RampUp delay for "+threadName+" was interrupted. Waited "+(now - start)+" milli-seconds out of "+initialDelay);
+                    }
+                    break;
+                }
             }
         }
     }
@@ -779,8 +864,18 @@ public class JMeterThread implements Runnable, Interruptible {
         onErrorStopThread = b;
     }
 
+    /**
+     * Should Thread start next loop on Sampler error?
+     *
+     * @param b -
+     *            true or false
+     */
+    public void setOnErrorStartNextLoop(boolean b) {
+        onErrorStartNextLoop = b;
+    }
+
     public void setThreadGroup(AbstractThreadGroup group) {
         this.threadGroup = group;
     }
 
-}
\ No newline at end of file
+}
