@@ -19,64 +19,48 @@
 package org.apache.jmeter.threads;
 
 import java.util.Iterator;
-import java.util.LinkedList;
 import java.util.List;
 
 import org.apache.jmeter.assertions.Assertion;
 import org.apache.jmeter.config.ConfigTestElement;
+import org.apache.jmeter.control.Controller;
 import org.apache.jmeter.processor.PostProcessor;
 import org.apache.jmeter.processor.PreProcessor;
 import org.apache.jmeter.samplers.SampleListener;
 import org.apache.jmeter.samplers.Sampler;
 import org.apache.jmeter.testelement.TestElement;
 import org.apache.jmeter.timers.Timer;
-import org.apache.jorphan.logging.LoggingManager;
-import org.apache.log.Logger;
 
 /**
  * Packages methods related to sample handling.
  */
 public class SamplePackage {
-    private static final Logger log = LoggingManager.getLoggerForClass();
 
-    private List<SampleListener> sampleListeners = new LinkedList<SampleListener>();
+    private final List<SampleListener> sampleListeners;
 
-    private List<Timer> timers = new LinkedList<Timer>();
+    private final List<Timer> timers;
 
-    private List<Assertion> assertions = new LinkedList<Assertion>();
+    private final List<Assertion> assertions;
 
-    private List<PostProcessor> postProcessors = new LinkedList<PostProcessor>();
+    private final List<PostProcessor> postProcessors;
 
-    private List<PreProcessor> preProcessors = new LinkedList<PreProcessor>();
+    private final List<PreProcessor> preProcessors;
 
-    // TODO the following lists don't seem to be used at present
-    private List<?> responseModifiers;
+    private final List<ConfigTestElement> configs;
 
-    private List<ConfigTestElement> configs;
-
-    private List<?> modifiers;
-
-    private List<TestElement> controllers;
+    private final List<Controller> controllers;
 
     private Sampler sampler;
 
-    public SamplePackage() {
-    }
-
     public SamplePackage(
             List<ConfigTestElement> configs,
-            List<?> modifiers,
-            List<?> responseModifiers, 
             List<SampleListener> listeners,
             List<Timer> timers,
             List<Assertion> assertions, 
             List<PostProcessor> postProcessors, 
             List<PreProcessor> preProcessors,
-            List<TestElement> controllers) {
-        log.debug("configs is null: " + (configs == null));
+            List<Controller> controllers) {
         this.configs = configs;
-        this.modifiers = modifiers;
-        this.responseModifiers = responseModifiers;
         this.sampleListeners = listeners;
         this.timers = timers;
         this.assertions = assertions;
@@ -87,30 +71,26 @@ public class SamplePackage {
 
     public void setRunningVersion(boolean running) {
         setRunningVersion(configs, running);
-        setRunningVersion(modifiers, running);
         setRunningVersion(sampleListeners, running);
         setRunningVersion(assertions, running);
         setRunningVersion(timers, running);
-        setRunningVersion(responseModifiers, running);
         setRunningVersion(postProcessors, running);
         setRunningVersion(preProcessors, running);
         setRunningVersion(controllers, running);
         sampler.setRunningVersion(running);
     }
 
-    // TODO: Unfortunately, few of the test element interfaces implement TestElement
-    // (though all the implementation classes do)
-    @SuppressWarnings("unchecked")
     private void setRunningVersion(List<?> list, boolean running) {
-        Iterator<TestElement> iter = (Iterator<TestElement>) list.iterator();
+        @SuppressWarnings("unchecked") // All implementations extend TestElement
+        Iterator<? extends TestElement> iter = (Iterator<? extends TestElement>) list.iterator();
         while (iter.hasNext()) {
             iter.next().setRunningVersion(running);
         }
     }
 
-    @SuppressWarnings("unchecked")
     private void recoverRunningVersion(List<?> list) {
-        Iterator<TestElement> iter = (Iterator<TestElement>) list.iterator();
+        @SuppressWarnings("unchecked") // All implementations extend TestElement
+        Iterator<? extends TestElement> iter = (Iterator<? extends TestElement>) list.iterator();
         while (iter.hasNext()) {
             iter.next().recoverRunningVersion();
         }
@@ -118,11 +98,9 @@ public class SamplePackage {
 
     public void recoverRunningVersion() {
         recoverRunningVersion(configs);
-        recoverRunningVersion(modifiers);
         recoverRunningVersion(sampleListeners);
         recoverRunningVersion(assertions);
         recoverRunningVersion(timers);
-        recoverRunningVersion(responseModifiers);
         recoverRunningVersion(postProcessors);
         recoverRunningVersion(preProcessors);
         recoverRunningVersion(controllers);
@@ -180,16 +158,6 @@ public class SamplePackage {
         return preProcessors;
     }
 
-    /**
-     * Sets the preProcessors.
-     *
-     * @param preProcessors
-     *            the preProcessors to set
-     */
-    public void setPreProcessors(List<PreProcessor> preProcessors) {
-        this.preProcessors = preProcessors;
-    }
-
     /**
      * Returns the configs.
      *
@@ -199,87 +167,4 @@ public class SamplePackage {
         return configs;
     }
 
-    /**
-     * Returns the modifiers.
-     */
-    public List<?> getModifiers() {
-        return modifiers;
-    }
-
-    /**
-     * Returns the responseModifiers.
-     */
-    public List<?> getResponseModifiers() {
-        return responseModifiers;
-    }
-
-    /**
-     * Sets the assertions.
-     *
-     * @param assertions
-     *            the assertions to set
-     */
-    public void setAssertions(List<Assertion> assertions) {
-        this.assertions = assertions;
-    }
-
-    /**
-     * Sets the configs.
-     *
-     * @param configs
-     *            the configs to set
-     */
-    public void setConfigs(List<ConfigTestElement> configs) {
-        this.configs = configs;
-    }
-
-    /**
-     * Sets the modifiers.
-     *
-     * @param modifiers
-     *            the modifiers to set
-     */
-    public void setModifiers(List<?> modifiers) {
-        this.modifiers = modifiers;
-    }
-
-    /**
-     * Sets the postProcessors.
-     *
-     * @param postProcessors
-     *            the postProcessors to set
-     */
-    public void setPostProcessors(List<PostProcessor> postProcessors) {
-        this.postProcessors = postProcessors;
-    }
-
-    /**
-     * Sets the responseModifiers.
-     *
-     * @param responseModifiers
-     *            the responseModifiers to set
-     */
-    public void setResponseModifiers(List<?> responseModifiers) {
-        this.responseModifiers = responseModifiers;
-    }
-
-    /**
-     * Sets the sampleListeners.
-     *
-     * @param sampleListeners
-     *            the sampleListeners to set
-     */
-    public void setSampleListeners(List<SampleListener> sampleListeners) {
-        this.sampleListeners = sampleListeners;
-    }
-
-    /**
-     * Sets the timers.
-     *
-     * @param timers
-     *            the timers to set
-     */
-    public void setTimers(List<Timer> timers) {
-        this.timers = timers;
-    }
 }
\ No newline at end of file
