@@ -151,9 +151,7 @@ public class TestCompiler implements HashTreeTraverser {
 
     private void saveSamplerConfigs(Sampler sam) {
         List<ConfigTestElement> configs = new LinkedList<ConfigTestElement>();
-        List<?> modifiers = new LinkedList<Object>();
-        List<TestElement> controllers = new LinkedList<TestElement>();
-        List<?> responseModifiers = new LinkedList<Object>();
+        List<Controller> controllers = new LinkedList<Controller>();
         List<SampleListener> listeners = new LinkedList<SampleListener>();
         List<Timer> timers = new LinkedList<Timer>();
         List<Assertion> assertions = new LinkedList<Assertion>();
@@ -161,11 +159,11 @@ public class TestCompiler implements HashTreeTraverser {
         LinkedList<PreProcessor> pres = new LinkedList<PreProcessor>();
         for (int i = stack.size(); i > 0; i--) {
             addDirectParentControllers(controllers, stack.get(i - 1));
-            Iterator<TestElement> iter = testTree.list(stack.subList(0, i)).iterator();
+            Iterator<?> iter = testTree.list(stack.subList(0, i)).iterator();
             List<PreProcessor>  tempPre = new LinkedList<PreProcessor> ();
             List<PostProcessor> tempPost = new LinkedList<PostProcessor>();
             while (iter.hasNext()) {
-                TestElement item = iter.next();
+                Object item = iter.next();
                 if ((item instanceof ConfigTestElement)) {
                     configs.add((ConfigTestElement) item);
                 }
@@ -189,7 +187,7 @@ public class TestCompiler implements HashTreeTraverser {
             posts.addAll(0, tempPost);
         }
 
-        SamplePackage pack = new SamplePackage(configs, modifiers, responseModifiers, listeners, timers, assertions,
+        SamplePackage pack = new SamplePackage(configs, listeners, timers, assertions,
                 posts, pres, controllers);
         pack.setSampler(sam);
         pack.setRunningVersion(true);
@@ -198,9 +196,7 @@ public class TestCompiler implements HashTreeTraverser {
 
     private void saveTransactionControllerConfigs(TransactionController tc) {
         List<ConfigTestElement> configs = new LinkedList<ConfigTestElement>();
-        List<?> modifiers = new LinkedList<Object>();
-        List<TestElement> controllers = new LinkedList<TestElement>();
-        List<?> responseModifiers = new LinkedList<Object>();
+        List<Controller> controllers = new LinkedList<Controller>();
         List<SampleListener> listeners = new LinkedList<SampleListener>();
         List<Timer> timers = new LinkedList<Timer>();
         List<Assertion> assertions = new LinkedList<Assertion>();
@@ -208,9 +204,9 @@ public class TestCompiler implements HashTreeTraverser {
         LinkedList<PreProcessor> pres = new LinkedList<PreProcessor>();
         for (int i = stack.size(); i > 0; i--) {
             addDirectParentControllers(controllers, stack.get(i - 1));
-            Iterator<TestElement> iter = testTree.list(stack.subList(0, i)).iterator();
+            Iterator<?> iter = testTree.list(stack.subList(0, i)).iterator();
             while (iter.hasNext()) {
-                TestElement item = iter.next();
+                Object item = iter.next();
                 if (item instanceof SampleListener) {
                     listeners.add((SampleListener) item);
                 }
@@ -220,7 +216,7 @@ public class TestCompiler implements HashTreeTraverser {
             }
         }
 
-        SamplePackage pack = new SamplePackage(configs, modifiers, responseModifiers, listeners, timers, assertions,
+        SamplePackage pack = new SamplePackage(configs, listeners, timers, assertions,
                 posts, pres, controllers);
         pack.setSampler(new TransactionSampler(tc, tc.getName()));
         pack.setRunningVersion(true);
@@ -231,16 +227,17 @@ public class TestCompiler implements HashTreeTraverser {
      * @param controllers
      * @param i
      */
-    private void addDirectParentControllers(List<TestElement> controllers, TestElement maybeController) {
+    private void addDirectParentControllers(List<Controller> controllers, TestElement maybeController) {
         if (maybeController instanceof Controller) {
             log.debug("adding controller: " + maybeController + " to sampler config");
-            controllers.add(maybeController);
+            controllers.add((Controller) maybeController);
         }
     }
 
     private static class ObjectPair
     {
-        private TestElement child, parent;
+        private final TestElement child;
+        private final TestElement parent;
 
         public ObjectPair(TestElement one, TestElement two) {
             this.child = one;
@@ -270,6 +267,7 @@ public class TestCompiler implements HashTreeTraverser {
     }
 
     private void configureWithConfigElements(Sampler sam, List<ConfigTestElement> configs) {
+        sam.clearTestElementChildren();
         Iterator<ConfigTestElement> iter = configs.iterator();
         while (iter.hasNext()) {
             ConfigTestElement config = iter.next();
