@@ -124,17 +124,14 @@ public class SamplingStatCalculator {
      * calculates the average page size, which means divide the bytes by number
      * of samples.
      *
-     * @return average page size in bytes
+     * @return average page size in bytes (0 if sample count is zero)
      */
     public double getAvgPageBytes() {
-        double rate = 0;
-        if (this.getElapsed() > 0 && calculator.getTotalBytes() > 0) {
-            rate = calculator.getTotalBytes() / ((double) this.getElapsed() / 1000);
+        long count = calculator.getCount();
+        if (count == 0) {
+            return 0;
         }
-        if (rate < 0) {
-            rate = 0;
-        }
-        return rate;
+        return calculator.getTotalBytes() / (double) count;
     }
 
     public String getLabel() {
@@ -173,7 +170,7 @@ public class SamplingStatCalculator {
             rbool = res.isSuccessful();
         }
 
-        int count = calculator.getCount();
+        long count = calculator.getCount();
         Sample s =
             new Sample( null, rtime, cmean, cstdv, cmedian, cpercent, throughput, eCount, rbool, count, endTime );
         currentSample = s;
@@ -255,7 +252,7 @@ public class SamplingStatCalculator {
         return calculator.getPercentPoint(percent);
     }
 
-    public int getCount() {
+    public long getCount() {
         return calculator.getCount();
     }
 
@@ -268,7 +265,7 @@ public class SamplingStatCalculator {
     }
 
     public Number getMeanAsNumber() {
-        return new Long((long) calculator.getMean());
+        return Long.valueOf((long) calculator.getMean());
     }
 
     public Number getMedian() {
@@ -277,7 +274,7 @@ public class SamplingStatCalculator {
 
     public Number getMin() {
         if (calculator.getMin().longValue() < 0) {
-            return new Long(0);
+            return Long.valueOf(0);
         }
         return calculator.getMin();
     }
