@@ -34,7 +34,6 @@ import org.apache.avalon.framework.configuration.DefaultConfigurationBuilder;
 import org.apache.avalon.framework.context.Context;
 import org.apache.avalon.framework.context.ContextException;
 import org.apache.avalon.framework.context.DefaultContext;
-import org.apache.jorphan.util.ClassContext;
 import org.apache.log.Hierarchy;
 import org.apache.log.LogTarget;
 import org.apache.log.Logger;
@@ -62,7 +61,9 @@ public final class LoggingManager {
     private static final String PATTERN_THREAD_SUFFIX = "%{time:yyyy/MM/dd HH:mm:ss} %5.5{priority} "  //$NON_NLS-1$
             + "%{category}[%{thread}]: %{message} %{throwable}";  //$NON_NLS-1$
 
-    private static PatternFormatter format = null;
+    // Needs to be volatile as may be referenced from multiple threads
+    // TODO see if this can be made final somehow
+    private static volatile PatternFormatter format = null;
 
     /** Used to hold the default logging target. */
     //@GuardedBy("this")
@@ -234,18 +235,6 @@ public final class LoggingManager {
 
     private static final String PACKAGE_PREFIX = "org.apache."; //$NON_NLS-1$
 
-    /*
-     * Stack contains the follow when the context is obtained:
-     * 0 - getCallerClassNameAt()
-     * 1 - this method
-     * 2 - getLoggerForClass()
-     *
-     */
-    private static String getCallerClassName() {
-        String name = ClassContext.getCallerClassNameAt(3);
-        return name;
-    }
-
     /**
      * Removes the standard prefix, i.e. "org.apache.".
      * 
@@ -265,7 +254,7 @@ public final class LoggingManager {
      * @return Logger
      */
     public static Logger getLoggerForClass() {
-        String className = getCallerClassName();
+        String className = (new Exception()).getStackTrace()[1].getClassName();
         return Hierarchy.getDefaultHierarchy().getLoggerFor(removePrefix(className));
     }
 
