@@ -28,6 +28,7 @@ import javax.swing.BoxLayout;
 import javax.swing.JCheckBox;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
+import javax.swing.JPasswordField;
 import javax.swing.JTextField;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
@@ -38,8 +39,8 @@ import org.apache.jmeter.gui.util.HorizontalPanel;
 import org.apache.jmeter.gui.util.VerticalPanel;
 import org.apache.jmeter.protocol.http.gui.HTTPArgumentsPanel;
 import org.apache.jmeter.protocol.http.sampler.HTTPSamplerBase;
+import org.apache.jmeter.protocol.http.sampler.HTTPSamplerFactory;
 import org.apache.jmeter.protocol.http.util.HTTPArgument;
-import org.apache.jmeter.testelement.AbstractTestElement;
 import org.apache.jmeter.testelement.TestElement;
 import org.apache.jmeter.testelement.property.BooleanProperty;
 import org.apache.jmeter.testelement.property.TestElementProperty;
@@ -54,6 +55,7 @@ import org.apache.jorphan.gui.JLabeledChoice;
  * - redirects & keepalive
  */
 public class UrlConfigGui extends JPanel implements ChangeListener {
+
     private static final long serialVersionUID = 240L;
 
     private HTTPArgumentsPanel argsPanel;
@@ -68,7 +70,7 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
 
     private JTextField proxyUser;
 
-    private JTextField proxyPass;
+    private JPasswordField proxyPass;
 
     private JTextField connectTimeOut;
 
@@ -88,18 +90,28 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
 
     private JCheckBox useMultipartForPost;
 
+    private JCheckBox useBrowserCompatibleMultipartMode;
+
     private JLabeledChoice method;
+    
+    private JLabeledChoice httpImplementation;
 
     private final boolean notConfigOnly;
-    // set this true to suppress some items for use in HTTP Request defaults
+    // set this false to suppress some items for use in HTTP Request defaults
+    
+    private final boolean showImplementation; // Set false for AJP
 
     public UrlConfigGui() {
-        notConfigOnly=true;
-        init();
+        this(true);
     }
 
     public UrlConfigGui(boolean value) {
-        notConfigOnly=value;
+        this(value, true);
+    }
+
+    public UrlConfigGui(boolean showSamplerFields, boolean showImplementation) {
+        notConfigOnly=showSamplerFields;
+        this.showImplementation = showImplementation;
         init();
     }
 
@@ -111,6 +123,10 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
             method.setText(HTTPSamplerBase.DEFAULT_METHOD);
             useKeepAlive.setSelected(true);
             useMultipartForPost.setSelected(false);
+            useBrowserCompatibleMultipartMode.setSelected(HTTPSamplerBase.BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT);
+        }
+        if (showImplementation) {
+            httpImplementation.setText(""); // $NON-NLS-1$
         }
         path.setText(""); // $NON-NLS-1$
         port.setText(""); // $NON-NLS-1$
@@ -150,7 +166,7 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
         element.setProperty(HTTPSamplerBase.PROXYHOST, proxyHost.getText(),"");
         element.setProperty(HTTPSamplerBase.PROXYPORT, proxyPort.getText(),"");
         element.setProperty(HTTPSamplerBase.PROXYUSER, proxyUser.getText(),"");
-        element.setProperty(HTTPSamplerBase.PROXYPASS, proxyPass.getText(),"");
+        element.setProperty(HTTPSamplerBase.PROXYPASS, String.valueOf(proxyPass.getPassword()),"");
         element.setProperty(HTTPSamplerBase.CONNECT_TIMEOUT, connectTimeOut.getText());
         element.setProperty(HTTPSamplerBase.RESPONSE_TIMEOUT, responseTimeOut.getText());
         element.setProperty(HTTPSamplerBase.PROTOCOL, protocol.getText());
@@ -162,6 +178,10 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
             element.setProperty(new BooleanProperty(HTTPSamplerBase.AUTO_REDIRECTS, autoRedirects.isSelected()));
             element.setProperty(new BooleanProperty(HTTPSamplerBase.USE_KEEPALIVE, useKeepAlive.isSelected()));
             element.setProperty(new BooleanProperty(HTTPSamplerBase.DO_MULTIPART_POST, useMultipartForPost.isSelected()));
+            element.setProperty(HTTPSamplerBase.BROWSER_COMPATIBLE_MULTIPART, useBrowserCompatibleMultipartMode.isSelected(),HTTPSamplerBase.BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT);
+        }
+        if (showImplementation) {
+            element.setProperty(HTTPSamplerBase.IMPLEMENTATION, httpImplementation.getText(),"");
         }
     }
 
@@ -195,10 +215,15 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
         path.setText(el.getPropertyAsString(HTTPSamplerBase.PATH));
         if (notConfigOnly){
             method.setText(el.getPropertyAsString(HTTPSamplerBase.METHOD));
-            followRedirects.setSelected(((AbstractTestElement) el).getPropertyAsBoolean(HTTPSamplerBase.FOLLOW_REDIRECTS));
-            autoRedirects.setSelected(((AbstractTestElement) el).getPropertyAsBoolean(HTTPSamplerBase.AUTO_REDIRECTS));
-            useKeepAlive.setSelected(((AbstractTestElement) el).getPropertyAsBoolean(HTTPSamplerBase.USE_KEEPALIVE));
-            useMultipartForPost.setSelected(((AbstractTestElement) el).getPropertyAsBoolean(HTTPSamplerBase.DO_MULTIPART_POST));
+            followRedirects.setSelected(el.getPropertyAsBoolean(HTTPSamplerBase.FOLLOW_REDIRECTS));
+            autoRedirects.setSelected(el.getPropertyAsBoolean(HTTPSamplerBase.AUTO_REDIRECTS));
+            useKeepAlive.setSelected(el.getPropertyAsBoolean(HTTPSamplerBase.USE_KEEPALIVE));
+            useMultipartForPost.setSelected(el.getPropertyAsBoolean(HTTPSamplerBase.DO_MULTIPART_POST));
+            useBrowserCompatibleMultipartMode.setSelected(el.getPropertyAsBoolean(
+                    HTTPSamplerBase.BROWSER_COMPATIBLE_MULTIPART, HTTPSamplerBase.BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT));
+        }
+        if (showImplementation) {
+            httpImplementation.setText(el.getPropertyAsString(HTTPSamplerBase.IMPLEMENTATION));
         }
     }
 
@@ -368,7 +393,7 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
     }
 
     private JPanel getProxyPassPanel() {
-        proxyPass = new JTextField(5);
+        proxyPass = new JPasswordField(5);
 
         JLabel label = new JLabel(JMeterUtils.getResString("password")); // $NON-NLS-1$
         label.setLabelFor(proxyPass);
@@ -406,6 +431,10 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
 
             useMultipartForPost = new JCheckBox(JMeterUtils.getResString("use_multipart_for_http_post")); // $NON-NLS-1$
             useMultipartForPost.setSelected(false);
+
+            useBrowserCompatibleMultipartMode = new JCheckBox(JMeterUtils.getResString("use_multipart_mode_browser")); // $NON-NLS-1$
+            useBrowserCompatibleMultipartMode.setSelected(HTTPSamplerBase.BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT);
+
         }
 
         JPanel pathPanel = new JPanel(new BorderLayout(5, 0));
@@ -421,7 +450,8 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
             optionPanel.add(autoRedirects);
             optionPanel.add(followRedirects);
             optionPanel.add(useKeepAlive);
-             optionPanel.add(useMultipartForPost);
+            optionPanel.add(useMultipartForPost);
+            optionPanel.add(useBrowserCompatibleMultipartMode);
             optionPanel.setMinimumSize(optionPanel.getPreferredSize());
             panel.add(optionPanel);
         }
@@ -430,15 +460,24 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
     }
 
     protected JPanel getProtocolAndMethodPanel() {
+
+        // Implementation
+        
+        if (showImplementation) {
+            httpImplementation = new JLabeledChoice(JMeterUtils.getResString("http_implementation"), // $NON-NLS-1$
+                    HTTPSamplerFactory.getImplementations());
+            httpImplementation.addValue("");
+        }
         // PROTOCOL
-        protocol = new JTextField(10);
+        protocol = new JTextField(4);
+        JLabel protocolLabel = new JLabel(JMeterUtils.getResString("protocol")); // $NON-NLS-1$
+        protocolLabel.setLabelFor(protocol);        
+        
         // CONTENT_ENCODING
         contentEncoding = new JTextField(10);
-
-        JLabel protocolLabel = new JLabel(JMeterUtils.getResString("protocol")); // $NON-NLS-1$
-        protocolLabel.setLabelFor(protocol);
         JLabel contentEncodingLabel = new JLabel(JMeterUtils.getResString("content_encoding")); // $NON-NLS-1$
-        protocolLabel.setLabelFor(contentEncoding);
+        contentEncodingLabel.setLabelFor(contentEncoding);
+
         if (notConfigOnly){
             method = new JLabeledChoice(JMeterUtils.getResString("method"), // $NON-NLS-1$
                     HTTPSamplerBase.getValidMethodsAsArray());
@@ -446,6 +485,9 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
 
         JPanel panel = new JPanel(new FlowLayout(FlowLayout.LEFT));
 
+        if (showImplementation) {
+            panel.add(httpImplementation);
+        }
         panel.add(protocolLabel);
         panel.add(protocol);
         panel.add(Box.createHorizontalStrut(5));
@@ -458,6 +500,7 @@ public class UrlConfigGui extends JPanel implements ChangeListener {
 
         panel.add(contentEncodingLabel);
         panel.add(contentEncoding);
+        panel.setMinimumSize(panel.getPreferredSize());
         return panel;
     }
 
