@@ -28,11 +28,12 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Date;
 
-import org.apache.commons.httpclient.Header;
 import org.apache.commons.httpclient.HttpMethod;
 import org.apache.commons.httpclient.URIException;
 import org.apache.commons.httpclient.util.DateParseException;
 import org.apache.commons.httpclient.util.DateUtil;
+import org.apache.http.HttpResponse;
+import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.jmeter.config.ConfigTestElement;
 import org.apache.jmeter.engine.event.LoopIterationEvent;
 import org.apache.jmeter.protocol.http.util.HTTPConstantsInterface;
@@ -56,7 +57,7 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
     public static final String USE_EXPIRES = "useExpires"; // $NON-NLS-1$
     //-
 
-    private transient ThreadLocal<Map<String, CacheEntry>> threadCache;
+    private transient InheritableThreadLocal<Map<String, CacheEntry>> threadCache;
 
     private transient boolean useExpires; // Cached value
 
@@ -98,7 +99,7 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
 
     /**
      * Save the Last-Modified, Etag, and Expires headers if the result is cacheable.
-     *
+     * Version for Java implementation.
      * @param conn connection
      * @param res result
      */
@@ -115,7 +116,7 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
 
     /**
      * Save the Last-Modified, Etag, and Expires headers if the result is cacheable.
-     *
+     * Version for Commons HttpClient implementation.
      * @param method
      * @param res result
      */
@@ -130,6 +131,23 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
         }
     }
 
+    /**
+     * Save the Last-Modified, Etag, and Expires headers if the result is cacheable.
+     * Version for Apache HttpClient implementation.
+     * @param method
+     * @param res result
+     */
+    public void saveDetails(HttpResponse method, SampleResult res) {
+        if (isCacheable(res)){
+            method.getLastHeader(USE_EXPIRES);
+            String lastModified = getHeader(method ,HTTPConstantsInterface.LAST_MODIFIED);
+            String expires = getHeader(method ,HTTPConstantsInterface.EXPIRES);
+            String etag = getHeader(method ,HTTPConstantsInterface.ETAG);
+            String cacheControl = getHeader(method, HTTPConstantsInterface.CACHE_CONTROL);
+            setCache(lastModified, cacheControl, expires, etag, res.getUrlAsString()); // TODO correct URL?
+        }
+    }
+
     // helper method to save the cache entry
     private void setCache(String lastModified, String cacheControl, String expires, String etag, String url) {
         if (log.isDebugEnabled()){
@@ -156,9 +174,15 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
         getCache().put(url, new CacheEntry(lastModified, expiresDate, etag));
     }
 
-    // Helper method to deal with missing headers
+    // Helper method to deal with missing headers - Commons HttpClient
     private String getHeader(HttpMethod method, String name){
-        Header hdr = method.getResponseHeader(name);
+        org.apache.commons.httpclient.Header hdr = method.getResponseHeader(name);
+        return hdr != null ? hdr.getValue() : null;
+    }
+
+    // Apache HttpClient
+    private String getHeader(HttpResponse method, String name) {
+        org.apache.http.Header hdr = method.getLastHeader(name);
         return hdr != null ? hdr.getValue() : null;
     }
 
@@ -176,13 +200,14 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
      * Check the cache, and if there is a match, set the headers:<br/>
      * If-Modified-Since<br/>
      * If-None-Match<br/>
+     * Commons HttpClient version
      * @param url URL to look up in cache
      * @param method where to set the headers
      */
     public void setHeaders(URL url, HttpMethod method) {
         CacheEntry entry = getCache().get(url.toString());
         if (log.isDebugEnabled()){
-            log.debug(method.getName()+"(OAHC) "+url.toString()+" "+entry);
+            log.debug(method.getName()+"(OACH) "+url.toString()+" "+entry);
         }
         if (entry != null){
             final String lastModified = entry.getLastModified();
@@ -196,6 +221,31 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
         }
     }
 
+    /**
+     * Check the cache, and if there is a match, set the headers:<br/>
+     * If-Modified-Since<br/>
+     * If-None-Match<br/>
+     * Apache HttpClient version.
+     * @param url URL to look up in cache
+     * @param request where to set the headers
+     */
+    public void setHeaders(URL url, HttpRequestBase request) {
+        CacheEntry entry = getCache().get(url.toString());
+        if (log.isDebugEnabled()){
+            log.debug(request.getMethod()+"(OAH) "+url.toString()+" "+entry);
+        }
+        if (entry != null){
+            final String lastModified = entry.getLastModified();
+            if (lastModified != null){
+                request.setHeader(HTTPConstantsInterface.IF_MODIFIED_SINCE, lastModified);
+            }
+            final String etag = entry.getEtag();
+            if (etag != null){
+                request.setHeader(HTTPConstantsInterface.IF_NONE_MATCH, etag);
+            }
+        }
+    }
+
     /**
      * Check the cache, and if there is a match, set the headers:<br/>
      * If-Modified-Since<br/>
@@ -275,7 +325,7 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
 
     private void clearCache() {
         log.debug("Clear cache");
-        threadCache = new ThreadLocal<Map<String, CacheEntry>>(){
+        threadCache = new InheritableThreadLocal<Map<String, CacheEntry>>(){
             @Override
             protected Map<String, CacheEntry> initialValue(){
                 return new HashMap<String, CacheEntry>();
@@ -301,4 +351,5 @@ public class CacheManager extends ConfigTestElement implements TestListener, Ser
         }
         useExpires=getUseExpires(); // cache the value
     }
+
 }
\ No newline at end of file
