@@ -86,6 +86,15 @@ public class CookieManager extends ConfigTestElement implements TestListener, Se
     private static final boolean CHECK_COOKIES =
         JMeterUtils.getPropDefault("CookieManager.check.cookies", true);// $NON-NLS-1$
 
+    static {
+        log.info("Settings:"
+                + " Delete null: " + DELETE_NULL_COOKIES
+                + " Check: " + CHECK_COOKIES
+                + " Allow variable: " + ALLOW_VARIABLE_COOKIES
+                + " Save: " + SAVE_COOKIES
+                + " Prefix: " + COOKIE_NAME_PREFIX
+                );
+    }
     private transient CookieSpec cookieSpec;
 
     private transient CollectionProperty initialCookies;
@@ -198,7 +207,7 @@ public class CookieManager extends ConfigTestElement implements TestListener, Se
                         st[_path] = "/"; //$NON-NLS-1$
                     }
                     boolean secure = Boolean.valueOf(st[_secure]).booleanValue();
-                    long expires = new Long(st[_expires]).longValue();
+                    long expires = Long.valueOf(st[_expires]).longValue();
                     if (expires==Long.MAX_VALUE) {
                         expires=0;
                     }
@@ -498,4 +507,10 @@ public class CookieManager extends ConfigTestElement implements TestListener, Se
             setProperty((CollectionProperty)initialCookies.clone());
         }
     }
+
+    public static String[] getCookieSpecs(){
+        return CookiePolicy.getRegisteredCookieSpecs(); // Commons HttpClient
+        //return new DefaultHttpClient().getCookieSpecs().getSpecNames().toArray(new String[]{}); // Apache HttpClient
+    }
+
 }
\ No newline at end of file
