@@ -22,6 +22,7 @@ import java.io.InterruptedIOException;
 import java.net.ServerSocket;
 import java.net.Socket;
 
+import org.apache.jmeter.gui.Stoppable;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.jorphan.util.JOrphanUtils;
 import org.apache.log.Logger;
@@ -32,7 +33,7 @@ import org.apache.log.Logger;
  * For each client request, creates a thread to handle the request.
  *
  */
-public class HttpMirrorServer extends Thread {
+public class HttpMirrorServer extends Thread implements Stoppable {
     private static final Logger log = LoggingManager.getLoggerForClass();
 
     /**
@@ -86,7 +87,7 @@ public class HttpMirrorServer extends Thread {
                     if (running) {
                         // Pass request to new thread
                         HttpMirrorThread thd = new HttpMirrorThread(clientSocket);
-                        log.info("Starting new Mirror thread");
+                        log.debug("Starting new Mirror thread");
                         thd.start();
                     } else {
                         log.warn("Server not running");
@@ -119,6 +120,8 @@ public class HttpMirrorServer extends Thread {
         if (args.length > 0){
             port = Integer.parseInt(args[0]);
         }
+        LoggingManager.setPriority("INFO"); // default level
+        LoggingManager.setLoggingLevels(System.getProperties() ); // allow override by system properties
         HttpMirrorServer serv = new HttpMirrorServer(port);
         serv.start();
     }
