@@ -20,30 +20,36 @@ package org.apache.jmeter.protocol.http.control.gui;
 
 import java.awt.BorderLayout;
 import java.awt.Dimension;
-import java.awt.Font;
+import java.awt.FlowLayout;
 import java.awt.event.ActionEvent;
 
+import javax.swing.BorderFactory;
+import javax.swing.Box;
+import javax.swing.BoxLayout;
 import javax.swing.JButton;
 import javax.swing.JCheckBox;
-import javax.swing.JOptionPane;
 import javax.swing.JLabel;
+import javax.swing.JOptionPane;
 import javax.swing.JPanel;
+import javax.swing.JScrollPane;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
 import javax.swing.border.Border;
 import javax.swing.border.EmptyBorder;
 
 import org.apache.commons.lang.ArrayUtils;
+import org.apache.jmeter.gui.util.FilePanel;
+import org.apache.jmeter.gui.util.HorizontalPanel;
+import org.apache.jmeter.protocol.http.control.AuthManager;
 import org.apache.jmeter.protocol.http.sampler.HTTPSamplerBase;
 import org.apache.jmeter.protocol.http.sampler.WebServiceSampler;
+import org.apache.jmeter.protocol.http.util.WSDLHelper;
 import org.apache.jmeter.samplers.gui.AbstractSamplerGui;
 import org.apache.jmeter.testelement.TestElement;
 import org.apache.jmeter.util.JMeterUtils;
-import org.apache.jmeter.gui.util.FilePanel;
 import org.apache.jorphan.gui.JLabeledChoice;
-import org.apache.jorphan.gui.JLabeledTextArea;
 import org.apache.jorphan.gui.JLabeledTextField;
 import org.apache.jorphan.gui.layout.VerticalLayout;
-import org.apache.jmeter.protocol.http.util.WSDLHelper;
-import org.apache.jmeter.protocol.http.control.AuthManager;
 
 /**
  * This is the GUI for the webservice samplers. It extends AbstractSamplerGui
@@ -59,15 +65,15 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
 
     private final JLabeledTextField domain = new JLabeledTextField(JMeterUtils.getResString("web_server_domain")); // $NON-NLS-1$
 
-    private final JLabeledTextField protocol = new JLabeledTextField(JMeterUtils.getResString("protocol")); // $NON-NLS-1$
+    private final JLabeledTextField protocol = new JLabeledTextField(JMeterUtils.getResString("protocol"), 4); // $NON-NLS-1$
 
-    private final JLabeledTextField port = new JLabeledTextField(JMeterUtils.getResString("web_server_port")); // $NON-NLS-1$
+    private final JLabeledTextField port = new JLabeledTextField(JMeterUtils.getResString("web_server_port"), 4); // $NON-NLS-1$
 
     private final JLabeledTextField path = new JLabeledTextField(JMeterUtils.getResString("path")); // $NON-NLS-1$
 
     private final JLabeledTextField soapAction = new JLabeledTextField(JMeterUtils.getResString("webservice_soap_action")); // $NON-NLS-1$
 
-    private final JLabeledTextArea soapXml = new JLabeledTextArea(JMeterUtils.getResString("soap_data_title")); // $NON-NLS-1$
+    private JTextArea soapXml;
 
     private final JLabeledTextField wsdlField = new JLabeledTextField(JMeterUtils.getResString("wsdl_url")); // $NON-NLS-1$
 
@@ -83,27 +89,7 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
 
     private final JLabeledTextField randomXmlFile = new JLabeledTextField(JMeterUtils.getResString("get_xml_from_random")); // $NON-NLS-1$
 
-    private final JLabeledTextField connectTimeout = new JLabeledTextField(JMeterUtils.getResString("webservice_timeout")); // $NON-NLS-1$
-
-    /**
-     * We create several JLabel objects to display usage instructions in the
-     * GUI. The reason there are multiple labels is to make sure it displays
-     * correctly.
-     */
-    private JLabel wsdlMessage = new JLabel(JMeterUtils.getResString("get_xml_message")); // $NON-NLS-1$
-
-    private JLabel wsdlMessage2 = new JLabel(JMeterUtils.getResString("get_xml_message2")); // $NON-NLS-1$
-
-    private JLabel wsdlMessage3 = new JLabel(JMeterUtils.getResString("get_xml_message3")); // $NON-NLS-1$
-
-    private JLabel wsdlMessage4 = new JLabel(JMeterUtils.getResString("get_xml_message4")); // $NON-NLS-1$
-
-    private JLabel wsdlMessage5 = new JLabel(JMeterUtils.getResString("get_xml_message5")); // $NON-NLS-1$
-
-    /**
-     * This is the font for the note.
-     */
-    private Font plainText = new Font("plain", Font.PLAIN, 10); // $NON-NLS-1$
+    private final JLabeledTextField connectTimeout = new JLabeledTextField(JMeterUtils.getResString("webservice_timeout"), 4); // $NON-NLS-1$
 
     /**
      * checkbox for memory cache.
@@ -123,31 +109,30 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
     /**
      * text field for the proxy host
      */
-    private JLabeledTextField proxyHost = new JLabeledTextField(JMeterUtils.getResString("webservice_proxy_host")); // $NON-NLS-1$
+    private JTextField proxyHost;
 
     /**
      * text field for the proxy port
      */
-    private JLabeledTextField proxyPort = new JLabeledTextField(JMeterUtils.getResString("webservice_proxy_port")); // $NON-NLS-1$
+    private JTextField proxyPort;
 
     /**
      * Text note about read response and its usage.
      */
-    private JLabel readMessage = new JLabel(JMeterUtils.getResString("read_response_note")); // $NON-NLS-1$
-
-    private JLabel readMessage2 = new JLabel(JMeterUtils.getResString("read_response_note2")); // $NON-NLS-1$
-
-    private JLabel readMessage3 = new JLabel(JMeterUtils.getResString("read_response_note3")); // $NON-NLS-1$
+    private String readToolTip = JMeterUtils.getResString("read_response_note") // $NON-NLS-1$
+                                  + " " // $NON-NLS-1$
+                                  + JMeterUtils.getResString("read_response_note2") // $NON-NLS-1$
+                                  + " " // $NON-NLS-1$
+                                  + JMeterUtils.getResString("read_response_note3"); // $NON-NLS-1$
 
     /**
      * Text note for proxy
      */
-    private JLabel proxyMessage = new JLabel(JMeterUtils.getResString("webservice_proxy_note")); // $NON-NLS-1$
-
-    private JLabel proxyMessage2 = new JLabel(JMeterUtils.getResString("webservice_proxy_note2")); // $NON-NLS-1$
-
-    private JLabel proxyMessage3 = new JLabel(JMeterUtils.getResString("webservice_proxy_note3")); // $NON-NLS-1$
-
+    private String proxyToolTip = JMeterUtils.getResString("webservice_proxy_note") // $NON-NLS-1$
+                                  + " " // $NON-NLS-1$
+                                  + JMeterUtils.getResString("webservice_proxy_note2") // $NON-NLS-1$
+                                  + " " // $NON-NLS-1$
+                                  + JMeterUtils.getResString("webservice_proxy_note3"); // $NON-NLS-1$
     public WebServiceSamplerGui() {
         init();
     }
@@ -198,7 +183,7 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
     @Override
     public void clearGui() {
         super.clearGui();
-
+        wsdlMethods.setValues(new String[0]);
         domain.setText(""); //$NON-NLS-1$
         protocol.setText(""); //$NON-NLS-1$
         port.setText(""); //$NON-NLS-1$
@@ -225,77 +210,152 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
         setBorder(makeBorder());
         add(makeTitlePanel(), BorderLayout.NORTH);
 
-        wsdlMessage.setFont(plainText);
-        wsdlMessage2.setFont(plainText);
-        wsdlMessage3.setFont(plainText);
-        wsdlMessage4.setFont(plainText);
-        wsdlMessage5.setFont(plainText);
-        readMessage.setFont(plainText);
-        readMessage2.setFont(plainText);
-        readMessage3.setFont(plainText);
-
         // MAIN PANEL
         JPanel mainPanel = new JPanel();
-        Border margin = new EmptyBorder(10, 10, 5, 10);
-        mainPanel.setBorder(margin);
-        mainPanel.setLayout(new VerticalLayout(5, VerticalLayout.BOTH));
+        mainPanel.setLayout(new BoxLayout(mainPanel, BoxLayout.Y_AXIS));
+        
+        mainPanel.add(createTopPanel(), BorderLayout.NORTH);
+        mainPanel.add(createMessagePanel(), BorderLayout.CENTER);
+        mainPanel.add(createBottomPanel(), BorderLayout.SOUTH);
+        this.add(mainPanel);
+    }
+
+    private final JPanel createTopPanel() {
+        JPanel topPanel = new JPanel();
+        topPanel.setLayout(new VerticalLayout(5, VerticalLayout.BOTH));
+        
+        JPanel wsdlHelper = new JPanel();
+        wsdlHelper.setLayout(new BoxLayout(wsdlHelper, BoxLayout.Y_AXIS));
+        wsdlHelper.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(),
+                JMeterUtils.getResString("webservice_configuration_wizard"))); // $NON-NLS-1$
 
         // Button for browsing webservice wsdl
         JPanel wsdlEntry = new JPanel();
-        mainPanel.add(wsdlEntry);
+        wsdlEntry.setLayout(new BoxLayout(wsdlEntry, BoxLayout.X_AXIS));
+        Border margin = new EmptyBorder(0, 5, 0, 5);
+        wsdlEntry.setBorder(margin);
+        wsdlHelper.add(wsdlEntry);
         wsdlEntry.add(wsdlField);
         wsdlEntry.add(wsdlButton);
         wsdlButton.addActionListener(this);
 
         // Web Methods
         JPanel listPanel = new JPanel();
-        JLabel selectLabel = new JLabel("Web Methods");
+        listPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
+        JLabel selectLabel = new JLabel(JMeterUtils.getResString("webservice_methods")); // $NON-NLS-1$
         wsdlMethods = new JLabeledChoice();
-        mainPanel.add(listPanel);
+        wsdlHelper.add(listPanel);
         listPanel.add(selectLabel);
         listPanel.add(wsdlMethods);
         listPanel.add(selectButton);
         selectButton.addActionListener(this);
 
-        mainPanel.add(protocol);
-        mainPanel.add(domain);
-        mainPanel.add(port);
-        mainPanel.add(path);
-        mainPanel.add(connectTimeout);
-        mainPanel.add(soapAction);
-        // OPTIONAL TASKS
-        // we create a preferred size for the soap text area
-        // the width is the same as the soap file browser
-        Dimension pref = new Dimension(400, 200);
-        soapXml.setPreferredSize(pref);
-        mainPanel.add(soapXml);
-        mainPanel.add(soapXmlFile);
-        mainPanel.add(wsdlMessage);
-        mainPanel.add(wsdlMessage2);
-        mainPanel.add(wsdlMessage3);
-        mainPanel.add(wsdlMessage4);
-        mainPanel.add(wsdlMessage5);
-        mainPanel.add(randomXmlFile);
-        mainPanel.add(memCache);
-        mainPanel.add(readResponse);
-        mainPanel.add(readMessage);
-        mainPanel.add(readMessage2);
-        mainPanel.add(readMessage3);
+        topPanel.add(wsdlHelper);
+        
+        JPanel urlPane = new JPanel();
+        urlPane.setLayout(new FlowLayout(FlowLayout.LEFT, 0, 0));
+        urlPane.add(protocol);
+        urlPane.add(Box.createRigidArea(new Dimension(5,0)));
+        urlPane.add(domain);
+        urlPane.add(Box.createRigidArea(new Dimension(5,0)));
+        urlPane.add(port);
+        urlPane.add(Box.createRigidArea(new Dimension(5,0)));
+        urlPane.add(connectTimeout);
+        topPanel.add(urlPane);
+        
+        topPanel.add(path);
+        topPanel.add(soapAction);
+        return topPanel;
+    }
+
+    private final JPanel createMessagePanel() {
+        JPanel msgPanel = new JPanel();
+        msgPanel.setLayout(new BorderLayout(5, 0));
+        msgPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(),
+                JMeterUtils.getResString("webservice_message_soap"))); // $NON-NLS-1$
+
+        JPanel soapXmlPane = new JPanel();
+        soapXmlPane.setLayout(new BorderLayout(5, 0));
+        soapXmlPane.setBorder(BorderFactory.createTitledBorder(
+                JMeterUtils.getResString("soap_data_title"))); // $NON-NLS-1$
+        soapXmlPane.setPreferredSize(new Dimension(4, 4)); // Permit dynamic resize of TextArea
+        soapXml = new JTextArea();
+        soapXml.setLineWrap(true);
+        soapXml.setWrapStyleWord(true);
+        soapXml.setTabSize(4); // improve xml display
+        soapXmlPane.add(new JScrollPane(soapXml), BorderLayout.CENTER);
+        msgPanel.add(soapXmlPane, BorderLayout.CENTER);
+        
+        JPanel southPane = new JPanel();
+        southPane.setLayout(new BoxLayout(southPane, BoxLayout.Y_AXIS));
+        southPane.add(soapXmlFile);
+        JPanel randomXmlPane = new JPanel();
+        randomXmlPane.setLayout(new BorderLayout(5, 0));
+        randomXmlPane.setBorder(BorderFactory.createTitledBorder(
+                JMeterUtils.getResString("webservice_get_xml_from_random_title"))); // $NON-NLS-1$
+        randomXmlPane.add(randomXmlFile, BorderLayout.CENTER);
+        southPane.add(randomXmlPane);
+        msgPanel.add(southPane, BorderLayout.SOUTH);
+        return msgPanel;
+    }
+    
+    private final JPanel createBottomPanel() {
+        JPanel optionPane = new JPanel();
+        optionPane.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(),
+                JMeterUtils.getResString("option"))); // $NON-NLS-1$
+        optionPane.setLayout(new FlowLayout(FlowLayout.LEFT, 0, 0));
+        JPanel ckboxPane = new HorizontalPanel();
+        ckboxPane.add(memCache, BorderLayout.WEST);
+        ckboxPane.add(readResponse, BorderLayout.CENTER);
+        readResponse.setToolTipText(readToolTip);
+        optionPane.add(ckboxPane);
 
         // add the proxy elements
-        mainPanel.add(useProxy);
+        optionPane.add(getProxyServerPanel());
+        return optionPane;
+        
+    }
+    /**
+     * Create a panel containing the proxy server details
+     *
+     * @return the panel
+     */
+    private final JPanel getProxyServerPanel(){
+        JPanel proxyServer = new JPanel();
+        proxyServer.setLayout(new FlowLayout(FlowLayout.LEFT, 0, 0));
+        proxyServer.add(useProxy);
         useProxy.addActionListener(this);
-        mainPanel.add(proxyHost);
-        mainPanel.add(proxyPort);
-        // add the proxy notes
-        proxyMessage.setFont(plainText);
-        proxyMessage2.setFont(plainText);
-        proxyMessage3.setFont(plainText);
-        mainPanel.add(proxyMessage);
-        mainPanel.add(proxyMessage2);
-        mainPanel.add(proxyMessage3);
+        useProxy.setToolTipText(proxyToolTip);
+        proxyServer.add(Box.createRigidArea(new Dimension(5,0)));
+        proxyServer.add(getProxyHostPanel());
+        proxyServer.add(Box.createRigidArea(new Dimension(5,0)));
+        proxyServer.add(getProxyPortPanel());
+        return proxyServer;
+    }
+    
+    private JPanel getProxyHostPanel() {
+        proxyHost = new JTextField(12);
 
-        this.add(mainPanel);
+        JLabel label = new JLabel(JMeterUtils.getResString("web_server_domain")); // $NON-NLS-1$
+        label.setLabelFor(proxyHost);
+
+        JPanel panel = new JPanel(new BorderLayout(5, 0));
+        panel.add(label, BorderLayout.WEST);
+        panel.add(proxyHost, BorderLayout.CENTER);
+        return panel;
+    }
+    
+    private JPanel getProxyPortPanel() {
+        proxyPort = new JTextField(4);
+
+        JLabel label = new JLabel(JMeterUtils.getResString("web_server_port")); // $NON-NLS-1$
+        label.setLabelFor(proxyPort);
+
+        JPanel panel = new JPanel(new BorderLayout(5, 0));
+        panel.add(label, BorderLayout.WEST);
+        panel.add(proxyPort, BorderLayout.CENTER);
+
+        return panel;
     }
 
     /**
@@ -306,12 +366,17 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
         super.configure(el);
         WebServiceSampler sampler = (WebServiceSampler) el;
         wsdlField.setText(sampler.getWsdlURL());
+        final String wsdlText = wsdlField.getText();
+        if (wsdlText != null && wsdlText.length() > 0) {
+            fillWsdlMethods(wsdlField.getText(), true, sampler.getSoapAction());
+        }
         protocol.setText(sampler.getProtocol());
         domain.setText(sampler.getDomain());
         port.setText(sampler.getPropertyAsString(HTTPSamplerBase.PORT));
         path.setText(sampler.getPath());
         soapAction.setText(sampler.getSoapAction());
         soapXml.setText(sampler.getXmlData());
+        soapXml.setCaretPosition(0); // go to 1st line
         soapXmlFile.setFilename(sampler.getXmlFile());
         randomXmlFile.setText(sampler.getXmlPathLoc());
         connectTimeout.setText(sampler.getTimeout());
@@ -358,9 +423,10 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
      * easily replace it with a different WSDL driver later on.
      *
      * @param url
+     * @param silent 
      * @return array of web methods
      */
-    public String[] browseWSDL(String url) {
+    public String[] browseWSDL(String url, boolean silent) {
         try {
             // We get the AuthManager and pass it to the WSDLHelper
             // once the sampler is updated to Axis, all of this stuff
@@ -372,11 +438,13 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
             HELPER.parse();
             return HELPER.getWebMethods();
         } catch (Exception exception) {
-            JOptionPane.showConfirmDialog(this,
-                    JMeterUtils.getResString("wsdl_helper_error") // $NON-NLS-1$
-                    +"\n"+exception, // $NON-NLS-1$
-                    "Warning",
-                    JOptionPane.DEFAULT_OPTION, JOptionPane.ERROR_MESSAGE);
+            if (!silent) {
+                JOptionPane.showConfirmDialog(this,
+                        JMeterUtils.getResString("wsdl_helper_error") // $NON-NLS-1$
+                        +"\n"+exception, // $NON-NLS-1$
+                        JMeterUtils.getResString("warning"), // $NON-NLS-1$
+                        JOptionPane.DEFAULT_OPTION, JOptionPane.ERROR_MESSAGE);
+            }
             return ArrayUtils.EMPTY_STRING_ARRAY;
         }
     }
@@ -405,18 +473,33 @@ public class WebServiceSamplerGui extends AbstractSamplerGui implements java.awt
         } else if (eventSource == wsdlButton){
             final String wsdlText = wsdlField.getText();
             if (wsdlText != null && wsdlText.length() > 0) {
-                String[] wsdlData = browseWSDL(wsdlText);
-                if (wsdlData != null) {
-                    wsdlMethods.setValues(wsdlData);
-                    wsdlMethods.repaint();
-                }
+                fillWsdlMethods(wsdlText, false, null);
             } else {
                 JOptionPane.showConfirmDialog(this,
                         JMeterUtils.getResString("wsdl_url_error"), // $NON-NLS-1$
-                        "Warning",
+                        JMeterUtils.getResString("warning"), // $NON-NLS-1$
                         JOptionPane.DEFAULT_OPTION, JOptionPane.ERROR_MESSAGE);
             }
         }
     }
 
+    /**
+     * @param wsdlText
+     * @param silent
+     * @param soapAction 
+     */
+    private void fillWsdlMethods(final String wsdlText, boolean silent, String soapAction) {
+        String[] wsdlData = browseWSDL(wsdlText, silent);
+        if (wsdlData != null) {
+            wsdlMethods.setValues(wsdlData);
+            if (HELPER != null && soapAction != null) {
+                String selected = HELPER.getSoapActionName(soapAction);
+                if (selected != null) {
+                    wsdlMethods.setText(selected);
+                }
+            }
+            wsdlMethods.repaint();
+        }
+    }
+
 }
