@@ -85,22 +85,19 @@ public class URLRewritingModifier extends AbstractTestElement implements Seriali
                 MatchResult result = matcher.getMatch();
                 value = result.group(1);
             }
-        } else if (isPathExtension() && isPathExtensionNoEquals()) // && !
-                                                                    // isPathExtensionNoQuestionmark
+        } else if (isPathExtension() && isPathExtensionNoEquals()) // && !isPathExtensionNoQuestionmark()
         {
             if (matcher.contains(text, pathExtensionNoEqualsQuestionmarkRegexp)) {
                 MatchResult result = matcher.getMatch();
                 value = result.group(1);
             }
-        } else if (isPathExtension() && isPathExtensionNoQuestionmark()) // && !
-                                                                            // isPathExtensionNoEquals
+        } else if (isPathExtension() && isPathExtensionNoQuestionmark()) // && !isPathExtensionNoEquals()
         {
             if (matcher.contains(text, pathExtensionEqualsNoQuestionmarkRegexp)) {
                 MatchResult result = matcher.getMatch();
                 value = result.group(1);
             }
-        } else if (isPathExtension()) // && ! isPathExtensionNoEquals && !
-                                        // isPathExtensionNoQuestionmark
+        } else if (isPathExtension()) // && !isPathExtensionNoEquals() && !isPathExtensionNoQuestionmark()
         {
             if (matcher.contains(text, pathExtensionEqualsQuestionmarkRegexp)) {
                 MatchResult result = matcher.getMatch();
@@ -150,24 +147,24 @@ public class URLRewritingModifier extends AbstractTestElement implements Seriali
     private void initRegex(String argName) {
         String quotedArg = Perl5Compiler.quotemeta(argName);// Don't get tripped up by RE chars in the arg name
         pathExtensionEqualsQuestionmarkRegexp = JMeterUtils.getPatternCache().getPattern(
-                SEMI_COLON + quotedArg + "=([^\"'>&\\s;]*)[&\\s\"'>;]?$?", // $NON-NLS-1$
+                SEMI_COLON + quotedArg + "=([^\"'<>&\\s;]*)", // $NON-NLS-1$
                 Perl5Compiler.MULTILINE_MASK | Perl5Compiler.READ_ONLY_MASK);
 
         pathExtensionEqualsNoQuestionmarkRegexp = JMeterUtils.getPatternCache().getPattern(
-                SEMI_COLON + quotedArg + "=([^\"'>&\\s;?]*)[&\\s\"'>;?]?$?", // $NON-NLS-1$
+                SEMI_COLON + quotedArg + "=([^\"'<>&\\s;?]*)", // $NON-NLS-1$
                 Perl5Compiler.MULTILINE_MASK | Perl5Compiler.READ_ONLY_MASK);
 
         pathExtensionNoEqualsQuestionmarkRegexp = JMeterUtils.getPatternCache().getPattern(
-                SEMI_COLON + quotedArg + "([^\"'>&\\s;]*)[&\\s\"'>;]?$?", // $NON-NLS-1$
+                SEMI_COLON + quotedArg + "([^\"'<>&\\s;]*)", // $NON-NLS-1$
                 Perl5Compiler.MULTILINE_MASK | Perl5Compiler.READ_ONLY_MASK);
 
         pathExtensionNoEqualsNoQuestionmarkRegexp = JMeterUtils.getPatternCache().getPattern(
-                SEMI_COLON + quotedArg + "([^\"'>&\\s;?]*)[&\\s\"'>;?]?$?", // $NON-NLS-1$
+                SEMI_COLON + quotedArg + "([^\"'<>&\\s;?]*)", // $NON-NLS-1$
                 Perl5Compiler.MULTILINE_MASK | Perl5Compiler.READ_ONLY_MASK);
 
         parameterRegexp = JMeterUtils.getPatternCache().getPattern(
                 // ;sessionid=value
-                "[;\\?&]" + quotedArg + "=([^\"'>&\\s;\\\\]*)[&\\s\"'>;]?$?" +  // $NON-NLS-1$
+                "[;\\?&]" + quotedArg + "=([^\"'<>&\\s;\\\\]*)" +  // $NON-NLS-1$
 
                 // name="sessionid" value="value"
                 "|\\s[Nn][Aa][Mm][Ee]\\s*=\\s*[\"']" + quotedArg
