@@ -38,9 +38,7 @@ import org.apache.jmeter.protocol.http.config.MultipartUrlConfig;
 import org.apache.jmeter.protocol.http.control.Header;
 import org.apache.jmeter.protocol.http.control.HeaderManager;
 import org.apache.jmeter.protocol.http.control.gui.HttpTestSampleGui;
-import org.apache.jmeter.protocol.http.control.gui.HttpTestSampleGui2;
 import org.apache.jmeter.protocol.http.gui.HeaderPanel;
-import org.apache.jmeter.protocol.http.sampler.HTTPSampler2;
 import org.apache.jmeter.protocol.http.sampler.HTTPSamplerBase;
 import org.apache.jmeter.protocol.http.sampler.HTTPSamplerFactory;
 import org.apache.jmeter.protocol.http.util.ConversionUtils;
@@ -260,14 +258,8 @@ public class HttpRequestHdr {
             throws MalformedURLException, IOException {
         // Damn! A whole new GUI just to instantiate a test element?
         // Isn't there a beter way?
-        HttpTestSampleGui tempGui = null;
-        // Create the corresponding gui for the sampler class
-        if(sampler instanceof HTTPSampler2) {
-            tempGui = new HttpTestSampleGui2();
-        }
-        else {
-            tempGui = new HttpTestSampleGui();
-        }
+        HttpTestSampleGui tempGui = new HttpTestSampleGui();
+
         sampler.setProperty(TestElement.GUI_CLASS, tempGui.getClass().getName());
 
         // Populate the sampler
@@ -438,11 +430,9 @@ public class HttpRequestHdr {
                 sampler.setArguments(urlConfig.getArguments());
                 // Set the file uploads
                 sampler.setHTTPFiles(urlConfig.getHTTPFileArgs().asArray());
-            } else if (postData.trim().startsWith("<?")) {
-                // Not sure if this is needed anymore. I assume these requests
-                // do not have HTTPConstants.APPLICATION_X_WWW_FORM_URLENCODED as content type,
-                // and they would therefore be catched by the last else if of these if else if tests
-                sampler.addNonEncodedArgument("", postData, ""); //used when postData is pure xml (ex. an xml-rpc call)
+            // used when postData is pure xml (eg. an xml-rpc call) or for PUT
+            } else if (postData.trim().startsWith("<?") || "PUT".equals(sampler.getMethod())) {
+                sampler.addNonEncodedArgument("", postData, "");
             } else if (contentType == null || contentType.startsWith(HTTPConstants.APPLICATION_X_WWW_FORM_URLENCODED) ){
                 // It is the most common post request, with parameter name and values
                 // We also assume this if no content type is present, to be most backwards compatible,
