@@ -175,13 +175,7 @@ public class Proxy extends Thread {
     @Override
     public void run() {
         // Check which HTTPSampler class we should use
-        String httpSamplerName = HTTPSamplerFactory.DEFAULT_CLASSNAME;
-        if(target.getSamplerTypeName() == ProxyControl.SAMPLER_TYPE_HTTP_SAMPLER) {
-            httpSamplerName = HTTPSamplerFactory.HTTP_SAMPLER_JAVA;
-        }
-        else if(target.getSamplerTypeName() == ProxyControl.SAMPLER_TYPE_HTTP_SAMPLER2) {
-            httpSamplerName = HTTPSamplerFactory.HTTP_SAMPLER_APACHE;
-        }
+        String httpSamplerName = target.getSamplerTypeName();
         // Instantiate the sampler
         HTTPSamplerBase sampler = HTTPSamplerFactory.newInstance(httpSamplerName);
 
@@ -197,7 +191,7 @@ public class Proxy extends Thread {
             if ((request.getMethod().startsWith(HTTPConstants.CONNECT)) && (outStreamClient != null)) {
                 log.debug("Method CONNECT => SSL");
                 // write a OK reponse to browser, to engage SSL exchange
-                outStreamClient.write(("HTTP/1.0 200 OK\r\n\r\n").getBytes()); // $NON-NLS-1$
+                outStreamClient.write(("HTTP/1.0 200 OK\r\n\r\n").getBytes()); // $NON-NLS-1$ // TODO charset?
                 outStreamClient.flush();
                // With ssl request, url is host:port (without https:// or path)
                 String[] param = request.getUrl().split(":");  // $NON-NLS-1$
