@@ -120,7 +120,7 @@ public class HTTPSampleResult extends SampleResult {
             sb.append("\n");
             // Include request body if it is a post or put
             if (HTTPConstants.POST.equals(method) || HTTPConstants.PUT.equals(method)) {
-                sb.append("\nPOST data:\n");
+                sb.append("\n"+method+" data:\n");
                 sb.append(queryString);
                 sb.append("\n");
             }
@@ -193,6 +193,7 @@ public class HTTPSampleResult extends SampleResult {
         if (getDataEncodingNoDefault() == null && getContentType().startsWith("text/html")){ // $NON-NLS-1$
             byte[] bytes=getResponseData();
             // get the start of the file
+            // TODO - charset?
             String prefix = new String(bytes,0,Math.min(bytes.length, 1000)).toLowerCase(java.util.Locale.ENGLISH);
             // Extract the content-type if present
             final String METATAG = "<meta http-equiv=\"content-type\" content=\""; // $NON-NLS-1$
@@ -201,7 +202,8 @@ public class HTTPSampleResult extends SampleResult {
                 tagstart += METATAG.length();
                 int tagend = prefix.indexOf("\"", tagstart); // $NON-NLS-1$
                 if (tagend!=-1){
-                    final String ct = new String(bytes,tagstart,tagend-tagstart);
+                    // TODO use fixed charset:
+                    final String ct = new String(bytes,tagstart,tagend-tagstart); // TODO - charset?
                     setEncodingAndType(ct);// Update the dataEncoding
                 }
             }
@@ -213,4 +215,5 @@ public class HTTPSampleResult extends SampleResult {
         setResponseCode(HTTP_NO_CONTENT_CODE);
         setResponseMessage(HTTP_NO_CONTENT_MSG);
     }
+    
 }
