@@ -24,16 +24,22 @@ import java.io.PrintStream;
 import java.io.UnsupportedEncodingException;
 import java.net.MalformedURLException;
 import java.net.URI;
-import java.net.URISyntaxException;
 import java.net.URL;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.Callable;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.Future;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.io.IOUtils;
 import org.apache.jmeter.config.Argument;
@@ -48,9 +54,9 @@ import org.apache.jmeter.protocol.http.parser.HTMLParser;
 import org.apache.jmeter.protocol.http.util.ConversionUtils;
 import org.apache.jmeter.protocol.http.util.EncoderCache;
 import org.apache.jmeter.protocol.http.util.HTTPArgument;
+import org.apache.jmeter.protocol.http.util.HTTPConstantsInterface;
 import org.apache.jmeter.protocol.http.util.HTTPFileArg;
 import org.apache.jmeter.protocol.http.util.HTTPFileArgs;
-import org.apache.jmeter.protocol.http.util.HTTPConstantsInterface;
 import org.apache.jmeter.samplers.AbstractSampler;
 import org.apache.jmeter.samplers.Entry;
 import org.apache.jmeter.samplers.SampleResult;
@@ -64,6 +70,8 @@ import org.apache.jmeter.testelement.property.PropertyIterator;
 import org.apache.jmeter.testelement.property.StringProperty;
 import org.apache.jmeter.testelement.property.TestElementProperty;
 import org.apache.jmeter.util.JMeterUtils;
+import org.apache.jmeter.util.JsseSSLManager;
+import org.apache.jmeter.util.SSLManager;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.jorphan.util.JOrphanUtils;
 import org.apache.log.Logger;
@@ -82,6 +90,7 @@ public abstract class HTTPSamplerBase extends AbstractSampler
 
     private static final Logger log = LoggingManager.getLoggerForClass();
 
+    //+ JMX names - do not change
     public static final String ARGUMENTS = "HTTPsampler.Arguments"; // $NON-NLS-1$
 
     public static final String AUTH_MANAGER = "HTTPSampler.auth_manager"; // $NON-NLS-1$
@@ -128,8 +137,35 @@ public abstract class HTTPSamplerBase extends AbstractSampler
 
     public static final String URL = "HTTPSampler.URL"; // $NON-NLS-1$
 
-    public static final String CLIENT = "HTTPSampler.client"; // $NON-NLS-1$
+    /**
+     * IP source to use - does not apply to Java HTTP implementation currently
+     */
+    public static final String IP_SOURCE = "HTTPSampler.ipSource"; // $NON-NLS-1$
 
+    public static final String USE_KEEPALIVE = "HTTPSampler.use_keepalive"; // $NON-NLS-1$
+
+    public static final String DO_MULTIPART_POST = "HTTPSampler.DO_MULTIPART_POST"; // $NON-NLS-1$
+
+    public static final String BROWSER_COMPATIBLE_MULTIPART  = "HTTPSampler.BROWSER_COMPATIBLE_MULTIPART"; // $NON-NLS-1$
+    
+    public static final String CONCURRENT_DWN = "HTTPSampler.concurrentDwn"; // $NON-NLS-1$
+    
+    public static final String CONCURRENT_POOL = "HTTPSampler.concurrentPool"; // $NON-NLS-1$
+
+    private static final String CONCURRENT_POOL_DEFAULT = "4"; // default for concurrent pool (do not change)
+
+    //- JMX names
+
+    public static final boolean BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT = false; // The default setting to be used (i.e. historic)
+    
+    private static final long KEEPALIVETIME = 0; // for Thread Pool for resources but no need to use a special value?
+    
+    private static final long AWAIT_TERMINATION_TIMEOUT = 
+        JMeterUtils.getPropDefault("httpsampler.await_termination_timeout", 60); // $NON-NLS-1$ // default value: 60 secs 
+    
+    public static final int CONCURRENT_POOL_SIZE = 4; // Default concurrent pool size for download embedded resources
+    
+    
     public static final String DEFAULT_METHOD = GET; // $NON-NLS-1$
     // Supported methods:
     private static final String [] METHODS = {
@@ -144,11 +180,6 @@ public abstract class HTTPSamplerBase extends AbstractSampler
 
     private static final List<String> METHODLIST = Collections.unmodifiableList(Arrays.asList(METHODS));
 
-
-    public static final String USE_KEEPALIVE = "HTTPSampler.use_keepalive"; // $NON-NLS-1$
-
-    public static final String DO_MULTIPART_POST = "HTTPSampler.DO_MULTIPART_POST"; // $NON-NLS-1$
-
     // @see mergeFileProperties
     // Must be private, as the file list needs special handling
     private final static String FILE_ARGS = "HTTPsampler.Files"; // $NON-NLS-1$
@@ -204,6 +235,10 @@ public abstract class HTTPSamplerBase extends AbstractSampler
     private static final String RESPONSE_PARSERS= // list of parsers
         JMeterUtils.getProperty("HTTPResponse.parsers");//$NON-NLS-1$
 
+	// Control reuse of cached SSL Context in subsequent iterations
+	private static final boolean USE_CACHED_SSL_CONTEXT = 
+	        JMeterUtils.getPropDefault("https.use.cached.ssl.context", true);//$NON-NLS-1$
+    
     static{
         String []parsers = JOrphanUtils.split(RESPONSE_PARSERS, " " , true);// returns empty array for null
         for (int i=0;i<parsers.length;i++){
@@ -229,6 +264,9 @@ public abstract class HTTPSamplerBase extends AbstractSampler
             parsersForType.put("text/html", ""); //$NON-NLS-1$ //$NON-NLS-2$
             log.info("No response parsers defined: text/html only will be scanned for embedded resources");
         }
+        
+		log.info("Reuse SSL session context on subsequent iterations: "
+				+ USE_CACHED_SSL_CONTEXT);
     }
 
     // Bug 49083
@@ -240,6 +278,7 @@ public abstract class HTTPSamplerBase extends AbstractSampler
     private boolean dynamicPath = false;// Set false if spaces are already encoded
 
 
+
     ////////////////////// Code ///////////////////////////
 
     public HTTPSamplerBase() {
@@ -315,17 +354,6 @@ public abstract class HTTPSamplerBase extends AbstractSampler
         return protocol;
     }
 
-
-    // Not used?
-    public String getClient() {
-        return getPropertyAsString(CLIENT);
-    }
-
-    // Not used?
-    public void setClient(String client){
-        setProperty(CLIENT,client);
-    }
-
     /**
      * Sets the Path attribute of the UrlConfig object Also calls parseArguments
      * to extract and store any query arguments
@@ -339,8 +367,8 @@ public abstract class HTTPSamplerBase extends AbstractSampler
     }
 
     /**
-     * Sets the Path attribute of the UrlConfig object Also calls parseArguments
-     * to extract and store any query arguments
+     * Sets the PATH property; also calls {@link #parseArguments(String, String)}
+     * to extract and store any query arguments if the request is a GET or DELETE.
      *
      * @param path
      *            The new Path value
@@ -418,6 +446,14 @@ public abstract class HTTPSamplerBase extends AbstractSampler
         return getPropertyAsBoolean(DO_MULTIPART_POST, false);
     }
 
+    public void setDoBrowserCompatibleMultipart(boolean value) {
+        setProperty(BROWSER_COMPATIBLE_MULTIPART, value, BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT);
+    }
+
+    public boolean getDoBrowserCompatibleMultipart() {
+        return getPropertyAsBoolean(BROWSER_COMPATIBLE_MULTIPART, BROWSER_COMPATIBLE_MULTIPART_MODE_DEFAULT);
+    }
+
     public void setMonitor(String value) {
         this.setProperty(MONITOR, value);
     }
@@ -457,6 +493,14 @@ public abstract class HTTPSamplerBase extends AbstractSampler
         this.addEncodedArgument(name, value, ARG_VAL_SEP);
     }
 
+    /**
+     * Creates an HTTPArgument and adds it to the current set {@link #getArguments()} of arguments.
+     * 
+     * @param name - the parameter name
+     * @param value - the parameter value
+     * @param metaData - normally just '='
+     * @param contentEncoding - the encoding, may be null
+     */
     public void addEncodedArgument(String name, String value, String metaData, String contentEncoding) {
         if (log.isDebugEnabled()){
             log.debug("adding argument: name: " + name + " value: " + value + " metaData: " + metaData + " contentEncoding: " + contentEncoding);
@@ -528,6 +572,16 @@ public abstract class HTTPSamplerBase extends AbstractSampler
         }
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * Clears the Header Manager property so subsequent loops don't keep merging more elements
+     */
+    @Override
+    public void clearTestElementChildren(){
+        removeProperty(HEADER_MANAGER);
+    }
+
     public void setPort(int value) {
         setProperty(new IntegerProperty(PORT, value));
     }
@@ -663,10 +717,9 @@ public abstract class HTTPSamplerBase extends AbstractSampler
     public void setHeaderManager(HeaderManager value) {
         HeaderManager mgr = getHeaderManager();
         if (mgr != null) {
-            log.warn("Existing HeaderManager '" + mgr.getName() + "' merged with '" + value.getName() + "'");
             value = mgr.merge(value, true);
             if (log.isDebugEnabled()) {
-                log.debug("HeaderManager merged: " + value.getName());
+                log.debug("Existing HeaderManager '" + mgr.getName() + "' merged with '" + value.getName() + "'");
                 for (int i=0; i < value.getHeaders().size(); i++) {
                     log.debug("    " + value.getHeader(i).getName() + "=" + value.getHeader(i).getValue());
                 }
@@ -704,11 +757,11 @@ public abstract class HTTPSamplerBase extends AbstractSampler
     }
 
     public boolean isImageParser() {
-        return getPropertyAsBoolean(IMAGE_PARSER);
+        return getPropertyAsBoolean(IMAGE_PARSER, false);
     }
 
     public void setImageParser(boolean parseImages) {
-        setProperty(new BooleanProperty(IMAGE_PARSER, parseImages));
+        setProperty(IMAGE_PARSER, parseImages, false);
     }
 
     /**
@@ -875,10 +928,10 @@ public abstract class HTTPSamplerBase extends AbstractSampler
      * For each name found, addArgument() is called
      *
      * @param queryString -
-     *            the query string
+     *            the query string, might be the post body of a http post request.
      * @param contentEncoding -
-     *            the content encoding of the query string. The query string might
-     *            actually be the post body of a http post request.
+     *            the content encoding of the query string; 
+     *            if non-null then it is used to decode the 
      */
     public void parseArguments(String queryString, String contentEncoding) {
         String[] args = JOrphanUtils.split(queryString, QRY_SEP);
@@ -966,11 +1019,7 @@ public abstract class HTTPSamplerBase extends AbstractSampler
             }
             res.setSampleLabel(getName());
             return res;
-        } catch (MalformedURLException e) {
-            return errorResult(e, new HTTPSampleResult());
-        } catch (IOException e) {
-            return errorResult(e, new HTTPSampleResult());
-        } catch (URISyntaxException e) {
+        } catch (Exception e) {
             return errorResult(e, new HTTPSampleResult());
         }
     }
@@ -1090,6 +1139,10 @@ public abstract class HTTPSamplerBase extends AbstractSampler
                     log.warn("Ignoring embedded URL match string: "+e.getMessage());
                 }
             }
+            
+            // For concurrent get resources
+            final List<Callable<HTTPSampleResult>> liste = new ArrayList<Callable<HTTPSampleResult>>();
+            
             while (urls.hasNext()) {
                 Object binURL = urls.next(); // See catch clause below
                 try {
@@ -1112,9 +1165,17 @@ public abstract class HTTPSamplerBase extends AbstractSampler
                         if (pattern != null && localMatcher != null && !localMatcher.matches(urlStrEnc, pattern)) {
                             continue; // we have a pattern and the URL does not match, so skip it
                         }
-                        HTTPSampleResult binRes = sample(url, GET, false, frameDepth + 1);
-                        res.addSubResult(binRes);
-                        res.setSuccessful(res.isSuccessful() && binRes.isSuccessful());
+                        
+                        if (isConcurrentDwn()) {
+                            // if concurrent download emb. resources, add to a list for async gets later
+                            liste.add(new ASyncSample(url, GET, false, frameDepth + 1));
+                        } else {
+                            // default: serial download embedded resources
+                            HTTPSampleResult binRes = sample(url, GET, false, frameDepth + 1);
+                            res.addSubResult(binRes);
+                            res.setSuccessful(res.isSuccessful() && binRes.isSuccessful());
+                        }
+
                     }
                 } catch (ClassCastException e) { // TODO can this happen?
                     res.addSubResult(errorResult(new Exception(binURL + " is not a correct URI"), res));
@@ -1122,6 +1183,42 @@ public abstract class HTTPSamplerBase extends AbstractSampler
                     continue;
                 }
             }
+            
+            // IF for download concurrent embedded resources
+            if (isConcurrentDwn()) {
+                int poolSize = CONCURRENT_POOL_SIZE; // init with default value
+                try {
+                    poolSize = Integer.parseInt(getConcurrentPool());
+                } catch (NumberFormatException nfe) {
+                    log.warn("Concurrent download resources selected, "// $NON-NLS-1$
+                            + "but pool size value is bad. Use default value");// $NON-NLS-1$
+                }
+                // Thread pool Executor to get resources 
+                // use a LinkedBlockingQueue, note: max pool size doesn't effect
+                final ThreadPoolExecutor exec = new ThreadPoolExecutor(
+                        poolSize, poolSize, KEEPALIVETIME, TimeUnit.SECONDS,
+                        new LinkedBlockingQueue<Runnable>());
+
+                try {
+                    // sample all resources with threadpool
+                    final List<Future<HTTPSampleResult>> retExec = exec.invokeAll(liste);
+                    // call normal shutdown (wait ending all tasks)
+                    exec.shutdown();
+                    // put a timeout if tasks couldn't terminate
+                    exec.awaitTermination(AWAIT_TERMINATION_TIMEOUT, TimeUnit.SECONDS);
+
+                    // add result to main sampleResult
+                    for (Future<HTTPSampleResult> future : retExec) {
+                        final HTTPSampleResult binRes = future.get();
+                        res.addSubResult(binRes);
+                        res.setSuccessful(res.isSuccessful() && binRes.isSuccessful());
+                    }
+                } catch (InterruptedException ie) {
+                    log.warn("Interruped fetching embedded resources", ie); // $NON-NLS-1$
+                } catch (ExecutionException ee) {
+                    log.warn("Execution issue when fetching embedded resources", ee); // $NON-NLS-1$
+                }
+            }
         }
         return res;
     }
@@ -1154,11 +1251,25 @@ public abstract class HTTPSamplerBase extends AbstractSampler
         testEnded();
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void testIterationStart(LoopIterationEvent event) {
-    }
+	/**
+	 * {@inheritDoc}
+	 */
+	public void testIterationStart(LoopIterationEvent event) {
+		if (!USE_CACHED_SSL_CONTEXT) {
+			JsseSSLManager sslMgr = (JsseSSLManager) SSLManager.getInstance();
+			sslMgr.resetContext();
+			notifySSLContextWasReset();
+		}
+	}
+
+	/**
+	 * Called by testIterationStart if the SSL Context was reset.
+	 * 
+	 * This implementation does nothing.
+	 */
+	protected void notifySSLContextWasReset() {
+		// NOOP
+	}
 
     /**
      * {@inheritDoc}
@@ -1418,6 +1529,7 @@ public abstract class HTTPSamplerBase extends AbstractSampler
     // (previously these were implemented in all TestElements)
     public void threadStarted(){
     }
+
     public void threadFinished(){
     }
 
@@ -1425,7 +1537,9 @@ public abstract class HTTPSamplerBase extends AbstractSampler
      * Read response from the input stream, converting to MD5 digest if the useMD5 property is set.
      *
      * For the MD5 case, the result byte count is set to the size of the original response.
-     *
+     * 
+     * Closes the inputStream (unless there was an error)
+     * 
      * @param sampleResult
      * @param in input stream
      * @param length expected input length or zero
@@ -1531,5 +1645,68 @@ public abstract class HTTPSamplerBase extends AbstractSampler
         removeProperty(FILE_NAME);
         removeProperty(MIMETYPE);
     }
+
+    /**
+     * set IP source to use - does not apply to Java HTTP implementation currently
+     */
+    public void setIpSource(String value) {
+        setProperty(IP_SOURCE, value, "");
+    }
+
+    /**
+     * get IP source to use - does not apply to Java HTTP implementation currently
+     */
+    public String getIpSource() {
+        return getPropertyAsString(IP_SOURCE,"");
+    }
+    
+    /**
+     * Return if used a concurrent thread pool to get embedded resources.
+     *
+     * @return true if used
+     */
+    public boolean isConcurrentDwn() {
+        return getPropertyAsBoolean(CONCURRENT_DWN, false);
+    }
+
+    public void setConcurrentDwn(boolean concurrentDwn) {
+        setProperty(CONCURRENT_DWN, concurrentDwn, false);
+    }
+
+    /**
+     * Get the pool size for concurrent thread pool to get embedded resources.
+     *
+     * @return the pool size
+     */
+    public String getConcurrentPool() {
+        return getPropertyAsString(CONCURRENT_POOL,CONCURRENT_POOL_DEFAULT);
+    }
+
+    public void setConcurrentPool(String poolSize) {
+        setProperty(CONCURRENT_POOL, poolSize, CONCURRENT_POOL_DEFAULT);
+    }
+
+    /**
+     * Callable class to sample asynchronously resources embedded
+     *
+     */
+    public class ASyncSample implements Callable<HTTPSampleResult> {
+        final private URL url;
+        final private String method;
+        final private boolean areFollowingRedirect;
+        final private int depth;
+
+        public ASyncSample(URL url, String method,
+                boolean areFollowingRedirect, int depth){
+            this.url = url;
+            this.method = method;
+            this.areFollowingRedirect = areFollowingRedirect;
+            this.depth = depth;
+        }
+
+        public HTTPSampleResult call() {
+            return sample(url, method, areFollowingRedirect, depth);
+        }
+    }
 }
 
