@@ -24,19 +24,18 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Properties;
 
-import org.apache.commons.httpclient.HttpVersion;
-import org.apache.commons.httpclient.ProtocolException;
-import org.apache.commons.httpclient.params.HttpParams;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.jorphan.util.JOrphanUtils;
 import org.apache.log.Logger;
 
 /*
- * Utility class to set up default HttpClient parameters from a file
+ * Utility class to set up default HttpClient parameters from a file.
+ * 
+ * Supports both Commons HttpClient and Apache HttpClient.
+ * 
  */
 public class HttpClientDefaultParameters {
 
@@ -46,7 +45,65 @@ public class HttpClientDefaultParameters {
     private HttpClientDefaultParameters(){
     }
 
-    public static void load(String file, HttpParams params){
+    // Helper class (callback) for applying parameter definitions
+    private static abstract class GenericHttpParams {
+        public abstract void setParameter(String name, Object value);
+        public abstract void setVersion(String name, String value) throws Exception;
+    }
+
+    /**
+     * Loads a property file and converts parameters as necessary.
+     * 
+     * @param file the file to load
+     * @param params Commons HttpClient parameter instance
+     */
+    public static void load(String file, 
+            final org.apache.commons.httpclient.params.HttpParams params){
+        load(file, 
+                new GenericHttpParams (){
+                    @Override
+                    public void setParameter(String name, Object value) {
+                        params.setParameter(name, value);
+                    }
+                    @Override
+                    public void setVersion(String name, String value) throws Exception {
+                        params.setParameter(name,
+                        org.apache.commons.httpclient.HttpVersion.parse("HTTP/"+value));
+                    }            
+                }
+            );
+    }
+
+    /**
+     * Loads a property file and converts parameters as necessary.
+     * 
+     * @param file the file to load
+     * @param params Apache HttpClient parameter instance
+     */
+    public static void load(String file, 
+            final org.apache.http.params.HttpParams params){
+        load(file, 
+                new GenericHttpParams (){
+                    @Override
+                    public void setParameter(String name, Object value) {
+                        params.setParameter(name, value);
+                    }
+
+                    @Override
+                    public void setVersion(String name, String value) {
+                        String parts[] = value.split("\\.");
+                        if (parts.length != 2){
+                            throw new IllegalArgumentException("Version must have form m.n");
+                        }
+                        params.setParameter(name,
+                                new org.apache.http.HttpVersion(
+                                        Integer.parseInt(parts[0]), Integer.parseInt(parts[1])));
+                    }            
+                }
+            );
+    }
+
+    private static void load(String file, GenericHttpParams params){
         log.info("Reading httpclient parameters from "+file);
         File f = new File(file);
         InputStream is = null;
@@ -54,9 +111,7 @@ public class HttpClientDefaultParameters {
         try {
             is = new FileInputStream(f);
             props.load(is);
-            Iterator<Map.Entry<Object, Object>> pi = props.entrySet().iterator();
-            while(pi.hasNext()){
-                Map.Entry<Object, Object> me = pi.next();
+            for (Map.Entry<Object, Object> me : props.entrySet()){
                 String key = (String) me.getKey();
                 String value = (String)me.getValue();
                 int typeSep = key.indexOf("$"); // $NON-NLS-1$
@@ -71,18 +126,16 @@ public class HttpClientDefaultParameters {
                             params.setParameter(name, Long.valueOf(value));
                         } else if (type.equals("Boolean")){
                             params.setParameter(name, Boolean.valueOf(value));
-                        } else if (type.equals("HttpVersion")){
-                            params.setParameter(name, HttpVersion.parse("HTTP/"+value));
+                        } else if (type.equals("HttpVersion")){ // Commons HttpClient only
+                            params.setVersion(name, value);
                         } else {
-                            log.warn("Unexpected type: "+type);
+                            log.warn("Unexpected type: "+type+" for name "+name);
                         }
                     } else {
                             log.info("Defining "+key+ " as "+value);
                             params.setParameter(key, value);
                     }
-                } catch (NumberFormatException e) {
-                    log.error("Error in property: "+key+"="+value+" "+e.toString());
-                } catch (ProtocolException e) {
+                } catch (Exception e) {
                     log.error("Error in property: "+key+"="+value+" "+e.toString());
                 }
             }
@@ -94,8 +147,5 @@ public class HttpClientDefaultParameters {
             JOrphanUtils.closeQuietly(is);
         }
     }
-//    public static void main(String args[]){
-//        load("bin/httpclient.parameters",
-//            org.apache.commons.httpclient.params.DefaultHttpParams.getDefaultParams());
-//    }
+
 }
