@@ -26,9 +26,9 @@ import java.io.StringReader;
 import java.io.StringWriter;
 import java.net.URL;
 import java.net.MalformedURLException;
-import java.util.Enumeration;
+import java.util.Map;
 import java.util.Random;
-import java.util.Hashtable;
+import java.util.Map.Entry;
 
 import javax.xml.parsers.DocumentBuilder;
 
@@ -66,6 +66,8 @@ import org.w3c.dom.Document;
 public class WebServiceSampler extends HTTPSamplerBase {
     private static final Logger log = LoggingManager.getLoggerForClass();
 
+    private static final long serialVersionUID = 240L;
+
     //+ JMX file attribut names - do not change!
     private static final String XML_DATA = "HTTPSamper.xml_data"; //$NON-NLS-1$
 
@@ -265,6 +267,7 @@ public class WebServiceSampler extends HTTPSamplerBase {
      *
      * @return the proxy hostname
      */
+    @Override
     public String getProxyHost() {
         this.checkProxy();
         return this.getPropertyAsString(PROXY_HOST);
@@ -415,6 +418,7 @@ public class WebServiceSampler extends HTTPSamplerBase {
      * sample()
      */
 
+    @Override
     protected HTTPSampleResult sample(URL u, String s, boolean b, int i) {
         throw new RuntimeException("Not implemented - should not be called");
     }
@@ -426,6 +430,7 @@ public class WebServiceSampler extends HTTPSamplerBase {
      * reader will read, but do nothing with it. Essentially, the stream from
      * the server goes into the ether.
      */
+    @Override
     public SampleResult sample() {
         SampleResult result = new SampleResult();
         result.setSuccessful(false); // Assume it will fail
@@ -504,7 +509,9 @@ public class WebServiceSampler extends HTTPSamplerBase {
             spconn.setMaintainSession(true);
             msg.setSOAPTransport(spconn);
             msg.send(this.getUrl(), this.getSoapAction(), msgEnv);
-            result.setResponseHeaders(convertSoapHeaders(spconn.getHeaders()));
+            @SuppressWarnings("unchecked") // API uses raw types
+            final Map<String, String> headers = spconn.getHeaders();
+            result.setResponseHeaders(convertSoapHeaders(headers));
 
             if (this.getHeaderManager() != null) {
                 this.getHeaderManager().setSOAPHeader(spconn);
@@ -531,7 +538,7 @@ public class WebServiceSampler extends HTTPSamplerBase {
                     // performance on slow clients
                     length=br.read();
                     result.sampleEnd();
-                    result.setResponseData(JMeterUtils.getResString("read_response_message").getBytes()); //$NON-NLS-1$
+                    result.setResponseData(JMeterUtils.getResString("read_response_message"), null); //$NON-NLS-1$
                 }
                 // It is not possible to access the actual HTTP response code, so we assume no data means failure
                 if (length > 0){
@@ -541,7 +548,7 @@ public class WebServiceSampler extends HTTPSamplerBase {
                 } else {
                     result.setSuccessful(false);
                     result.setResponseCode("999");
-                    result.setResponseMessage("Empty response");                    
+                    result.setResponseMessage("Empty response");
                 }
             } else {
                 result.sampleEnd();
@@ -587,10 +594,10 @@ public class WebServiceSampler extends HTTPSamplerBase {
                 result.setResponseMessage(exception.toString());
             }
         } finally {
-            // Make sure the sample start time and sample end time are recorded 
-            // in order not to confuse the statistics calculation methods: if 
+            // Make sure the sample start time and sample end time are recorded
+            // in order not to confuse the statistics calculation methods: if
             //  an error occurs and an exception is thrown it is possible that
-            // the result.sampleStart() or result.sampleEnd() won't be called  
+            // the result.sampleStart() or result.sampleEnd() won't be called
             if (result.getStartTime() == 0)
             {
                 result.sampleStart();
@@ -608,15 +615,14 @@ public class WebServiceSampler extends HTTPSamplerBase {
      * implementation. We want to reuse the other parts of HTTPSampler, but not
      * the connection. The connection is handled by the Apache SOAP driver.
      */
+    @Override
     public void addEncodedArgument(String name, String value, String metaData) {
     }
 
-    public String convertSoapHeaders(Hashtable ht) {
-        Enumeration en = ht.keys();
-        StringBuffer buf = new StringBuffer();
-        while (en.hasMoreElements()) {
-            Object key = en.nextElement();
-            buf.append((String) key).append("=").append((String) ht.get(key)).append("\n"); //$NON-NLS-1$ //$NON-NLS-2$
+    public String convertSoapHeaders(Map<String, String> ht) {
+        StringBuilder buf = new StringBuilder();
+        for (Entry<String, String> entry : ht.entrySet()) {
+            buf.append(entry.getKey()).append("=").append(entry.getValue()).append("\n"); //$NON-NLS-1$ //$NON-NLS-2$
         }
         return buf.toString();
     }
@@ -627,7 +633,7 @@ public class WebServiceSampler extends HTTPSamplerBase {
 //     * @return String containing the lines
 //     */
 //    private String convertSoapHeaders(Enumeration en) {
-//        StringBuffer buf = new StringBuffer(100);
+//        StringBuilder buf = new StringBuilder(100);
 //        while (en.hasMoreElements()) {
 //            buf.append(en.nextElement()).append("\n"); //$NON-NLS-1$
 //        }
