@@ -66,7 +66,7 @@ public class LoopbackHTTPSocket extends Socket {
     private LoopbackHTTPSocket() throws IOException{
         os=new LoopbackOutputStream();
         // Preload the output so that can be read back as HTTP
-        os.write("HTTP/1.1 200 OK\r\nContent-Type: text/plain\r\n\r\n".getBytes());
+        os.write("HTTP/1.1 200 OK\r\nContent-Type: text/plain\r\n\r\n".getBytes()); // TODO - charset?
     }
 
     public LoopbackHTTPSocket(String host, int port, InetAddress localAddress, int localPort, int timeout) throws IOException {
