@@ -49,6 +49,9 @@ import org.apache.jmeter.protocol.http.control.AuthManager;
  *
  */
 public class WSDLHelper {
+    
+    private static int GET_WDSL_TIMEOUT = 5000; // timeout to retrieve wsdl when server not response
+    
     /**
      * -------------------------------------------- The members used by the
      * class to do its work --------------------------------------------
@@ -173,6 +176,8 @@ public class WSDLHelper {
     protected void connect() throws IOException {
         try {
             CONN = WSDLURL.openConnection();
+            CONN.setConnectTimeout(GET_WDSL_TIMEOUT);
+            CONN.setReadTimeout(GET_WDSL_TIMEOUT);
             // in the rare case the WSDL is protected and requires
             // authentication, use the AuthManager to set the
             // authorization. Basic and Digest authorization are
@@ -370,6 +375,20 @@ public class WSDLHelper {
         return ops.toArray();
     }
 
+    /**
+     * return the "wsdl method name" from a soap action
+     * @param soapAction the soap action
+     * @return the associated "wsdl method name" or null if not found
+     */
+    public String getSoapActionName(String soapAction) {
+        for (Map.Entry<String, String> entry : ACTIONS.entrySet()) {
+            if (entry.getValue().equals(soapAction)) {
+                return entry.getKey();
+            }
+        }
+        return null;
+    }
+    
     /**
      * Simple test for the class uses bidbuy.wsdl from Apache's soap driver
      * examples.
@@ -398,4 +417,5 @@ public class WSDLHelper {
             exception.printStackTrace();
         }
     }
+
 }
