@@ -19,22 +19,20 @@
 package org.apache.jmeter.protocol.java.sampler;
 
 import org.apache.jmeter.samplers.Entry;
+import org.apache.jmeter.samplers.Interruptible;
 import org.apache.jmeter.samplers.SampleResult;
 import org.apache.jmeter.samplers.Sampler;
-import org.apache.jmeter.threads.JMeterContext;
-import org.apache.jmeter.threads.JMeterContextService;
-import org.apache.jmeter.threads.JMeterVariables;
 import org.apache.jmeter.util.BeanShellInterpreter;
 import org.apache.jmeter.util.BeanShellTestElement;
 import org.apache.jorphan.logging.LoggingManager;
-import org.apache.jorphan.util.JOrphanUtils;
+import org.apache.jorphan.util.JMeterException;
 import org.apache.log.Logger;
 
 /**
  * A sampler which understands BeanShell
  *
  */
-public class BeanShellSampler extends BeanShellTestElement implements Sampler
+public class BeanShellSampler extends BeanShellTestElement implements Sampler, Interruptible
 {
     private static final Logger log = LoggingManager.getLoggerForClass();
 
@@ -50,21 +48,13 @@ public class BeanShellSampler extends BeanShellTestElement implements Sampler
 
     public static final String RESET_INTERPRETER = "BeanShellSampler.resetInterpreter"; //$NON-NLS-1$
 
+    private volatile BeanShellInterpreter savedBsh = null;
+    
     @Override
     protected String getInitFileProperty() {
         return INIT_FILE;
     }
 
-    /**
-     * Returns a formatted string label describing this sampler
-     *
-     * @return a formatted string label describing this sampler
-     */
-
-    public String getLabel() {
-        return getName();
-    }
-
     @Override
     public String getScript() {
         return this.getPropertyAsString(SCRIPT);
@@ -90,7 +80,7 @@ public class BeanShellSampler extends BeanShellTestElement implements Sampler
         // log.info(getLabel()+" "+getFilename());
         SampleResult res = new SampleResult();
         boolean isSuccessful = false;
-        res.setSampleLabel(getLabel());
+        res.setSampleLabel(getName());
         res.sampleStart();
         final BeanShellInterpreter bshInterpreter = getBeanShellInterpreter();
         if (bshInterpreter == null) {
@@ -109,35 +99,18 @@ public class BeanShellSampler extends BeanShellTestElement implements Sampler
                 res.setSamplerData(fileName);
             }
 
-            bshInterpreter.set("Label", getLabel()); //$NON-NLS-1$
-            bshInterpreter.set("FileName", getFilename()); //$NON-NLS-1$
             bshInterpreter.set("SampleResult", res); //$NON-NLS-1$
 
-            // Save parameters as single line and as string array
-            bshInterpreter.set("Parameters", getParameters());//$NON-NLS-1$
-            bshInterpreter.set("bsh.args", //$NON-NLS-1$
-                    JOrphanUtils.split(getParameters(), " "));//$NON-NLS-1$
-
             // Set default values
             bshInterpreter.set("ResponseCode", "200"); //$NON-NLS-1$
             bshInterpreter.set("ResponseMessage", "OK");//$NON-NLS-1$
             bshInterpreter.set("IsSuccess", true);//$NON-NLS-1$
 
-            // Add variables for access to context and variables
-            JMeterContext jmctx = JMeterContextService.getContext();
-            JMeterVariables vars = jmctx.getVariables();
-            bshInterpreter.set("ctx", jmctx);//$NON-NLS-1$
-            bshInterpreter.set("vars", vars);//$NON-NLS-1$
-
             res.setDataType(SampleResult.TEXT); // assume text output - script can override if necessary
 
-            Object bshOut;
-
-            if (fileName.length() == 0) {
-                bshOut = bshInterpreter.eval(request);
-            } else {
-                bshOut = bshInterpreter.source(fileName);
-            }
+            savedBsh = bshInterpreter;
+            Object bshOut = processFileOrScript(bshInterpreter);
+            savedBsh = null;
 
             if (bshOut != null) {// Set response data
                 String out = bshOut.toString();
@@ -167,6 +140,8 @@ public class BeanShellSampler extends BeanShellTestElement implements Sampler
             log.warn(ex.toString());
             res.setResponseCode("500");//$NON-NLS-1$
             res.setResponseMessage(ex.toString());
+        } finally {
+            savedBsh = null;
         }
 
         res.sampleEnd();
@@ -176,4 +151,16 @@ public class BeanShellSampler extends BeanShellTestElement implements Sampler
 
         return res;
     }
+
+    public boolean interrupt() {
+        if (savedBsh != null) {
+            try {
+                savedBsh.evalNoLog("interrupt()"); // $NON-NLS-1$
+            } catch (JMeterException ignored) {
+                log.debug(getClass().getName() + " : " + ignored.getLocalizedMessage()); // $NON-NLS-1$
+            }
+            return true;
+        }
+        return false;
+    }
 }
