@@ -18,14 +18,14 @@
 
 package org.apache.jmeter.protocol.jms.client;
 
-import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Properties;
+import java.util.concurrent.ConcurrentHashMap;
 
 import javax.naming.Context;
 import javax.naming.InitialContext;
 import javax.naming.NamingException;
 
+import org.apache.commons.lang.StringUtils;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.log.Logger;
 
@@ -34,8 +34,7 @@ import org.apache.log.Logger;
  */
 public class InitialContextFactory {
 
-    //GuardedBy("this")
-    private static final HashMap<String, Context> MAP = new HashMap<String, Context>();
+    private static final ConcurrentHashMap<String, Context> MAP = new ConcurrentHashMap<String, Context>();
 
     private static final Logger log = LoggingManager.getLoggerForClass();
 
@@ -50,9 +49,10 @@ public class InitialContextFactory {
      * @return the context, never null
      * @throws NamingException 
      */
-    public static synchronized Context lookupContext(String initialContextFactory, 
+    public static Context lookupContext(String initialContextFactory, 
             String providerUrl, boolean useAuth, String securityPrincipal, String securityCredentials) throws NamingException {
-        Context ctx = MAP.get(initialContextFactory + providerUrl);
+        String cacheKey = createKey(initialContextFactory ,providerUrl, securityPrincipal, securityCredentials);
+        Context ctx = MAP.get(cacheKey);
         if (ctx == null) {
             Properties props = new Properties();
             props.setProperty(Context.INITIAL_CONTEXT_FACTORY, initialContextFactory);
@@ -70,11 +70,38 @@ public class InitialContextFactory {
             } catch (Exception e) {
                 throw new NamingException(e.toString());
             }
-            MAP.put(initialContextFactory + providerUrl, ctx);
+            // we want to return the context that is actually in the map
+            ctx = MAP.putIfAbsent(cacheKey, ctx);
         }
         return ctx;
     }
 
+    /**
+     * Create cache key
+     * @param initialContextFactory
+     * @param providerUrl
+     * @param securityPrincipal
+     * @param securityCredentials
+     * @return
+     */
+    private static String createKey(String initialContextFactory,
+            String providerUrl, String securityPrincipal,
+            String securityCredentials) {
+       StringBuilder builder = new StringBuilder();
+       builder.append(initialContextFactory);
+       builder.append("#");
+       builder.append(providerUrl);
+       builder.append("#");
+       if(!StringUtils.isEmpty(securityPrincipal)) {
+           builder.append(securityPrincipal);
+           builder.append("#");
+       }
+       if(!StringUtils.isEmpty(securityCredentials)) {
+           builder.append(securityCredentials);
+       }
+       return builder.toString();
+    }
+
     /**
      * Initialize the JNDI initial context
      *
@@ -103,13 +130,12 @@ public class InitialContextFactory {
             return lookupContext(initialContextFactory, providerUrl, useAuth, securityPrincipal, securityCredentials);
         }
     }
+    
     /**
      * clear all the InitialContext objects.
      */
-    public synchronized static void close() { // TODO - why is this not used?
-        Iterator<?> itr = MAP.keySet().iterator();
-        while (itr.hasNext()) {
-            Context ctx = MAP.get(itr.next());
+    public static void close() {
+        for (Context ctx : MAP.values()) {
             try {
                 ctx.close();
             } catch (NamingException e) {
@@ -119,4 +145,4 @@ public class InitialContextFactory {
         MAP.clear();
         log.info("InitialContextFactory.close() called and Context instances cleaned up");
     }
-}
+}
\ No newline at end of file
