@@ -29,6 +29,7 @@ import javax.jms.Message;
 import javax.jms.MessageConsumer;
 import javax.jms.MessageListener;
 import javax.jms.Session;
+import javax.jms.Topic;
 import javax.naming.Context;
 import javax.naming.NamingException;
 
@@ -81,16 +82,24 @@ public class ReceiveSubscriber implements Closeable, MessageListener {
      */
     public ReceiveSubscriber(boolean useProps, 
             String initialContextFactory, String providerUrl, String connfactory, String destinationName,
-            boolean useAuth, 
+            String durableSubscriptionId, boolean useAuth, 
             String securityPrincipal, String securityCredentials) throws NamingException, JMSException {
-        Context ctx = InitialContextFactory.getContext(useProps, 
-                initialContextFactory, providerUrl, useAuth, securityPrincipal, securityCredentials);
-        CONN = Utils.getConnection(ctx, connfactory);
-        SESSION = CONN.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Destination dest = Utils.lookupDestination(ctx, destinationName);
-        SUBSCRIBER = SESSION.createConsumer(dest);
-        queue = null;
-        log.debug("<init> complete");
+        boolean initSuccess = false;
+        try{
+            Context ctx = InitialContextFactory.getContext(useProps, 
+                    initialContextFactory, providerUrl, useAuth, securityPrincipal, securityCredentials);
+            CONN = Utils.getConnection(ctx, connfactory);
+            SESSION = CONN.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            Destination dest = Utils.lookupDestination(ctx, destinationName);
+           	SUBSCRIBER = createSubscriber(SESSION, dest, durableSubscriptionId);
+            queue = null;
+            log.debug("<init> complete");
+            initSuccess = true;
+        } finally {
+            if(!initSuccess) {
+                close();
+            }
+        }
     }
 
     /**
@@ -114,21 +123,51 @@ public class ReceiveSubscriber implements Closeable, MessageListener {
      */
     public ReceiveSubscriber(int queueSize, boolean useProps, 
             String initialContextFactory, String providerUrl, String connfactory, String destinationName,
-            boolean useAuth, 
+            String durableSubscriptionId, boolean useAuth, 
             String securityPrincipal, String securityCredentials) throws NamingException, JMSException {
-        Context ctx = InitialContextFactory.getContext(useProps, 
-                initialContextFactory, providerUrl, useAuth, securityPrincipal, securityCredentials);
-        CONN = Utils.getConnection(ctx, connfactory);
-        SESSION = CONN.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Destination dest = Utils.lookupDestination(ctx, destinationName);
-        SUBSCRIBER = SESSION.createConsumer(dest);
-        if (queueSize <=0) {
-            queue = new LinkedBlockingQueue<Message>();
-        } else {
-            queue = new LinkedBlockingQueue<Message>(queueSize);            
+        boolean initSuccess = false;
+        try{
+            Context ctx = InitialContextFactory.getContext(useProps, 
+                    initialContextFactory, providerUrl, useAuth, securityPrincipal, securityCredentials);
+            CONN = Utils.getConnection(ctx, connfactory);
+            SESSION = CONN.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            Destination dest = Utils.lookupDestination(ctx, destinationName);
+            SUBSCRIBER = createSubscriber(SESSION, dest, durableSubscriptionId);
+            if (queueSize <=0) {
+                queue = new LinkedBlockingQueue<Message>();
+            } else {
+                queue = new LinkedBlockingQueue<Message>(queueSize);            
+            }
+            SUBSCRIBER.setMessageListener(this);
+            log.debug("<init> complete");
+            initSuccess = true;
         }
-        SUBSCRIBER.setMessageListener(this);
-        log.debug("<init> complete");
+        finally {
+            if(!initSuccess) {
+                close();
+            }
+        }
+    }
+    
+    /**
+     * Return a simple MessageConsumer or a TopicSubscriber (as a durable subscription)
+     * @param session
+     * 				JMS session	
+     * @param destination
+     * 				JMS destination, can be either topic or queue
+     * @param durableSubscriptionId 
+     * 				If neither empty nor null, this means that a durable 
+     * 				subscription will be used
+     * @return
+     * @throws JMSException
+     */
+    private MessageConsumer createSubscriber(Session session, 
+    		Destination destination, String durableSubscriptionId) throws JMSException {
+    	if (isEmpty(durableSubscriptionId)) {
+        	return  session.createConsumer(destination);
+        } else {
+        	return session.createDurableSubscriber((Topic) destination, durableSubscriptionId); 
+        }	
     }
 
     /**
@@ -186,7 +225,9 @@ public class ReceiveSubscriber implements Closeable, MessageListener {
     public void close() { // called from threadFinished() thread
         log.debug("close()");
         try {
-            CONN.stop();
+            if(CONN != null) {
+                CONN.stop();
+            }
         } catch (JMSException e) {
             log.error(e.getMessage());
         }
@@ -204,4 +245,16 @@ public class ReceiveSubscriber implements Closeable, MessageListener {
             log.warn("Could not add message to queue");
         }
     }
+    
+    
+    /**
+     * Checks whether string is empty
+     * 
+     * @param s1
+     * @return True if input is null, an empty string, 
+     * 				or a white space-only string
+     */
+    private boolean isEmpty(String s1) {
+    	return (s1 == null || s1.trim().equals(""));
+    }
 }
