@@ -40,6 +40,7 @@ import javax.naming.NamingException;
 
 import org.apache.jmeter.config.Arguments;
 import org.apache.jmeter.engine.event.LoopIterationEvent;
+import org.apache.jmeter.protocol.jms.Utils;
 import org.apache.jmeter.samplers.AbstractSampler;
 import org.apache.jmeter.samplers.Entry;
 import org.apache.jmeter.samplers.SampleResult;
@@ -61,6 +62,7 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
     private static final long serialVersionUID = 233L;
 
     private static final int DEFAULT_TIMEOUT = 2000;
+    private static final String DEFAULT_TIMEOUT_STRING = Integer.toString(DEFAULT_TIMEOUT);
 
     //++ These are JMX names, and must not be changed
     private static final String JNDI_INITIAL_CONTEXT_FACTORY = "JMSSampler.initialContextFactory"; // $NON-NLS-1$
@@ -87,17 +89,20 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
 
     private static final String USE_REQ_MSGID_AS_CORRELID = "JMSSampler.useReqMsgIdAsCorrelId"; // $NON-NLS-1$
 
+    private static final String USE_RES_MSGID_AS_CORRELID = "JMSSampler.useResMsgIdAsCorrelId"; // $NON-NLS-1$
+
+    private static final boolean USE_RES_MSGID_AS_CORRELID_DEFAULT = false; // Default to be applied
+
+
     //--
 
     // Should we use java.naming.security.[principal|credentials] to create the QueueConnection?
-    private static final boolean USE_SECURITY_PROPERTIES = 
+    private static final boolean USE_SECURITY_PROPERTIES =
         JMeterUtils.getPropDefault("JMSSampler.useSecurity.properties", true); // $NON-NLS-1$
-    
+
     //
     // Member variables
     //
-    /** Factory for the connections to the queueing system. */
-    // NOTUSED private QueueConnectionFactory factory;
     /** Queue for receiving messages (if applicable). */
     private transient Queue receiveQueue;
 
@@ -107,11 +112,6 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
     /** Connection to the queueing system. */
     private transient QueueConnection connection;
 
-    /** Queue for sending messages. */
-    private transient Queue sendQueue;
-
-    /** Is the communication oneway? */
-    // NOTUSED private boolean oneway;
     /** The executor for (pseudo) synchronous communication. */
     private transient QueueExecutor executor;
 
@@ -120,49 +120,52 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
 
     private transient Receiver receiverThread = null;
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jmeter.samplers.Sampler#sample(org.apache.jmeter.samplers.Entry)
+    private transient Throwable thrown = null;
+
+    /**
+     * {@inheritDoc}
      */
     public SampleResult sample(Entry entry) {
         SampleResult res = new SampleResult();
         res.setSampleLabel(getName());
         res.setSamplerData(getContent());
+        res.setSuccessful(false); // Assume failure
         res.setDataType(SampleResult.TEXT);
         res.sampleStart();
 
         try {
             TextMessage msg = createMessage();
-
             if (isOneway()) {
                 producer.send(msg);
-                res.setSuccessful(true);
-                res.setResponseData("Oneway request has no response data".getBytes());
+                res.setRequestHeaders(Utils.messageProperties(msg));
+                res.setResponseOK();
+                res.setResponseData("Oneway request has no response data", null);
             } else {
                 if (!useTemporyQueue()) {
                     msg.setJMSReplyTo(receiveQueue);
                 }
 
                 Message replyMsg = executor.sendAndReceive(msg);
+                res.setRequestHeaders(Utils.messageProperties(msg));
                 if (replyMsg == null) {
-                    res.setSuccessful(false);
-                    if (LOGGER.isDebugEnabled()) {
-                        LOGGER.debug("No reply message received");
-                    }
+                    res.setResponseMessage("No reply message received");
                 } else {
                     if (replyMsg instanceof TextMessage) {
-                        res.setResponseData(((TextMessage) replyMsg).getText().getBytes());
+                        res.setResponseData(((TextMessage) replyMsg).getText(), null);
                     } else {
-                        res.setResponseData(replyMsg.toString().getBytes());
+                        res.setResponseData(replyMsg.toString(), null);
                     }
-                    res.setSuccessful(true);
+                    res.setResponseHeaders(Utils.messageProperties(replyMsg));
+                    res.setResponseOK();
                 }
             }
         } catch (Exception e) {
             LOGGER.warn(e.getLocalizedMessage(), e);
-            res.setResponseData(new byte[0]);
-            res.setSuccessful(false);
+            if (thrown != null){
+                res.setResponseMessage(thrown.toString());
+            } else {                
+                res.setResponseMessage(e.getLocalizedMessage());
+            }
         }
         res.sampleEnd();
         return res;
@@ -179,16 +182,16 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
     }
 
     private void addJMSProperties(TextMessage msg) throws JMSException {
-        Map map = getArguments(JMSSampler.JMS_PROPERTIES).getArgumentsAsMap();
-        Iterator argIt = map.entrySet().iterator();
+        Map<String, String> map = getArguments(JMSSampler.JMS_PROPERTIES).getArgumentsAsMap();
+        Iterator<Map.Entry<String, String>>  argIt = map.entrySet().iterator();
         while (argIt.hasNext()) {
-            Map.Entry me = (Map.Entry) argIt.next();
-            String name = (String) me.getKey();
-            String value = (String) me.getValue();
+            Map.Entry<String, String> me = argIt.next();
+            String name = me.getKey();
+            String value = me.getValue();
             if (LOGGER.isDebugEnabled()) {
                 LOGGER.debug("Adding property [" + name + "=" + value + "]");
             }
-            
+
             // WebsphereMQ does not allow corr. id. to be set using setStringProperty()
             if("JMSCorrelationID".equalsIgnoreCase(name)) { // $NON-NLS-1$
                 msg.setJMSCorrelationID(value);
@@ -254,10 +257,24 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
         return getPropertyAsBoolean(IS_NON_PERSISTENT);
     }
 
+    /**
+     * Which request field to use for correlation?
+     * 
+     * @return true if correlation should use the request JMSMessageID rather than JMSCorrelationID
+     */
     public boolean isUseReqMsgIdAsCorrelId() {
         return getPropertyAsBoolean(USE_REQ_MSGID_AS_CORRELID);
     }
 
+    /**
+     * Which response field to use for correlation?
+     * 
+     * @return true if correlation should use the response JMSMessageID rather than JMSCorrelationID
+     */
+    public boolean isUseResMsgIdAsCorrelId() {
+        return getPropertyAsBoolean(USE_RES_MSGID_AS_CORRELID, USE_RES_MSGID_AS_CORRELID_DEFAULT);
+    }
+
     public String getInitialContextFactory() {
         return getPropertyAsString(JMSSampler.JNDI_INITIAL_CONTEXT_FACTORY);
     }
@@ -278,6 +295,11 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
         setProperty(new BooleanProperty(USE_REQ_MSGID_AS_CORRELID, value));
     }
 
+    public void setUseResMsgIdAsCorrelId(boolean value) {
+        setProperty(USE_RES_MSGID_AS_CORRELID, value, USE_RES_MSGID_AS_CORRELID_DEFAULT);
+    }
+
+    @Override
     public String toString() {
         return getQueueConnectionFactory() + ", queue: " + getSendQueue();
     }
@@ -290,29 +312,30 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
         logThreadStart();
 
         Context context = null;
+        thrown = null;
         try {
             context = getInitialContext();
             Object obj = context.lookup(getQueueConnectionFactory());
             if (!(obj instanceof QueueConnectionFactory)) {
-                String msg = "QueueConnectionFactory expected, but got " 
+                String msg = "QueueConnectionFactory expected, but got "
                     + obj == null ? "null" :  obj.getClass().getName();
                 LOGGER.fatalError(msg);
                 throw new IllegalStateException(msg);
             }
             QueueConnectionFactory factory = (QueueConnectionFactory) obj;
-            Queue queue = (Queue) context.lookup(getSendQueue());
+            Queue sendQueue = (Queue) context.lookup(getSendQueue());
 
-            sendQueue = queue;
             if (!useTemporyQueue()) {
                 receiveQueue = (Queue) context.lookup(getReceiveQueue());
-                receiverThread = Receiver.createReceiver(factory, receiveQueue, getPrincipal(context), getCredentials(context));
+                receiverThread = Receiver.createReceiver(factory, receiveQueue, getPrincipal(context), getCredentials(context)
+                        , isUseResMsgIdAsCorrelId());
             }
 
             String principal = null;
             String credentials = null;
             if (USE_SECURITY_PROPERTIES){
                 principal = getPrincipal(context);
-                credentials = getCredentials(context);                
+                credentials = getCredentials(context);
             }
             if (principal != null && credentials != null) {
                 connection = factory.createQueueConnection(principal, credentials);
@@ -340,7 +363,7 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
                     if (isNonPersistent()) {
                         producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
                     }
-                    executor = new FixedQueueExecutor(producer, getTimeout(), isUseReqMsgIdAsCorrelId());
+                    executor = new FixedQueueExecutor(producer, getTimeoutAsInt(), isUseReqMsgIdAsCorrelId());
                 }
             }
             if (LOGGER.isDebugEnabled()) {
@@ -352,10 +375,12 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
             if (LOGGER.isDebugEnabled()) {
                 LOGGER.debug("Connection started");
             }
-        } catch (JMSException e) {
-            LOGGER.warn(e.getLocalizedMessage(), e);
-        } catch (NamingException e) {
-            LOGGER.warn(e.getLocalizedMessage(), e);
+        } catch (Exception e) {
+            thrown = e;
+            LOGGER.error(e.getLocalizedMessage(), e);
+        } catch (NoClassDefFoundError e) {
+            thrown = e;
+            LOGGER.error(e.getLocalizedMessage(), e);
         } finally {
             if (context != null) {
                 try {
@@ -368,7 +393,7 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
     }
 
     private Context getInitialContext() throws NamingException {
-        Hashtable table = new Hashtable();
+        Hashtable<String, String> table = new Hashtable<String, String>();
 
         if (getInitialContextFactory() != null && getInitialContextFactory().trim().length() > 0) {
             if (LOGGER.isDebugEnabled()) {
@@ -382,7 +407,7 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
             }
             table.put(Context.PROVIDER_URL, getContextProvider());
         }
-        Map map = getArguments(JMSSampler.JNDI_PROPERTIES).getArgumentsAsMap();
+        Map<String, String> map = getArguments(JMSSampler.JNDI_PROPERTIES).getArgumentsAsMap();
         if (LOGGER.isDebugEnabled()) {
             if (map.isEmpty()) {
                 LOGGER.debug("Empty JNDI properties");
@@ -390,9 +415,9 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
                 LOGGER.debug("Number of JNDI properties: " + map.size());
             }
         }
-        Iterator it = map.entrySet().iterator();
+        Iterator<Map.Entry<String, String>> it = map.entrySet().iterator();
         while (it.hasNext()) {
-            Map.Entry me = (Map.Entry) it.next();
+            Map.Entry<String, String> me = it.next();
             table.put(me.getKey(), me.getValue());
         }
 
@@ -404,11 +429,12 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
     }
 
     private void printEnvironment(Context context) throws NamingException {
-        Hashtable env = context.getEnvironment();
+        Hashtable<?,?> env = context.getEnvironment();
         LOGGER.debug("Initial Context Properties");
-        Enumeration keys = env.keys();
+        @SuppressWarnings("unchecked")
+        Enumeration<String> keys = (Enumeration<String>) env.keys();
         while (keys.hasMoreElements()) {
-            String key = (String) keys.nextElement();
+            String key = keys.nextElement();
             LOGGER.debug(key + "=" + env.get(key));
         }
     }
@@ -424,35 +450,25 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
         }
     }
 
-    public int getTimeout() {
+    private int getTimeoutAsInt() {
         if (getPropertyAsInt(TIMEOUT) < 1) {
             return DEFAULT_TIMEOUT;
         }
         return getPropertyAsInt(TIMEOUT);
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jmeter.testelement.TestElement#threadFinished()
+    public String getTimeout() {
+        return getPropertyAsString(TIMEOUT, DEFAULT_TIMEOUT_STRING);
+    }
+
+    /**
+     * {@inheritDoc}
      */
     public void threadFinished() {
         LOGGER.debug("Thread ended " + new Date());
 
-        if (session != null) {
-            try {
-                session.close();
-            } catch (JMSException e) {
-                LOGGER.info(e.getLocalizedMessage());
-            }
-        }
-        if (connection != null) {
-            try {
-                connection.close();
-            } catch (JMSException e) {
-                LOGGER.info(e.getLocalizedMessage());
-            }
-        }
+        Utils.close(session, LOGGER);
+        Utils.close(connection, LOGGER);
         if (receiverThread != null) {
             receiverThread.deactivate();
         }
@@ -499,7 +515,7 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
      * @throws NamingException
      */
     private String getPrincipal(Context context) throws NamingException{
-            Hashtable env = context.getEnvironment();
+            Hashtable<?,?> env = context.getEnvironment();
             return (String) env.get("java.naming.security.principal"); // $NON-NLS-1$
     }
 
@@ -511,7 +527,7 @@ public class JMSSampler extends AbstractSampler implements ThreadListener {
      * @throws NamingException
      */
     private String getCredentials(Context context) throws NamingException{
-            Hashtable env = context.getEnvironment();
+            Hashtable<?,?> env = context.getEnvironment();
             return (String) env.get("java.naming.security.credentials"); // $NON-NLS-1$
     }
 
