@@ -18,12 +18,18 @@
 
 package org.apache.jmeter.protocol.jms.sampler;
 
+import javax.jms.Connection;
+import javax.jms.ConnectionFactory;
+import javax.jms.Destination;
+import javax.jms.JMSException;
+import javax.jms.Message;
+import javax.jms.MessageConsumer;
+import javax.jms.Session;
+
 import org.apache.jmeter.protocol.jms.Utils;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.log.Logger;
 
-import javax.jms.*;
-
 /**
  * Receiver of pseudo-synchronous reply messages.
  *
@@ -72,7 +78,7 @@ public class Receiver implements Runnable {
             String principal, String credentials, boolean useResMsgIdAsCorrelId)
             throws JMSException {
         Receiver receiver = new Receiver(factory, receiveQueue, principal, credentials, useResMsgIdAsCorrelId);
-        Thread thread = new Thread(receiver);
+        Thread thread = new Thread(receiver, "JMS Receiever");
         thread.start();
         return receiver;
     }
