@@ -25,18 +25,21 @@ import javax.jms.Message;
 import javax.jms.TextMessage;
 import javax.naming.NamingException;
 
+import org.apache.jmeter.engine.event.LoopIterationEvent;
 import org.apache.jmeter.protocol.jms.Utils;
+import org.apache.jmeter.protocol.jms.client.InitialContextFactory;
 import org.apache.jmeter.protocol.jms.client.ReceiveSubscriber;
 import org.apache.jmeter.protocol.jms.control.gui.JMSSubscriberGui;
 import org.apache.jmeter.samplers.Interruptible;
 import org.apache.jmeter.samplers.SampleResult;
+import org.apache.jmeter.testelement.TestListener;
 import org.apache.jmeter.testelement.ThreadListener;
 import org.apache.jmeter.util.JMeterUtils;
 import org.apache.jorphan.logging.LoggingManager;
 import org.apache.log.Logger;
 
 /**
- * This class implements the JMS Subcriber sampler.
+ * This class implements the JMS Subscriber sampler.
  * It supports both receive and onMessage strategies via the ReceiveSubscriber class.
  * 
  */
@@ -48,14 +51,14 @@ import org.apache.log.Logger;
 // Note: originally the code did use the ClientPool to "share" subscribers, however since the
 // key was "this" and each sampler is unique - nothing was actually shared.
 
-public class SubscriberSampler extends BaseJMSSampler implements Interruptible, ThreadListener {
+public class SubscriberSampler extends BaseJMSSampler implements Interruptible, ThreadListener, TestListener {
 
     private static final long serialVersionUID = 240L;
 
     private static final Logger log = LoggingManager.getLoggerForClass();
 
     // Default wait (ms) for a message if timeouts are not enabled
-    // This is the maximimum time the sampler can be blocked.
+    // This is the maximum time the sampler can be blocked.
     private static final long DEFAULT_WAIT = 500L;
 
     // No need to synch/ - only used by sampler and ClientPool (which does its own synch)
@@ -64,10 +67,10 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
     private transient volatile boolean interrupted = false;
 
     private transient long timeout;
-
+    
     private transient boolean useReceive;
 
-    // This will be null iff initialisation succeeeds.
+    // This will be null if initialization succeeds.
     private transient Exception exceptionDuringInit;
 
     // If true, start/stop subscriber for each sample
@@ -77,8 +80,11 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
     private static final String CLIENT_CHOICE = "jms.client_choice"; // $NON-NLS-1$
     private static final String TIMEOUT = "jms.timeout"; // $NON-NLS-1$
     private static final String TIMEOUT_DEFAULT = "";
+    private static final String DURABLE_SUBSCRIPTION_ID = "jms.durableSubscriptionId"; // $NON-NLS-1$
+    private static final String DURABLE_SUBSCRIPTION_ID_DEFAULT = "";
     private static final String STOP_BETWEEN = "jms.stop_between_samples"; // $NON-NLS-1$
-
+    
+    private transient boolean START_ON_SAMPLE = false;
 
     public SubscriberSampler() {
     }
@@ -92,7 +98,7 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
      */
     private void initListenerClient() throws JMSException, NamingException {
         SUBSCRIBER = new ReceiveSubscriber(0, getUseJNDIPropertiesAsBoolean(), getJNDIInitialContextFactory(),
-                    getProviderUrl(), getConnectionFactory(), getDestination(), 
+                    getProviderUrl(), getConnectionFactory(), getDestination(), getDurableSubscriptionId(),
                     isUseAuth(), getUsername(), getPassword());
         log.debug("SubscriberSampler.initListenerClient called");
     }
@@ -105,7 +111,7 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
     private void initReceiveClient() throws NamingException, JMSException {
         SUBSCRIBER = new ReceiveSubscriber(getUseJNDIPropertiesAsBoolean(),
                 getJNDIInitialContextFactory(), getProviderUrl(), getConnectionFactory(), getDestination(),
-                isUseAuth(), getUsername(), getPassword());
+                getDurableSubscriptionId(), isUseAuth(), getUsername(), getPassword());
         log.debug("SubscriberSampler.initReceiveClient called");
     }
 
@@ -118,6 +124,10 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
     // TODO - should we call start() and stop()?
     @Override
     public SampleResult sample() {
+        // run threadStarted only if Destination setup on each sample
+        if (!isDestinationStatic()) {
+            threadStarted(true);
+        }
         SampleResult result = new SampleResult();
         result.setDataType(SampleResult.TEXT);
         result.setSampleLabel(getName());
@@ -165,9 +175,9 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
         result.sampleEnd();
         result.setResponseMessage(read + " samples messages received");
         if (getReadResponseAsBoolean()) {
-            result.setResponseData(buffer.toString().getBytes());
+            result.setResponseData(buffer.toString().getBytes()); // TODO - charset?
         } else {
-            result.setBytes(buffer.toString().getBytes().length);
+            result.setBytes(buffer.toString().getBytes().length); // TODO - charset?
         }
         result.setResponseHeaders(propBuffer.toString());
         if (read == 0) {
@@ -188,6 +198,10 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
                 log.warn("Problem stopping subscriber", e);
             }
         }
+        // run threadFinished only if Destination setup on each sample (stop Listen queue)
+        if (!isDestinationStatic()) {
+            threadFinished(true);
+        }
         return result;
     }
 
@@ -238,37 +252,47 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
      * {@inheritDoc}
      */
     public void threadStarted() {
-        timeout = getTimeoutAsLong();
-        interrupted = false;
-        exceptionDuringInit = null;
-        useReceive = getClientChoice().equals(JMSSubscriberGui.RECEIVE_RSC);
-        stopBetweenSamples = isStopBetweenSamples();
-        if (useReceive) {
-            try {
-                initReceiveClient();
-                if (!stopBetweenSamples){ // Don't start yet if stop between samples
-                    SUBSCRIBER.start();
+        // Disabled thread start if listen on sample choice
+        if (isDestinationStatic() || START_ON_SAMPLE) {
+            timeout = getTimeoutAsLong();
+            interrupted = false;
+            exceptionDuringInit = null;
+            useReceive = getClientChoice().equals(JMSSubscriberGui.RECEIVE_RSC);
+            stopBetweenSamples = isStopBetweenSamples();
+            if (useReceive) {
+                try {
+                    initReceiveClient();
+                    if (!stopBetweenSamples){ // Don't start yet if stop between samples
+                        SUBSCRIBER.start();
+                    }
+                } catch (NamingException e) {
+                    exceptionDuringInit = e;
+                } catch (JMSException e) {
+                    exceptionDuringInit = e;
+                }
+            } else {
+                try {
+                    initListenerClient();
+                    if (!stopBetweenSamples){ // Don't start yet if stop between samples
+                        SUBSCRIBER.start();
+                    }
+                } catch (JMSException e) {
+                    exceptionDuringInit = e;
+                } catch (NamingException e) {
+                    exceptionDuringInit = e;
                 }
-            } catch (NamingException e) {
-                exceptionDuringInit = e;
-            } catch (JMSException e) {
-                exceptionDuringInit = e;
             }
-        } else {
-            try {
-                initListenerClient();
-                if (!stopBetweenSamples){ // Don't start yet if stop between samples
-                    SUBSCRIBER.start();
-                }
-            } catch (JMSException e) {
-                exceptionDuringInit = e;
-            } catch (NamingException e) {
-                exceptionDuringInit = e;
+            if (exceptionDuringInit != null){
+                log.error("Could not initialise client",exceptionDuringInit);
             }
         }
-        if (exceptionDuringInit != null){
-            log.error("Could not initialise client",exceptionDuringInit);
+    }
+    
+    public void threadStarted(boolean wts) {
+        if (wts) {
+            START_ON_SAMPLE = true; // listen on sample 
         }
+        threadStarted();
     }
 
     /**
@@ -281,6 +305,13 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
             SUBSCRIBER.close();
         }
     }
+    
+    public void threadFinished(boolean wts) {
+        if (wts) {
+            START_ON_SAMPLE = false; // listen on sample
+        }
+        threadFinished();
+    }
 
     /**
      * Handle an interrupt of the test.
@@ -327,6 +358,14 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
     public void setTimeout(String timeout){
         setProperty(TIMEOUT, timeout, TIMEOUT_DEFAULT);        
     }
+    
+    public String getDurableSubscriptionId(){
+        return getPropertyAsString(DURABLE_SUBSCRIPTION_ID);
+    }
+
+    public void setDurableSubscriptionId(String durableSubscriptionId){
+        setProperty(DURABLE_SUBSCRIPTION_ID, durableSubscriptionId, DURABLE_SUBSCRIPTION_ID_DEFAULT);        
+    }
 
     // This was the old value that was checked for
     private final static String RECEIVE_STR = JMeterUtils.getResString(JMSSubscriberGui.RECEIVE_RSC); // $NON-NLS-1$
@@ -339,4 +378,38 @@ public class SubscriberSampler extends BaseJMSSampler implements Interruptible,
         setProperty(STOP_BETWEEN, selected, false);                
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    public void testEnded() {
+        InitialContextFactory.close();
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public void testEnded(String host) {
+        testEnded();
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public void testIterationStart(LoopIterationEvent event) {
+        //NOOP
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public void testStarted() {
+        //NOOP
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    public void testStarted(String host) {
+        // NOOP        
+    }
 }
