@@ -58,6 +58,9 @@ import org.apache.jorphan.gui.JLabeledChoice;
  ******************************************************************************/
 
 public class LdapExtConfigGui extends AbstractConfigGui implements ItemListener {
+
+    private static final long serialVersionUID = 240L;
+
     // private final static String ROOTDN = "rootDn";
     // private final static String TEST = "tesT";
     // private static String testValue="NNNN";
@@ -160,9 +163,9 @@ public class LdapExtConfigGui extends AbstractConfigGui implements ItemListener
 
     private boolean displayName = true;
 
-    ArgumentsPanel tableAddPanel = new ArgumentsPanel(JMeterUtils.getResString("addtest")); // $NON-NLS-1$
+    private ArgumentsPanel tableAddPanel = new ArgumentsPanel(JMeterUtils.getResString("addtest")); // $NON-NLS-1$
 
-    LDAPArgumentsPanel tableModifyPanel = new LDAPArgumentsPanel(JMeterUtils.getResString("modtest")); // $NON-NLS-1$
+    private LDAPArgumentsPanel tableModifyPanel = new LDAPArgumentsPanel(JMeterUtils.getResString("modtest")); // $NON-NLS-1$
 
     private JPanel cards;
 
@@ -197,6 +200,7 @@ public class LdapExtConfigGui extends AbstractConfigGui implements ItemListener
      * @param element
      *            the TestElement to configure
      */
+    @Override
     public void configure(TestElement element) {
         super.configure(element);
         servername.setText(element.getPropertyAsString(LDAPExtSampler.SERVERNAME));
@@ -227,7 +231,7 @@ public class LdapExtConfigGui extends AbstractConfigGui implements ItemListener
             cl.show(cards, CARDS_BIND);
         } else if (testType.equals(LDAPExtSampler.SBIND)) {
             sbind.setSelected(true);
-            cl.show(cards, CARDS_DEFAULT);
+            cl.show(cards, CARDS_BIND);
         } else if (testType.equals(LDAPExtSampler.COMPARE)) {
             compare.setSelected(true);
             cl.show(cards, CARDS_COMPARE);
@@ -330,6 +334,7 @@ public class LdapExtConfigGui extends AbstractConfigGui implements ItemListener
     /**
      * Implements JMeterGUIComponent.clearGui
      */
+    @Override
     public void clearGui() {
         super.clearGui();
 
