@@ -22,9 +22,9 @@ import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
-import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import javax.naming.NamingEnumeration;
 import javax.naming.NamingException;
@@ -33,7 +33,6 @@ import javax.naming.directory.Attributes;
 import javax.naming.directory.BasicAttribute;
 import javax.naming.directory.BasicAttributes;
 import javax.naming.directory.DirContext;
-import javax.naming.directory.InitialDirContext;
 import javax.naming.directory.ModificationItem;
 import javax.naming.directory.SearchResult;
 
@@ -64,6 +63,8 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
 
     private static final Logger log = LoggingManager.getLoggerForClass();
 
+    private static final long serialVersionUID = 240L;
+
     /*
      * The following strings are used in the test plan, and the values must not be changed
      * if test plans are to be upwardly compatible.
@@ -139,9 +140,8 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
     private static final String SEMI_COLON = ";"; // $NON-NLS-1$
 
 
-    private static final Hashtable ldapConnections = new Hashtable();
-
-    private static final Hashtable ldapContexts = new Hashtable();
+    private static final ConcurrentHashMap<String, DirContext> ldapContexts =
+        new ConcurrentHashMap<String, DirContext>();
 
     private static final int MAX_SORTED_RESULTS =
         JMeterUtils.getPropDefault("ldapsampler.max_sorted_results", 1000); // $NON-NLS-1$
@@ -601,10 +601,11 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * This will do the add test for the User defined TestCase
      *
      **************************************************************************/
-    private void addTest(LdapExtClient ldap, DirContext dirContext, SampleResult res) throws NamingException {
+    private void addTest(DirContext dirContext, SampleResult res) throws NamingException {
         try {
             res.sampleStart();
-            ldap.createTest(dirContext, getUserAttributes(), getBaseEntryDN());
+            DirContext ctx = LdapExtClient.createTest(dirContext, getUserAttributes(), getBaseEntryDN());
+            ctx.close(); // the createTest() method creates an extra context which needs to be closed
         } finally {
             res.sampleEnd();
         }
@@ -614,10 +615,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * This will do the delete test for the User defined TestCase
      *
      **************************************************************************/
-    private void deleteTest(LdapExtClient ldap, DirContext dirContext, SampleResult res) throws NamingException {
+    private void deleteTest(DirContext dirContext, SampleResult res) throws NamingException {
         try {
             res.sampleStart();
-            ldap.deleteTest(dirContext, getPropertyAsString(DELETE));
+            LdapExtClient.deleteTest(dirContext, getPropertyAsString(DELETE));
         } finally {
             res.sampleEnd();
         }
@@ -627,10 +628,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * This will do the modify test for the User defined TestCase
      *
      **************************************************************************/
-    private void modifyTest(LdapExtClient ldap, DirContext dirContext, SampleResult res) throws NamingException {
+    private void modifyTest(DirContext dirContext, SampleResult res) throws NamingException {
         try {
             res.sampleStart();
-            ldap.modifyTest(dirContext, getUserModAttributes(), getBaseEntryDN());
+            LdapExtClient.modifyTest(dirContext, getUserModAttributes(), getBaseEntryDN());
         } finally {
             res.sampleEnd();
         }
@@ -641,15 +642,15 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * the whole context
      *
      **************************************************************************/
-    private void bindOp(LdapExtClient ldap, DirContext dirContext, SampleResult res) throws NamingException {
-        DirContext ctx = (DirContext) ldapContexts.remove(getThreadName());
+    private void bindOp(DirContext dirContext, SampleResult res) throws NamingException {
+        DirContext ctx = ldapContexts.remove(getThreadName());
         if (ctx != null) {
             log.warn("Closing previous context for thread: " + getThreadName());
             ctx.close();
         }
         try {
             res.sampleStart();
-            ctx = ldap.connect(getServername(), getPort(), getRootdn(), getUserDN(), getUserPw(),getConnTimeOut(),isSecure());
+            ctx = LdapExtClient.connect(getServername(), getPort(), getRootdn(), getUserDN(), getUserPw(),getConnTimeOut(),isSecure());
         } finally {
             res.sampleEnd();
         }
@@ -661,12 +662,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      *
      **************************************************************************/
     private void singleBindOp(SampleResult res) throws NamingException {
-        LdapExtClient ldap_temp;
-        ldap_temp = new LdapExtClient();
         try {
             res.sampleStart();
-            DirContext ctx = ldap_temp.connect(getServername(), getPort(), getRootdn(), getUserDN(), getUserPw(),getConnTimeOut(),isSecure());
-            ldap_temp.disconnect(ctx);
+            DirContext ctx = LdapExtClient.connect(getServername(), getPort(), getRootdn(), getUserDN(), getUserPw(),getConnTimeOut(),isSecure());
+            LdapExtClient.disconnect(ctx);
         } finally {
             res.sampleEnd();
         }
@@ -676,10 +675,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * This will do a moddn Opp for the User new DN defined
      *
      **************************************************************************/
-    private void renameTest(LdapExtClient ldap, DirContext dirContext, SampleResult res) throws NamingException {
+    private void renameTest(DirContext dirContext, SampleResult res) throws NamingException {
         try {
             res.sampleStart();
-            ldap.moddnOp(dirContext, getPropertyAsString(MODDDN), getPropertyAsString(NEWDN));
+            LdapExtClient.moddnOp(dirContext, getPropertyAsString(MODDDN), getPropertyAsString(NEWDN));
         } finally {
             res.sampleEnd();
         }
@@ -690,14 +689,13 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * test case
      *
      **************************************************************************/
-    private void unbindOp(LdapExtClient ldap, DirContext dirContext, SampleResult res) {
+    private void unbindOp(DirContext dirContext, SampleResult res) {
         try {
             res.sampleStart();
-            ldap.disconnect(dirContext);
+            LdapExtClient.disconnect(dirContext);
         } finally {
             res.sampleEnd();
         }
-        ldapConnections.remove(getThreadName());
         ldapContexts.remove(getThreadName());
         log.info("context and LdapExtClients removed");
     }
@@ -713,23 +711,13 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
         XMLBuffer xmlBuffer = new XMLBuffer();
         xmlBuffer.openTag("ldapanswer"); // $NON-NLS-1$
         SampleResult res = new SampleResult();
-        res.setResponseData("successfull".getBytes());
+        res.setResponseData("successfull", null);
         res.setResponseMessage("Success"); // $NON-NLS-1$
         res.setResponseCode("0"); // $NON-NLS-1$
         res.setContentType("text/xml");// $NON-NLS-1$
         boolean isSuccessful = true;
         res.setSampleLabel(getName());
-        LdapExtClient temp_client = (LdapExtClient) ldapConnections.get(getThreadName());
-        DirContext dirContext = (DirContext) ldapContexts.get(getThreadName());
-        if (temp_client == null) {
-            temp_client = new LdapExtClient();
-            try {
-                dirContext = new InitialDirContext();
-            } catch (NamingException err) {
-                log.error("Ldap client context creation - ", err);
-            }
-            ldapConnections.put(getThreadName(), temp_client);
-        }
+        DirContext dirContext = ldapContexts.get(getThreadName());
 
         try {
             xmlBuffer.openTag("operation"); // $NON-NLS-1$
@@ -740,13 +728,13 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
                 res.setSamplerData("Unbind");
                 xmlBuffer.tag("baseobj",getRootdn()); // $NON-NLS-1$
                 xmlBuffer.tag("binddn",getUserDN()); // $NON-NLS-1$
-                unbindOp(temp_client, dirContext, res);
+                unbindOp(dirContext, res);
             } else if (testType.equals(BIND)) {
                 res.setSamplerData("Bind as "+getUserDN());
                 xmlBuffer.tag("baseobj",getRootdn()); // $NON-NLS-1$
                 xmlBuffer.tag("binddn",getUserDN()); // $NON-NLS-1$
                 xmlBuffer.tag("connectionTO",getConnTimeOut()); // $NON-NLS-1$
-                bindOp(temp_client, dirContext, res);
+                bindOp(dirContext, res);
             } else if (testType.equals(SBIND)) {
                 res.setSamplerData("SingleBind as "+getUserDN());
                 xmlBuffer.tag("baseobj",getRootdn()); // $NON-NLS-1$
@@ -758,10 +746,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
                                 + getPropertyAsString(COMPAREDN));
                 xmlBuffer.tag("comparedn",getPropertyAsString(COMPAREDN)); // $NON-NLS-1$
                 xmlBuffer.tag("comparefilter",getPropertyAsString(COMPAREFILT)); // $NON-NLS-1$
-                NamingEnumeration cmp=null;
+                NamingEnumeration<SearchResult> cmp=null;
                 try {
                     res.sampleStart();
-                    cmp = temp_client.compare(dirContext, getPropertyAsString(COMPAREFILT),
+                    cmp = LdapExtClient.compare(dirContext, getPropertyAsString(COMPAREFILT),
                             getPropertyAsString(COMPAREDN));
                     if (!cmp.hasMore()) {
                         res.setResponseCode("5"); // $NON-NLS-1$
@@ -778,21 +766,21 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
                 res.setSamplerData("Add object " + getBaseEntryDN());
                 xmlBuffer.tag("attributes",getArguments().toString()); // $NON-NLS-1$
                 xmlBuffer.tag("dn",getBaseEntryDN()); // $NON-NLS-1$
-                addTest(temp_client, dirContext, res);
+                addTest(dirContext, res);
             } else if (testType.equals(DELETE)) {
                 res.setSamplerData("Delete object " + getBaseEntryDN());
                 xmlBuffer.tag("dn",getBaseEntryDN()); // $NON-NLS-1$
-                deleteTest(temp_client, dirContext, res);
+                deleteTest(dirContext, res);
             } else if (testType.equals(MODIFY)) {
                 res.setSamplerData("Modify object " + getBaseEntryDN());
                 xmlBuffer.tag("dn",getBaseEntryDN()); // $NON-NLS-1$
                 xmlBuffer.tag("attributes",getLDAPArguments().toString()); // $NON-NLS-1$
-                modifyTest(temp_client, dirContext, res);
+                modifyTest(dirContext, res);
             } else if (testType.equals(RENAME)) {
                 res.setSamplerData("ModDN object " + getPropertyAsString(MODDDN) + " to " + getPropertyAsString(NEWDN));
                 xmlBuffer.tag("dn",getPropertyAsString(MODDDN)); // $NON-NLS-1$
                 xmlBuffer.tag("newdn",getPropertyAsString(NEWDN)); // $NON-NLS-1$
-                renameTest(temp_client, dirContext, res);
+                renameTest(dirContext, res);
             } else if (testType.equals(SEARCH)) {
                 final String            scopeStr = getScope();
                 final int               scope = getScopeAsInt();
@@ -809,10 +797,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
                 xmlBuffer.tag("countlimit",countLimit); // $NON-NLS-1$
                 xmlBuffer.tag("timelimit",timeLimit); // $NON-NLS-1$
 
-                NamingEnumeration srch=null;
+                NamingEnumeration<SearchResult> srch=null;
                 try {
                     res.sampleStart();
-                    srch = temp_client.searchTest(
+                    srch = LdapExtClient.searchTest(
                             dirContext, searchBase, searchFilter,
                             scope, getCountlimAsLong(),
                             getTimelimAsInt(),
@@ -859,7 +847,7 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
             xmlBuffer.closeTag("operation"); // $NON-NLS-1$
             xmlBuffer.tag("responsecode",res.getResponseCode()); // $NON-NLS-1$
             xmlBuffer.tag("responsemessage",res.getResponseMessage()); // $NON-NLS-1$
-            res.setResponseData(xmlBuffer.toString().getBytes());
+            res.setResponseData(xmlBuffer.toString(), null);
             res.setDataType(SampleResult.TEXT);
             res.setSuccessful(isSuccessful);
         }
@@ -872,18 +860,18 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
      * unless the number of results exceeds {@link #MAX_SORTED_RESULTS} in which case just stream
      * the results out without sorting.
      */
-    private void writeSearchResults(final XMLBuffer xmlb, final NamingEnumeration srch)
+    private void writeSearchResults(final XMLBuffer xmlb, final NamingEnumeration<SearchResult> srch)
             throws NamingException
     {
 
-        final ArrayList     sortedResults = new ArrayList(MAX_SORTED_RESULTS);
+        final ArrayList<SearchResult>     sortedResults = new ArrayList<SearchResult>(MAX_SORTED_RESULTS);
         final String        searchBase = getPropertyAsString(SEARCHBASE);
         final String        rootDn = getRootdn();
 
         // read all sortedResults into memory so we can guarantee ordering
         try {
             while (srch.hasMore() && (sortedResults.size() < MAX_SORTED_RESULTS)) {
-                final SearchResult    sr = (SearchResult) srch.next();
+                final SearchResult    sr = srch.next();
 
                     // must be done prior to sorting
                 normaliseSearchDN(sr, searchBase, rootDn);
@@ -893,15 +881,15 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
 
             sortResults(sortedResults);
 
-            for (Iterator it = sortedResults.iterator(); it.hasNext();)
+            for (Iterator<SearchResult> it = sortedResults.iterator(); it.hasNext();)
             {
-                final SearchResult  sr = (SearchResult) it.next();
+                final SearchResult  sr = it.next();
                 writeSearchResult(sr, xmlb);
             }
         }
 
         while (srch.hasMore()) { // If there's anything left ...
-            final SearchResult    sr = (SearchResult) srch.next();
+            final SearchResult    sr = srch.next();
 
             normaliseSearchDN(sr, searchBase, rootDn);
             writeSearchResult(sr, xmlb);
@@ -913,7 +901,7 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
     {
         final Attributes    attrs = sr.getAttributes();
         final int           size = attrs.size();
-        final ArrayList     sortedAttrs = new ArrayList(size);
+        final ArrayList<Attribute>     sortedAttrs = new ArrayList<Attribute>(size);
 
         xmlb.openTag("searchresult"); // $NON-NLS-1$
         xmlb.tag("dn", sr.getName()); // $NON-NLS-1$
@@ -921,25 +909,25 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
          xmlb.openTag("attributes"); // $NON-NLS-1$
 
          try {
-            for (NamingEnumeration en = attrs.getAll(); en.hasMore(); )
+            for (NamingEnumeration<? extends Attribute> en = attrs.getAll(); en.hasMore(); )
             {
-                final Attribute     attr = (Attribute) en.next();
+                final Attribute     attr = en.next();
 
                 sortedAttrs.add(attr);
             }
             sortAttributes(sortedAttrs);
-            for (Iterator ait = sortedAttrs.iterator(); ait.hasNext();)
+            for (Iterator<Attribute> ait = sortedAttrs.iterator(); ait.hasNext();)
             {
-                final Attribute     attr = (Attribute) ait.next();
+                final Attribute     attr = ait.next();
 
-                StringBuffer sb = new StringBuffer();
+                StringBuilder sb = new StringBuilder();
                 if (attr.size() == 1) {
                     sb.append(getWriteValue(attr.get()));
                 } else {
-                    final ArrayList     sortedVals = new ArrayList(attr.size());
+                    final ArrayList<String>     sortedVals = new ArrayList<String>(attr.size());
                     boolean             first = true;
 
-                    for (NamingEnumeration ven = attr.getAll(); ven.hasMore(); )
+                    for (NamingEnumeration<?> ven = attr.getAll(); ven.hasMore(); )
                     {
                         final Object    value = getWriteValue(ven.next());
                         sortedVals.add(value.toString());
@@ -947,9 +935,9 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
 
                     Collections.sort(sortedVals);
 
-                    for (Iterator vit = sortedVals.iterator(); vit.hasNext();)
+                    for (Iterator<String> vit = sortedVals.iterator(); vit.hasNext();)
                     {
-                        final String    value = (String) vit.next();
+                        final String    value = vit.next();
                         if (first) {
                             first = false;
                         } else {
@@ -966,21 +954,21 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
         }
     }
 
-    private void sortAttributes(final ArrayList sortedAttrs) {
-        Collections.sort(sortedAttrs, new Comparator()
+    private void sortAttributes(final ArrayList<Attribute> sortedAttrs) {
+        Collections.sort(sortedAttrs, new Comparator<Attribute>()
         {
-            public int compare(Object o1, Object o2)
+            public int compare(Attribute o1, Attribute o2)
             {
-                String      nm1 = ((Attribute) o1).getID();
-                String      nm2 = ((Attribute) o2).getID();
+                String      nm1 = o1.getID();
+                String      nm2 = o2.getID();
 
                 return nm1.compareTo(nm2);
             }
         });
     }
 
-    private void sortResults(final ArrayList sortedResults) {
-        Collections.sort(sortedResults, new Comparator()
+    private void sortResults(final ArrayList<SearchResult> sortedResults) {
+        Collections.sort(sortedResults, new Comparator<SearchResult>()
         {
             private int compareToReverse(final String s1, final String s2)
             {
@@ -1001,10 +989,10 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
                 return len1 - len2;
             }
 
-            public int compare(Object o1, Object o2)
+            public int compare(SearchResult o1, SearchResult o2)
             {
-                String      nm1 = ((SearchResult) o1).getName();
-                String      nm2 = ((SearchResult) o2).getName();
+                String      nm1 = o1.getName();
+                String      nm2 = o2.getName();
 
                 if (nm1 == null) {
                     nm1 = "";
@@ -1072,11 +1060,11 @@ public class LDAPExtSampler extends AbstractSampler implements TestListener {
 
     // Ensure any remaining contexts are closed
     public void testEnded(String host) {
-        Iterator it = ldapContexts.entrySet().iterator();
+        Iterator<Map.Entry<String, DirContext>> it = ldapContexts.entrySet().iterator();
         while (it.hasNext()) {
-            Map.Entry entry = (Map.Entry) it.next();
-            String key = (String) entry.getKey();
-            DirContext dc = (DirContext) entry.getValue();
+            Map.Entry<String, DirContext> entry = it.next();
+            String key = entry.getKey();
+            DirContext dc = entry.getValue();
             try {
                 log.warn("Tidying old Context for thread: " + key);
                 dc.close();
