@@ -18,6 +18,7 @@
 package org.apache.jmeter.protocol.mail.sampler;
 
 import java.io.ByteArrayOutputStream;
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
@@ -37,10 +38,14 @@ import javax.mail.internet.MimeMultipart;
 import javax.mail.internet.MimeUtility;
 
 import org.apache.commons.io.IOUtils;
+import org.apache.jmeter.protocol.smtp.sampler.gui.SecuritySettingsPanel;
+import org.apache.jmeter.protocol.smtp.sampler.protocol.LocalTrustStoreSSLSocketFactory;
+import org.apache.jmeter.protocol.smtp.sampler.protocol.TrustAllSSLSocketFactory;
 import org.apache.jmeter.samplers.AbstractSampler;
 import org.apache.jmeter.samplers.Entry;
 import org.apache.jmeter.samplers.Interruptible;
 import org.apache.jmeter.samplers.SampleResult;
+import org.apache.jmeter.services.FileServer;
 import org.apache.jmeter.testelement.property.BooleanProperty;
 import org.apache.jmeter.testelement.property.IntegerProperty;
 import org.apache.jmeter.testelement.property.StringProperty;
@@ -72,6 +77,38 @@ public class MailReaderSampler extends AbstractSampler implements Interruptible
 
     public static final String DEFAULT_PROTOCOL = "pop3";  // $NON-NLS-1$
 
+    // Use the actual class so the name must be correct.
+    private static final String TRUST_ALL_SOCKET_FACTORY = TrustAllSSLSocketFactory.class.getName();
+
+    public boolean isUseLocalTrustStore() {
+        return getPropertyAsBoolean(SecuritySettingsPanel.USE_LOCAL_TRUSTSTORE);
+    }
+
+    public String getTrustStoreToUse() {
+        return getPropertyAsString(SecuritySettingsPanel.TRUSTSTORE_TO_USE);
+    }
+
+
+    public boolean isUseSSL() {
+        return getPropertyAsBoolean(SecuritySettingsPanel.USE_SSL);
+    }
+
+
+    public boolean isUseStartTLS() {
+        return getPropertyAsBoolean(SecuritySettingsPanel.USE_STARTTLS);
+    }
+
+
+    public boolean isTrustAllCerts() {
+        return getPropertyAsBoolean(SecuritySettingsPanel.SSL_TRUST_ALL_CERTS);
+    }
+
+
+    public boolean isEnforceStartTLS() {
+        return getPropertyAsBoolean(SecuritySettingsPanel.ENFORCE_STARTTLS);
+
+    }
+
     public static final int ALL_MESSAGES = -1; // special value
 
     private volatile boolean busy;
@@ -104,8 +141,47 @@ public class MailReaderSampler extends AbstractSampler implements Interruptible
             // Create empty properties
             Properties props = new Properties();
 
+            if (isUseStartTLS()) {
+                props.setProperty("mail.pop3s.starttls.enable", "true");
+                if (isEnforceStartTLS()){
+                    // Requires JavaMail 1.4.2+
+                    props.setProperty("mail.pop3s.starttls.require", "true");
+                }
+            }
+
+            if (isTrustAllCerts()) {
+                if (isUseSSL()) {
+                    props.setProperty("mail.pop3s.ssl.socketFactory.class", TRUST_ALL_SOCKET_FACTORY);
+                    props.setProperty("mail.pop3s.ssl.socketFactory.fallback", "false");
+                } else if (isUseStartTLS()) {
+                    props.setProperty("mail.pop3s.ssl.socketFactory.class", TRUST_ALL_SOCKET_FACTORY);
+                    props.setProperty("mail.pop3s.ssl.socketFactory.fallback", "false");
+                }
+            } else if (isUseLocalTrustStore()){
+                File truststore = new File(getTrustStoreToUse());
+                log.info("load local truststore - try to load truststore from: "+truststore.getAbsolutePath());
+                if(!truststore.exists()){
+                    log.info("load local truststore -Failed to load truststore from: "+truststore.getAbsolutePath());
+                    truststore = new File(FileServer.getFileServer().getBaseDir(), getTrustStoreToUse());
+                    log.info("load local truststore -Attempting to read truststore from:  "+truststore.getAbsolutePath());
+                    if(!truststore.exists()){
+                        log.info("load local truststore -Failed to load truststore from: "+truststore.getAbsolutePath() + ". Local truststore not available, aborting execution.");
+                        throw new IOException("Local truststore file not found. Also not available under : " + truststore.getAbsolutePath());
+                    }
+                }
+                if (isUseSSL()) {
+                    // Requires JavaMail 1.4.2+
+                    props.put("mail.pop3s.ssl.socketFactory", new LocalTrustStoreSSLSocketFactory(truststore));
+                    props.put("mail.pop3s.ssl.socketFactory.fallback", "false");
+                } else if (isUseStartTLS()) {
+                    // Requires JavaMail 1.4.2+
+                    props.put("mail.pop3s.ssl.socketFactory", new LocalTrustStoreSSLSocketFactory(truststore));
+                    props.put("mail.pop3s.ssl.socketFactory.fallback", "false");
+                }
+            }
+
             // Get session
-            Session session = Session.getDefaultInstance(props, null);
+            Session session = Session.getInstance(props, null);
 
             // Get the store
             Store store = session.getStore(getServerType());
@@ -201,7 +277,7 @@ public class MailReaderSampler extends AbstractSampler implements Interruptible
         } catch (MessagingException ex) {
             log.debug("", ex);// No need to log normally, as we set the status
             parent.setResponseCode("500"); // $NON-NLS-1$
-            parent.setResponseMessage(ex.toString());
+            parent.setResponseMessage(ex.toString() + "\n" + samplerString); // $NON-NLS-1$
         } catch (IOException ex) {
             log.debug("", ex);// No need to log normally, as we set the status
             parent.setResponseCode("500"); // $NON-NLS-1$
