@@ -22,22 +22,21 @@ import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.awt.event.ItemEvent;
-import java.awt.event.ItemListener;
+import java.io.File;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 
 import javax.swing.BorderFactory;
-import javax.swing.ButtonGroup;
 import javax.swing.JButton;
 import javax.swing.JCheckBox;
 import javax.swing.JFileChooser;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
-import javax.swing.JRadioButton;
 import javax.swing.JTextArea;
 import javax.swing.JTextField;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
 
 import org.apache.jmeter.config.Argument;
 import org.apache.jmeter.protocol.smtp.sampler.SmtpSampler;
@@ -56,27 +55,22 @@ public class SmtpPanel extends JPanel {
 
     // local vars
     private JTextField tfMailFrom;
+    private JTextField tfMailReplyTo;
     private JButton browseButton;
     private JButton emlBrowseButton;
-    private JCheckBox cbTrustAllCerts;
-    private JCheckBox cbEnforceStartTLS;
     private JCheckBox cbUseAuth;
-    private JCheckBox cbUseLocalTrustStore;
-    private JRadioButton rbUseNone;
-    private JRadioButton rbUseSSL;
-    private JRadioButton rbUseStartTLS;
-    private ButtonGroup bgSecuritySettings;
     private JTextField tfMailServer;
     private JTextField tfMailServerPort;
-    private JTextField tfTrustStoreToUse;
     private JTextField tfMailTo;
     private JTextField tfMailToCC;
     private JTextField tfMailToBCC;
     private JTextField tfAttachment;
     private JTextField tfEmlMessage;
     private JTextArea taMessage;
+    private JCheckBox cbPlainBody;
 
     private JLabel jlAddressFrom;
+    private JLabel jlAddressReplyTo;
     private JLabel jlAddressTo;
     private JLabel jlAddressToCC;
     private JLabel jlAddressToBCC;
@@ -84,7 +78,6 @@ public class SmtpPanel extends JPanel {
     private JLabel jlMailServer;
     private JLabel jlAttachFile;
     private JLabel jlDutPortStandard;
-    private JLabel jlTrustStoreToUse;
     private JLabel jlPassword;
     private JLabel jlSubject;
     private JLabel jlUsername;
@@ -95,11 +88,12 @@ public class SmtpPanel extends JPanel {
     private JTextField tfAuthPassword;
     private JTextField tfAuthUsername;
     private JTextField tfSubject;
+    private JCheckBox cbSuppressSubject;
     private JCheckBox cbIncludeTimestamp;
     private JCheckBox cbMessageSizeStats;
     private JCheckBox cbEnableDebug;
     private JCheckBox cbUseEmlMessage;
-    
+
     private JPanel headerFieldsPanel;
     private JButton addHeaderFieldButton;
     private JLabel headerFieldName;
@@ -108,6 +102,8 @@ public class SmtpPanel extends JPanel {
     private Map<JButton,JTextField> removeButtons = new HashMap<JButton, JTextField>();
     private int headerGridY = 0;
 
+    private SecuritySettingsPanel securitySettingsPanel;
+
     /**
      * Creates new form SmtpPanel, standard constructer. Calls
      * initComponents();.
@@ -288,6 +284,43 @@ public class SmtpPanel extends JPanel {
         tfSubject.setText(subject);
     }
 
+    /**
+     * Returns true if subject header should be suppressed
+     *
+     * @return true if subject header should be suppressed
+     */
+    public boolean isSuppressSubject() {
+        return cbSuppressSubject.isSelected();
+    }
+
+    /**
+     * Sets the property that defines if the subject header should be suppressed
+     *
+     * @param emptySubject
+     *
+     */
+    public void setSuppressSubject(boolean emptySubject) {
+        cbSuppressSubject.setSelected(emptySubject);
+    }
+
+    /**
+     * Returns true if message body should be plain (i.e. not multipart/mixed)
+     *
+     * @return true if using plain message body (i.e. not multipart/mixed)
+     */
+    public boolean isPlainBody() {
+        return cbPlainBody.isSelected();
+    }
+
+    /**
+     * Sets the property that defines if the body should be plain (i.e. not multipart/mixed)
+     *
+     * @param plainBody whether to use a plain body (i.e. not multipart/mixed)
+     */
+    public void setPlainBody(boolean plainBody) {
+        cbPlainBody.setSelected(plainBody);
+    }
+
     /**
      * Returns if mail-server needs authentication (checkbox)
      *
@@ -308,65 +341,6 @@ public class SmtpPanel extends JPanel {
         tfAuthUsername.setEditable(selected); // ensure correctly set on initial display
     }
 
-    /**
-     * Returns if SSL is used to secure the SMTP-connection (checkbox)
-     *
-     * @return true if SSL is used to secure the SMTP-connection
-     */
-    public boolean isUseSSL() {
-        return rbUseSSL.isSelected();
-    }
-
-    /**
-     * Sets SSL to be used to secure the SMTP-connection (checkbox)
-     *
-     * @param useSSL
-     *            Use SSL to secure the connection
-     */
-    public void setUseSSL(boolean useSSL) {
-        rbUseSSL.setSelected(useSSL);
-    }
-
-    /**
-     * Returns if StartTLS is used to secure the connection (checkbox)
-     *
-     * @return true if StartTLS is used to secure the connection
-     */
-    public boolean isUseStartTLS() {
-        return rbUseStartTLS.isSelected();
-    }
-
-    /**
-     * Sets StartTLS to be used to secure the SMTP-connection (checkbox)
-     *
-     * @param useStartTLS
-     *            Use StartTLS to secure the connection
-     */
-    public void setUseStartTLS(boolean useStartTLS) {
-        rbUseStartTLS.setSelected(useStartTLS);
-    }
-
-    /**
-     * Returns if StartTLS is enforced (normally, SMTP uses plain
-     * SMTP-connection as fallback if "250-STARTTLS" isn't sent from the
-     * mailserver) (checkbox)
-     *
-     * @return true if StartTLS is enforced
-     */
-    public boolean isEnforceStartTLS() {
-        return cbEnforceStartTLS.isSelected();
-    }
-
-    /**
-     * Enforces StartTLS to secure the SMTP-connection (checkbox)
-     *
-     * @param enforceStartTLS
-     *            Enforce the use of StartTLS to secure the connection
-     * @see #isEnforceStartTLS()
-     */
-    public void setEnforceStartTLS(boolean enforceStartTLS) {
-        cbEnforceStartTLS.setSelected(enforceStartTLS);
-    }
 
     public boolean isEnableDebug() {
         return cbEnableDebug.isSelected();
@@ -376,70 +350,7 @@ public class SmtpPanel extends JPanel {
         cbEnableDebug.setSelected(selected);
     }
 
-    /**
-     * Returns if all certificates are blindly trusted (using according
-     * SocketFactory) (checkbox)
-     *
-     * @return true if all certificates are blindly trusted
-     */
-    public boolean isTrustAllCerts() {
-        return cbTrustAllCerts.isSelected();
-    }
 
-    /**
-     * Enforces JMeter to trust all certificates, no matter what CA is issuer
-     * (checkbox)
-     *
-     * @param trustAllCerts
-     *            Trust all certificates
-     * @see #isTrustAllCerts()
-     */
-    public void setTrustAllCerts(boolean trustAllCerts) {
-        cbTrustAllCerts.setSelected(trustAllCerts);
-    }
-
-    /**
-     * Returns if local (pre-installed) truststore is used to avoid
-     * SSL-connection-exceptions (checkbox)
-     *
-     * @return true if a local truststore is used
-     */
-    public boolean isUseLocalTrustStore() {
-        return cbUseLocalTrustStore.isSelected();
-    }
-
-    /**
-     * Set the use of a local (pre-installed) truststore to avoid
-     * SSL-connection-exceptions (checkbox)
-     *
-     * @param useLocalTrustStore
-     *            Use local keystore
-     */
-    public void setUseLocalTrustStore(boolean useLocalTrustStore) {
-        cbUseLocalTrustStore.setSelected(useLocalTrustStore);
-        tfTrustStoreToUse.setEditable(useLocalTrustStore); // ensure correctly set on initial display
-    }
-
-    /**
-     * Returns the path to the local (pre-installed) truststore to be used to
-     * avoid SSL-connection-exceptions
-     *
-     * @return Path to local truststore
-     */
-    public String getTrustStoreToUse() {
-        return tfTrustStoreToUse.getText();
-    }
-
-    /**
-     * Set the path to local (pre-installed) truststore to be used to avoid
-     * SSL-connection-exceptions
-     *
-     * @param trustStoreToUse
-     *            Path to local truststore
-     */
-    public void setTrustStoreToUse(String trustStoreToUse) {
-        tfTrustStoreToUse.setText(trustStoreToUse);
-    }
 
     /**
      * Returns if an .eml-message is sent instead of the content of message-text
@@ -522,10 +433,6 @@ public class SmtpPanel extends JPanel {
         cbMessageSizeStats.setSelected(val);
     }
 
-    public void setUseNoSecurity(boolean selected) {
-        rbUseNone.setSelected(selected);
-    }
-
     public String getPassword() {
         return tfAuthPassword.getText();
     }
@@ -543,37 +450,48 @@ public class SmtpPanel extends JPanel {
     }
 
     public CollectionProperty getHeaderFields() {
-    	CollectionProperty result = new CollectionProperty();
-    	result.setName(SmtpSampler.HEADER_FIELDS);
-		for (Iterator<JTextField> iterator = headerFields.keySet().iterator(); iterator.hasNext();) {
-			JTextField headerName = iterator.next();
-			String name = headerName.getText();
-			String value = headerFields.get(headerName).getText();
-			Argument argument = new Argument(name, value);
-			result.addItem(argument);
-		}
-    	return result;
-	}
+        CollectionProperty result = new CollectionProperty();
+        result.setName(SmtpSampler.HEADER_FIELDS);
+        for (Iterator<JTextField> iterator = headerFields.keySet().iterator(); iterator.hasNext();) {
+            JTextField headerName = iterator.next();
+            String name = headerName.getText();
+            String value = headerFields.get(headerName).getText();
+            Argument argument = new Argument(name, value);
+            result.addItem(argument);
+        }
+        return result;
+    }
 
     public void setHeaderFields(CollectionProperty fields) {
-    	clearHeaderFields();
-    	for (int i = 0; i < fields.size(); i++) {
-    		Argument argument = (Argument)((TestElementProperty)fields.get(i)).getObjectValue();
-			String name = argument.getName();
-			JButton removeButton = addHeaderActionPerformed(null);
-			JTextField nameTF = removeButtons.get(removeButton);
-			nameTF.setText(name);
-			JTextField valueTF = headerFields.get(nameTF);
-			valueTF.setText(argument.getValue());			
-		}
-    	validate();
-	}
-	/**
+        clearHeaderFields();
+        for (int i = 0; i < fields.size(); i++) {
+            Argument argument = (Argument)((TestElementProperty)fields.get(i)).getObjectValue();
+            String name = argument.getName();
+            JButton removeButton = addHeaderActionPerformed(null);
+            JTextField nameTF = removeButtons.get(removeButton);
+            nameTF.setText(name);
+            JTextField valueTF = headerFields.get(nameTF);
+            valueTF.setText(argument.getValue());
+        }
+        validate();
+    }
+
+    public String getMailReplyTo() {
+        return tfMailReplyTo.getText();
+    }
+
+    public void setMailReplyTo(String replyTo) {
+        tfMailReplyTo.setText(replyTo);        
+    }
+    
+
+    /**
      * Main method of class, builds all gui-components for SMTP-sampler.
      */
     private void initComponents() {
         GridBagConstraints gridBagConstraints, gridBagConstraintsMain;
 
+        jlAddressReplyTo = new JLabel(JMeterUtils.getResString("smtp_replyto")); // $NON-NLS-1$
         jlAddressFrom = new JLabel(JMeterUtils.getResString("smtp_from")); // $NON-NLS-1$
         jlAddressTo = new JLabel(JMeterUtils.getResString("smtp_to")); // $NON-NLS-1$
         jlAddressToCC = new JLabel(JMeterUtils.getResString("smtp_cc")); // $NON-NLS-1$
@@ -584,14 +502,13 @@ public class SmtpPanel extends JPanel {
         jlDutPortStandard = new JLabel(JMeterUtils.getResString("smtp_default_port")); // $NON-NLS-1$
         jlUsername = new JLabel(JMeterUtils.getResString("smtp_username")); // $NON-NLS-1$
         jlPassword = new JLabel(JMeterUtils.getResString("smtp_password")); // $NON-NLS-1$
-        jlTrustStoreToUse = new JLabel(JMeterUtils.getResString("smtp_truststore")); // $NON-NLS-1$
         jlSubject = new JLabel(JMeterUtils.getResString("smtp_subject")); // $NON-NLS-1$
         jlMessage = new JLabel(JMeterUtils.getResString("smtp_message")); // $NON-NLS-1$
 
         tfMailServer = new JTextField(30);
         tfMailServerPort = new JTextField(6);
-        tfTrustStoreToUse = new JTextField(20);
         tfMailFrom = new JTextField(25);
+        tfMailReplyTo = new JTextField(25);
         tfMailTo = new JTextField(25);
         tfMailToCC = new JTextField(25);
         tfMailToBCC = new JTextField(25);
@@ -603,17 +520,20 @@ public class SmtpPanel extends JPanel {
 
         taMessage = new JTextArea(5, 20);
 
+        cbPlainBody = new JCheckBox(JMeterUtils.getResString("smtp_plainbody")); // $NON-NLS-1$
+        
+        cbSuppressSubject = new JCheckBox(JMeterUtils.getResString("smtp_suppresssubj")); // $NON-NLS-1$
+        cbSuppressSubject.addChangeListener(new ChangeListener() {
+            public void stateChanged(ChangeEvent evt) {
+                emptySubjectActionPerformed(evt);
+            }
+        });
+
         cbUseAuth = new JCheckBox(JMeterUtils.getResString("smtp_useauth")); // $NON-NLS-1$
-        rbUseNone = new JRadioButton(JMeterUtils.getResString("smtp_usenone")); // $NON-NLS-1$
-        rbUseSSL = new JRadioButton(JMeterUtils.getResString("smtp_usessl")); // $NON-NLS-1$
-        rbUseStartTLS = new JRadioButton(JMeterUtils.getResString("smtp_usestarttls")); // $NON-NLS-1$
 
-        cbTrustAllCerts = new JCheckBox(JMeterUtils.getResString("smtp_trustall")); // $NON-NLS-1$
-        cbEnforceStartTLS = new JCheckBox(JMeterUtils.getResString("smtp_enforcestarttls")); // $NON-NLS-1$
         cbIncludeTimestamp = new JCheckBox(JMeterUtils.getResString("smtp_timestamp")); // $NON-NLS-1$
         cbMessageSizeStats = new JCheckBox(JMeterUtils.getResString("smtp_messagesize")); // $NON-NLS-1$
         cbEnableDebug = new JCheckBox(JMeterUtils.getResString("smtp_enabledebug")); // $NON-NLS-1$
-        cbUseLocalTrustStore = new JCheckBox(JMeterUtils.getResString("smtp_usetruststore")); // $NON-NLS-1$
         cbUseEmlMessage = new JCheckBox(JMeterUtils.getResString("smtp_eml")); // $NON-NLS-1$
 
         attachmentFileChooser = new JFileChooser();
@@ -725,6 +645,14 @@ public class SmtpPanel extends JPanel {
         gridBagConstraints.gridy = 3;
         panelMailSettings.add(tfMailToBCC, gridBagConstraints);
 
+        gridBagConstraints.gridx = 0;
+        gridBagConstraints.gridy = 4;
+        panelMailSettings.add(jlAddressReplyTo, gridBagConstraints);
+
+        gridBagConstraints.gridx = 1;
+        gridBagConstraints.gridy = 4;
+        panelMailSettings.add(tfMailReplyTo, gridBagConstraints);
+
         gridBagConstraintsMain.gridx = 0;
         gridBagConstraintsMain.gridy = 1;
         add(panelMailSettings, gridBagConstraintsMain);
@@ -780,103 +708,11 @@ public class SmtpPanel extends JPanel {
         /*
          * Security Settings
          */
-        JPanel panelSecuritySettings = new JPanel(new GridBagLayout());
-        panelSecuritySettings.setBorder(BorderFactory.createTitledBorder(
-                BorderFactory.createEtchedBorder(),
-                JMeterUtils.getResString("smtp_security_settings"))); // $NON-NLS-1$
-
-        rbUseNone.setSelected(true);
-        bgSecuritySettings = new ButtonGroup();
-        bgSecuritySettings.add(rbUseNone);
-        bgSecuritySettings.add(rbUseSSL);
-        bgSecuritySettings.add(rbUseStartTLS);
-
-        gridBagConstraints.gridx = 0;
-        gridBagConstraints.gridy = 0;
-        panelSecuritySettings.add(rbUseNone, gridBagConstraints);
-
-        gridBagConstraints.gridx = 1;
-        gridBagConstraints.gridy = 0;
-        panelSecuritySettings.add(rbUseSSL, gridBagConstraints);
-
-        gridBagConstraints.gridx = 2;
-        gridBagConstraints.gridy = 0;
-        panelSecuritySettings.add(rbUseStartTLS, gridBagConstraints);
-
-        rbUseNone.addItemListener(new ItemListener() {
-            public void itemStateChanged(ItemEvent evt) {
-                rbSecuritySettingsItemStateChanged(evt);
-            }
-        });
-        rbUseSSL.addItemListener(new ItemListener() {
-            public void itemStateChanged(ItemEvent evt) {
-                rbSecuritySettingsItemStateChanged(evt);
-            }
-        });
-        rbUseStartTLS.addItemListener(new ItemListener() {
-            public void itemStateChanged(ItemEvent evt) {
-                rbSecuritySettingsItemStateChanged(evt);
-            }
-        });
-
-        cbTrustAllCerts.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        cbTrustAllCerts.setMargin(new java.awt.Insets(0, 0, 0, 0));
-        cbTrustAllCerts.setEnabled(false);
-        cbTrustAllCerts.setToolTipText(JMeterUtils.getResString("smtp_trustall_tooltip")); // $NON-NLS-1$
-        cbTrustAllCerts.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent evt) {
-                cbTrustAllCertsActionPerformed(evt);
-            }
-        });
-
-        gridBagConstraints.gridx = 0;
-        gridBagConstraints.gridy = 1;
-        panelSecuritySettings.add(cbTrustAllCerts, gridBagConstraints);
-
-        cbEnforceStartTLS.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        cbEnforceStartTLS.setMargin(new java.awt.Insets(0, 0, 0, 0));
-        cbEnforceStartTLS.setEnabled(false);
-        cbEnforceStartTLS.addActionListener(new ActionListener() {
-                    public void actionPerformed(ActionEvent evt) {
-                        cbEnforceStartTLSActionPerformed(evt);
-                    }
-                });
-        cbEnforceStartTLS.setToolTipText(JMeterUtils.getResString("smtp_enforcestarttls_tooltip")); // $NON-NLS-1$
-
-        gridBagConstraints.gridx = 2;
-        gridBagConstraints.gridy = 1;
-        panelSecuritySettings.add(cbEnforceStartTLS, gridBagConstraints);
-
-        cbUseLocalTrustStore.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        cbUseLocalTrustStore.setMargin(new java.awt.Insets(0, 0, 0, 0));
-        cbUseLocalTrustStore.setEnabled(false);
-        cbUseLocalTrustStore.addActionListener(new ActionListener() {
-                    public void actionPerformed(ActionEvent evt) {
-                        cbUseLocalTrustStoreActionPerformed(evt);
-                    }
-                });
-
-        cbUseLocalTrustStore.setToolTipText(JMeterUtils.getResString("smtp_usetruststore_tooltip")); // $NON-NLS-1$
-
-        gridBagConstraints.gridx = 1;
-        gridBagConstraints.gridy = 1;
-        gridBagConstraints.gridwidth = 2;
-        panelSecuritySettings.add(cbUseLocalTrustStore, gridBagConstraints);
-
-        gridBagConstraints.gridx = 0;
-        gridBagConstraints.gridy = 2;
-        gridBagConstraints.gridwidth = 1;
-        jlTrustStoreToUse.setToolTipText(JMeterUtils.getResString("smtp_truststore_tooltip"));
-        panelSecuritySettings.add(jlTrustStoreToUse, gridBagConstraints);
-
-        gridBagConstraints.gridx = 1;
-        gridBagConstraints.gridy = 2;
-        tfTrustStoreToUse.setToolTipText(JMeterUtils.getResString("smtp_truststore_tooltip"));
-        panelSecuritySettings.add(tfTrustStoreToUse, gridBagConstraints);
+        securitySettingsPanel = new SecuritySettingsPanel();
 
         gridBagConstraintsMain.gridx = 0;
         gridBagConstraintsMain.gridy = 3;
-        add(panelSecuritySettings, gridBagConstraintsMain);
+        add(securitySettingsPanel, gridBagConstraintsMain);
 
         /*
          * (non-Javadoc) Message Settings
@@ -895,11 +731,18 @@ public class SmtpPanel extends JPanel {
         gridBagConstraints.fill = GridBagConstraints.HORIZONTAL;
         panelMessageSettings.add(tfSubject, gridBagConstraints);
 
-        cbIncludeTimestamp.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        cbIncludeTimestamp.setMargin(new java.awt.Insets(0, 0, 0, 0));
+        cbSuppressSubject.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
+        cbSuppressSubject.setMargin(new java.awt.Insets(0, 0, 0, 0));
         gridBagConstraints.gridx = 2;
         gridBagConstraints.gridy = 0;
         gridBagConstraints.fill = GridBagConstraints.NONE;
+        panelMessageSettings.add(cbSuppressSubject, gridBagConstraints);
+
+        cbIncludeTimestamp.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
+        cbIncludeTimestamp.setMargin(new java.awt.Insets(0, 0, 0, 0));
+        gridBagConstraints.gridx = 1;
+        gridBagConstraints.gridy = 1;
+        gridBagConstraints.fill = GridBagConstraints.NONE;
         panelMessageSettings.add(cbIncludeTimestamp, gridBagConstraints);
 
         /*
@@ -915,15 +758,15 @@ public class SmtpPanel extends JPanel {
         headerFieldName = new JLabel(JMeterUtils.getResString("smtp_header_name"));
         headerFieldValue = new JLabel(JMeterUtils.getResString("smtp_header_value"));
         headerFieldsPanel = new JPanel(new GridBagLayout());
-        
+
         headerFieldName.setVisible(false);
-        headerFieldValue.setVisible(false);        
+        headerFieldValue.setVisible(false);
 
         headerGridY=0;
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = headerGridY++;
         headerFieldsPanel.add(addHeaderFieldButton, gridBagConstraints);
-        
+
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = headerGridY;
         headerFieldsPanel.add(headerFieldName, gridBagConstraints);
@@ -931,28 +774,35 @@ public class SmtpPanel extends JPanel {
         gridBagConstraints.gridx = 1;
         gridBagConstraints.gridy = headerGridY++;
         headerFieldsPanel.add(headerFieldValue, gridBagConstraints);
-        
+
         gridBagConstraintsMain.gridx = 1;
-        gridBagConstraintsMain.gridy = 1;
-        panelMessageSettings.add(headerFieldsPanel, gridBagConstraintsMain);        
+        gridBagConstraintsMain.gridy = 2;
+        panelMessageSettings.add(headerFieldsPanel, gridBagConstraintsMain);
 
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.gridy = 2;
+        gridBagConstraints.gridy = 3;
         panelMessageSettings.add(jlMessage, gridBagConstraints);
 
         taMessage.setBorder(BorderFactory.createBevelBorder(1));
         gridBagConstraints.gridx = 1;
-        gridBagConstraints.gridy = 2;
+        gridBagConstraints.gridy = 3;
         gridBagConstraints.fill = GridBagConstraints.BOTH;
         panelMessageSettings.add(taMessage, gridBagConstraints);
+        
+        cbPlainBody.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
+        cbPlainBody.setMargin(new java.awt.Insets(0, 0, 0, 0));
+        gridBagConstraints.gridx = 2;
+        gridBagConstraints.gridy = 3;
+        gridBagConstraints.fill = GridBagConstraints.NONE;
+        panelMessageSettings.add(cbPlainBody, gridBagConstraints);
 
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.gridy = 3;
+        gridBagConstraints.gridy = 4;
         gridBagConstraints.fill = GridBagConstraints.NONE;
         panelMessageSettings.add(jlAttachFile, gridBagConstraints);
 
         gridBagConstraints.gridx = 1;
-        gridBagConstraints.gridy = 3;
+        gridBagConstraints.gridy = 4;
         gridBagConstraints.fill = GridBagConstraints.HORIZONTAL;
         panelMessageSettings.add(tfAttachment, gridBagConstraints);
         tfAttachment.setToolTipText(JMeterUtils.getResString("smtp_attach_file_tooltip")); // $NON-NLS-1$
@@ -964,7 +814,7 @@ public class SmtpPanel extends JPanel {
         });
 
         gridBagConstraints.gridx = 2;
-        gridBagConstraints.gridy = 3;
+        gridBagConstraints.gridy = 4;
         gridBagConstraints.fill = GridBagConstraints.NONE;
         panelMessageSettings.add(browseButton, gridBagConstraints);
 
@@ -976,12 +826,12 @@ public class SmtpPanel extends JPanel {
         });
 
         gridBagConstraints.gridx = 0;
-        gridBagConstraints.gridy = 4;
+        gridBagConstraints.gridy = 5;
         gridBagConstraints.fill = GridBagConstraints.NONE;
         panelMessageSettings.add(cbUseEmlMessage, gridBagConstraints);
 
         gridBagConstraints.gridx = 1;
-        gridBagConstraints.gridy = 4;
+        gridBagConstraints.gridy = 5;
         gridBagConstraints.fill = GridBagConstraints.HORIZONTAL;
         tfEmlMessage.setEnabled(false);
         panelMessageSettings.add(tfEmlMessage, gridBagConstraints);
@@ -994,12 +844,12 @@ public class SmtpPanel extends JPanel {
         emlBrowseButton.setEnabled(false);
 
         gridBagConstraints.gridx = 2;
-        gridBagConstraints.gridy = 4;
+        gridBagConstraints.gridy = 5;
         gridBagConstraints.fill = GridBagConstraints.NONE;
         panelMessageSettings.add(emlBrowseButton, gridBagConstraints);
 
         gridBagConstraintsMain.gridx = 0;
-        gridBagConstraintsMain.gridy = 5;
+        gridBagConstraintsMain.gridy = 6;
         add(panelMessageSettings, gridBagConstraintsMain);
 
         /*
@@ -1022,7 +872,7 @@ public class SmtpPanel extends JPanel {
         panelAdditionalSettings.add(cbEnableDebug, gridBagConstraints);
 
         gridBagConstraintsMain.gridx = 0;
-        gridBagConstraintsMain.gridy = 6;
+        gridBagConstraintsMain.gridy = 7;
         add(panelAdditionalSettings, gridBagConstraintsMain);
     }
 
@@ -1037,35 +887,7 @@ public class SmtpPanel extends JPanel {
         tfAuthPassword.setEditable(cbUseAuth.isSelected());
     }
 
-    /**
-     * ActionPerformed-method for checkbox "useLocalTrustStore"
-     *
-     * @param evt
-     *            ActionEvent to be handled
-     */
-    private void cbUseLocalTrustStoreActionPerformed(
-            ActionEvent evt) {
-        final boolean selected = cbUseLocalTrustStore.isSelected();
-        tfTrustStoreToUse.setEditable(selected); // must follow the checkbox setting
-        if (selected) {
-            cbTrustAllCerts.setSelected(false); // not compatible
-        }
-    }
 
-    /**
-     * ActionPerformed-method for checkbox "cbTrustAllCerts"
-     *
-     * @param evt
-     *            ActionEvent to be handled
-     */
-    private void cbTrustAllCertsActionPerformed(
-            ActionEvent evt) {
-        final boolean selected = cbTrustAllCerts.isSelected();
-        if (selected) {
-            cbUseLocalTrustStore.setSelected(false); // not compatible
-            tfTrustStoreToUse.setEditable(false); // must follow the checkbox setting
-        }
-    }
 
     /**
      * ActionPerformed-method for filechoser "attachmentFileChoser", creates
@@ -1075,15 +897,17 @@ public class SmtpPanel extends JPanel {
      *            ActionEvent to be handled
      */
     private void attachmentFolderFileChooserActionPerformed(ActionEvent evt) {
+        File chosen = attachmentFileChooser.getSelectedFile();
+        if (chosen == null){
+            return;
+        }
         final String attachments = tfAttachment.getText().trim();
         if (null != attachments && attachments.length() > 0) {
             tfAttachment.setText(attachments
                             + SmtpSampler.FILENAME_SEPARATOR
-                            + attachmentFileChooser.getSelectedFile()
-                                    .getAbsolutePath());
+                            + chosen.getAbsolutePath());
         } else {
-            tfAttachment.setText(attachmentFileChooser.getSelectedFile()
-                    .getAbsolutePath());
+            tfAttachment.setText(chosen.getAbsolutePath());
         }
 
     }
@@ -1147,47 +971,7 @@ public class SmtpPanel extends JPanel {
         emlFileChooser.showOpenDialog(this);
     }
 
-    /**
-     * ActionPerformed-method for checkbox "enforceStartTLS", empty method
-     * header
-     *
-     * @param evt
-     *            ActionEvent to be handled
-     */
-    private void cbEnforceStartTLSActionPerformed(ActionEvent evt) {
-    }
 
-    /**
-     * ItemStateChanged-method for radiobutton "securitySettings"
-     *
-     * @param evt
-     *            ItemEvent to be handled
-     */
-    private void rbSecuritySettingsItemStateChanged(ItemEvent evt) {
-        final Object source = evt.getSource();
-        if (source == rbUseNone) {
-            cbTrustAllCerts.setEnabled(false);
-            cbTrustAllCerts.setSelected(false);
-            cbEnforceStartTLS.setEnabled(false);
-            cbEnforceStartTLS.setSelected(false);
-            cbUseLocalTrustStore.setSelected(false);
-            cbUseLocalTrustStore.setEnabled(false);
-            tfTrustStoreToUse.setEditable(false);
-        } else if (source == rbUseSSL) {
-            cbTrustAllCerts.setEnabled(true);
-            cbEnforceStartTLS.setEnabled(false);
-            cbEnforceStartTLS.setSelected(false);
-            cbUseLocalTrustStore.setEnabled(true);
-            tfTrustStoreToUse.setEditable(false);
-        } else if (source == rbUseStartTLS) {
-            cbTrustAllCerts.setEnabled(true);
-            cbTrustAllCerts.setSelected(false);
-            cbEnforceStartTLS.setEnabled(true);
-            cbUseLocalTrustStore.setEnabled(true);
-            cbUseLocalTrustStore.setSelected(false);
-            tfTrustStoreToUse.setEditable(false);
-        }
-    }
 
     /**
      * Reset all the Gui fields.
@@ -1204,93 +988,115 @@ public class SmtpPanel extends JPanel {
         tfAuthUsername.setText("");
         tfEmlMessage.setText("");
         tfMailFrom.setText("");
+        tfMailReplyTo.setText("");
         tfMailServer.setText("");
         tfMailServerPort.setText("");
         tfMailTo.setText("");
         tfMailToBCC.setText("");
         tfMailToCC.setText("");
         tfSubject.setText("");
-        tfTrustStoreToUse.setText("");
-        rbUseNone.setSelected(true);
-   		clearHeaderFields();
-		validate();        
+        cbPlainBody.setSelected(false);
+        cbSuppressSubject.setSelected(false);
+        securitySettingsPanel.clear();
+        clearHeaderFields();
+        validate();
     }
 
-	private void clearHeaderFields() {
-		headerFieldName.setVisible(false);
-   		headerFieldValue.setVisible(false);
+    private void clearHeaderFields() {
+        headerFieldName.setVisible(false);
+           headerFieldValue.setVisible(false);
 
-		for (Iterator<JButton> iterator = removeButtons.keySet().iterator(); iterator.hasNext();) {
-			JButton removeButton = iterator.next();
-	   		JTextField headerName = removeButtons.get(removeButton);
-			JTextField headerValue = headerFields.get(headerName);
-			
-			headerFieldsPanel.remove(headerName);
-			if (headerValue != null){ // Can be null (not sure why)
-			    headerFieldsPanel.remove(headerValue);
-			}
-			headerFieldsPanel.remove(removeButton);	
-			headerFields.remove(headerName);
-			iterator.remove();
-		}
-	}
-    
-    private JButton addHeaderActionPerformed(ActionEvent evt){
-		if(headerFields.size() == 0){
-    		headerFieldName.setVisible(true);
-    		headerFieldValue.setVisible(true);
+        for (Iterator<JButton> iterator = removeButtons.keySet().iterator(); iterator.hasNext();) {
+            JButton removeButton = iterator.next();
+               JTextField headerName = removeButtons.get(removeButton);
+            JTextField headerValue = headerFields.get(headerName);
+
+            headerFieldsPanel.remove(headerName);
+            if (headerValue != null){ // Can be null (not sure why)
+                headerFieldsPanel.remove(headerValue);
+            }
+            headerFieldsPanel.remove(removeButton);
+            headerFields.remove(headerName);
+            iterator.remove();
         }
-    	JTextField nameTF = new JTextField();
-    	JTextField valueTF = new JTextField();    	
-    	JButton removeButton = new JButton(JMeterUtils.getResString("smtp_header_remove"));
-    	headerFields.put(nameTF, valueTF);
-    	removeButtons.put(removeButton, nameTF);
-    	
-    	removeButton.addActionListener(new ActionListener() {
+    }
+
+    private JButton addHeaderActionPerformed(ActionEvent evt){
+        if(headerFields.size() == 0){
+            headerFieldName.setVisible(true);
+            headerFieldValue.setVisible(true);
+        }
+        JTextField nameTF = new JTextField();
+        JTextField valueTF = new JTextField();
+        JButton removeButton = new JButton(JMeterUtils.getResString("smtp_header_remove"));
+        headerFields.put(nameTF, valueTF);
+        removeButtons.put(removeButton, nameTF);
+
+        removeButton.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
-            	removeHeaderActionPerformed(evt);
+                removeHeaderActionPerformed(evt);
             }
         });
-    	
-    	GridBagConstraints gridBagConstraints = new GridBagConstraints();
-    	gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
-    	gridBagConstraints.weightx = 0.5;
-    	gridBagConstraints.anchor = GridBagConstraints.WEST;
-    	
+
+        GridBagConstraints gridBagConstraints = new GridBagConstraints();
+        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
+        gridBagConstraints.weightx = 0.5;
+        gridBagConstraints.anchor = GridBagConstraints.WEST;
+
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = headerGridY;
         gridBagConstraints.fill = GridBagConstraints.HORIZONTAL;
         headerFieldsPanel.add(nameTF, gridBagConstraints);
-        
+
         gridBagConstraints.gridx = 1;
         gridBagConstraints.gridy = headerGridY;
         gridBagConstraints.fill = GridBagConstraints.HORIZONTAL;
         headerFieldsPanel.add(valueTF, gridBagConstraints);
-        
+
         gridBagConstraints.gridx = 2;
         gridBagConstraints.gridy = headerGridY++;
         gridBagConstraints.fill = GridBagConstraints.NONE;
         headerFieldsPanel.add(removeButton, gridBagConstraints);
-        
+
         validate();
         return removeButton;
     }
-    
-    private void removeHeaderActionPerformed(ActionEvent evt){
-    	final Object source = evt.getSource();
-    	if(source != null && source instanceof JButton){
-			if(headerFields.size() == 1){
-	    		headerFieldName.setVisible(false);
-	    		headerFieldValue.setVisible(false);
-	        }
-			JTextField nameTF = removeButtons.get(source);
-			JTextField valueTF = headerFields.get(nameTF);
-			headerFields.remove(nameTF);
-			
-			headerFieldsPanel.remove(nameTF);
-			headerFieldsPanel.remove(valueTF);
-			headerFieldsPanel.remove((JButton)source);
-			validate();
-		}
+    public SecuritySettingsPanel getSecuritySettingsPanel() {
+        return securitySettingsPanel;
     }
+
+    public void setSecuritySettingsPanel(SecuritySettingsPanel securitySettingsPanel) {
+        this.securitySettingsPanel = securitySettingsPanel;
+    }
+
+    private void removeHeaderActionPerformed(ActionEvent evt){
+        final Object source = evt.getSource();
+        if(source != null && source instanceof JButton){
+            if(headerFields.size() == 1){
+                headerFieldName.setVisible(false);
+                headerFieldValue.setVisible(false);
+            }
+            JTextField nameTF = removeButtons.get(source);
+            JTextField valueTF = headerFields.get(nameTF);
+            headerFields.remove(nameTF);
+
+            headerFieldsPanel.remove(nameTF);
+            headerFieldsPanel.remove(valueTF);
+            headerFieldsPanel.remove((JButton)source);
+            validate();
+        }
+    }
+    private void emptySubjectActionPerformed(ChangeEvent evt) {
+        final Object source = evt.getSource();
+        if(source != null && source instanceof JCheckBox){
+            if(cbSuppressSubject.isSelected()){
+                tfSubject.setEnabled(false);
+                cbIncludeTimestamp.setEnabled(false);
+            }else{
+                tfSubject.setEnabled(true);
+                cbIncludeTimestamp.setEnabled(true);
+            }
+        }
+    }
+
 }
\ No newline at end of file
