@@ -21,6 +21,7 @@ package org.apache.jmeter.protocol.smtp.sampler.protocol;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
@@ -38,6 +39,7 @@ import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
 
+import org.apache.commons.io.IOUtils;
 import org.apache.jmeter.config.Argument;
 import org.apache.jmeter.services.FileServer;
 import org.apache.jmeter.testelement.property.CollectionProperty;
@@ -68,6 +70,7 @@ public class SendMailCommand {
     private String smtpServer;
     private String smtpPort;
     private String sender;
+    private List<InternetAddress> replyTo;
     private String emlMessage;
     private List<InternetAddress> receiverTo;
     private List<InternetAddress> receiverCC;
@@ -90,9 +93,11 @@ public class SendMailCommand {
     private boolean synchronousMode;
 
     private Session session;
-    private Message message;
 
-    private StringBuffer serverResponse = new StringBuffer();
+    private StringBuffer serverResponse = new StringBuffer(); // TODO this is not populated currently
+
+    /** send plain body, i.e. not multipart/mixed */
+    private boolean plainBody;
 
     /**
      * Standard-Constructor
@@ -165,6 +170,8 @@ public class SendMailCommand {
         }
 
         session = Session.getInstance(props, null);
+        
+        Message message;
 
         if (sendEmlMessage) {
             message = new MimeMessage(session, new FileInputStream(emlMessage));
@@ -172,18 +179,33 @@ public class SendMailCommand {
             message = new MimeMessage(session);
             // handle body and attachments
             Multipart multipart = new MimeMultipart();
-            BodyPart body = new MimeBodyPart();
-            body.setText(mailBody);
-            multipart.addBodyPart(body);
-
-            for (File f : attachments) {
-                BodyPart attach = new MimeBodyPart();
-                attach.setFileName(f.getName());
-                attach.setDataHandler(new DataHandler(new FileDataSource(f)));
-                multipart.addBodyPart(attach);
+            final int attachmentCount = attachments.size();
+            if (plainBody && 
+               (attachmentCount == 0 ||  (mailBody.length() == 0 && attachmentCount == 1))) {
+                if (attachmentCount == 1) { // i.e. mailBody is empty
+                    File first = attachments.get(0);
+                    InputStream is = null;
+                    try {
+                        is = new FileInputStream(first);
+                        message.setText(IOUtils.toString(is));
+                    } finally {
+                        IOUtils.closeQuietly(is);
+                    }
+                } else {
+                    message.setText(mailBody);
+                }
+            } else {
+                BodyPart body = new MimeBodyPart();
+                body.setText(mailBody);
+                multipart.addBodyPart(body);
+                for (File f : attachments) {
+                    BodyPart attach = new MimeBodyPart();
+                    attach.setFileName(f.getName());
+                    attach.setDataHandler(new DataHandler(new FileDataSource(f.getAbsolutePath())));
+                    multipart.addBodyPart(attach);
+                }
+                message.setContent(multipart);
             }
-
-            message.setContent(multipart);
         }
 
         // set from field and subject
@@ -191,10 +213,13 @@ public class SendMailCommand {
             message.setFrom(new InternetAddress(sender));
         }
 
-        if (null != subject) {
-            message.setSubject(subject);
+        if (null != replyTo) {
+            InternetAddress[] to = new InternetAddress[replyTo.size()];
+            message.setReplyTo(replyTo.toArray(to));
         }
 
+        message.setSubject(subject);
+
         if (receiverTo != null) {
             InternetAddress[] to = new InternetAddress[receiverTo.size()];
             receiverTo.toArray(to);
@@ -214,7 +239,7 @@ public class SendMailCommand {
         }
 
         for (int i = 0; i < headerFields.size(); i++) {
-        	Argument argument = (Argument)((TestElementProperty)headerFields.get(i)).getObjectValue();
+            Argument argument = (Argument)((TestElementProperty)headerFields.get(i)).getObjectValue();
             message.setHeader(argument.getName(), argument.getValue());
         }
 
@@ -323,7 +348,7 @@ public class SendMailCommand {
      * Sets subject for current message - called by SmtpSampler-object
      *
      * @param subject
-     *            Subject for message of current message
+     *            Subject for message of current message - may be null
      */
     public void setSubject(String subject) {
         this.subject = subject;
@@ -724,6 +749,15 @@ public class SendMailCommand {
     public void setMailBody(String body){
         mailBody = body;
     }
+    
+    /**
+     * Set whether to send a plain body (i.e. not multipart/mixed)
+     *
+     * @param plainBody <code>true</code> if sending a plain body (i.e. not multipart/mixed)
+     */
+    public void setPlainBody(boolean plainBody){
+        this.plainBody = plainBody;
+    }
 
     public StringBuffer getServerResponse() {
         return this.serverResponse;
@@ -733,4 +767,8 @@ public class SendMailCommand {
         enableDebug = selected;
 
     }
+
+    public void setReplyTo(List<InternetAddress> replyTo) {
+        this.replyTo = replyTo;
+    }
 }
\ No newline at end of file
