@@ -57,12 +57,12 @@ public class TestCVSDataSet extends JMeterTestCase {
         csv.setVariableNames("a,b,c");
         csv.setDelimiter(",");
         csv.iterationStart(null);
-        assertNull(threadVars.get("a"));
-        assertEquals("value",threadVars.get("b"));
-        assertNull(threadVars.get("c"));
+        assertEquals("<EOF>",threadVars.get("a"));
+        assertEquals("<EOF>",threadVars.get("b"));
+        assertEquals("<EOF>",threadVars.get("c"));
 
         csv = new CSVDataSet();
-        csv.setFilename("testfiles/testempty.csv");
+        csv.setFilename(findTestPath("testfiles/testempty.csv"));
         csv.setVariableNames("a,b,c");
         csv.setDelimiter(",");
         
@@ -92,11 +92,45 @@ public class TestCVSDataSet extends JMeterTestCase {
         assertEquals("b1",threadVars.get("b"));
         assertEquals("c1",threadVars.get("c"));
     }
+    
+    public void testutf8() throws Exception {
+    	
+        CSVDataSet csv = new CSVDataSet();
+        csv.setFilename(findTestPath("testfiles/testutf8.csv"));
+        csv.setVariableNames("a,b,c,d");
+        csv.setDelimiter(",");
+        csv.setQuotedData( true );
+        csv.setFileEncoding( "UTF-8" );
+        
+        csv.iterationStart(null);
+        assertEquals("a1",threadVars.get("a"));
+        assertEquals("b1",threadVars.get("b"));
+        assertEquals("\u00e71",threadVars.get("c"));
+        assertEquals("d1",threadVars.get("d"));
+
+        csv.iterationStart(null);
+        assertEquals("a2",threadVars.get("a"));
+        assertEquals("b2",threadVars.get("b"));
+        assertEquals("\u00e72",threadVars.get("c"));
+        assertEquals("d2",threadVars.get("d"));
+
+        csv.iterationStart(null);
+        assertEquals("a3",threadVars.get("a"));
+        assertEquals("b3",threadVars.get("b"));
+        assertEquals("\u00e73",threadVars.get("c"));
+        assertEquals("d3",threadVars.get("d"));
+
+        csv.iterationStart(null);
+        assertEquals("a4",threadVars.get("a"));
+        assertEquals("b4",threadVars.get("b"));
+        assertEquals("\u00e74",threadVars.get("c"));
+        assertEquals("d4",threadVars.get("d"));
+    }
 
     // Test CSV file with a header line
     public void testHeaderOpen(){
         CSVDataSet csv = new CSVDataSet();
-        csv.setFilename("testfiles/testheader.csv");
+        csv.setFilename(findTestPath("testfiles/testheader.csv"));
         csv.setDelimiter("|");
         assertNull(csv.getVariableNames());
         csv.iterationStart(null);
@@ -112,10 +146,29 @@ public class TestCVSDataSet extends JMeterTestCase {
         assertEquals("c2",threadVars.get("C"));
         assertEquals("d2",threadVars.get("D|1"));
     }
-
+    
+    // Test CSV file with a header line and recycle is true
+    public void testHeaderOpenAndRecycle(){
+        CSVDataSet csv = new CSVDataSet();
+        csv.setFilename(findTestPath("testfiles/testheader.csv"));
+        csv.setDelimiter("|");
+        csv.setRecycle(true);
+        assertNull(csv.getVariableNames()); // read 1st line
+        // read 5 lines + restart to file begin
+        csv.iterationStart(null); // line 2
+        csv.iterationStart(null); // line 3
+        csv.iterationStart(null); // line 4
+        csv.iterationStart(null); // line 5
+        csv.iterationStart(null); // return to 2nd line (first line is names)
+        assertEquals("a1",threadVars.get("A"));
+        assertEquals("b1",threadVars.get("B"));
+        assertEquals("c1",threadVars.get("C"));
+        assertEquals("d1",threadVars.get("D|1"));
+    }
+    
     private CSVDataSet initCSV(){
         CSVDataSet csv = new CSVDataSet();
-        csv.setFilename("testfiles/test.csv");
+        csv.setFilename(findTestPath("testfiles/test.csv"));
         csv.setVariableNames("a,b,c");
         csv.setDelimiter(",");
         return csv;
