@@ -64,7 +64,7 @@ public class PackageTest extends JMeterTestCase {
     // Create the CSVRead function and set its parameters.
     private static CSVRead setCSVReadParams(String p1, String p2) throws Exception {
         CSVRead cr = new CSVRead();
-        Collection parms = new LinkedList();
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         if (p1 != null) {
             parms.add(new CompoundVariable(p1));
         }
@@ -78,7 +78,7 @@ public class PackageTest extends JMeterTestCase {
     // Create the StringFromFile function and set its parameters.
     private static StringFromFile SFFParams(String p1, String p2, String p3, String p4) throws Exception {
         StringFromFile sff = new StringFromFile();
-        Collection parms = new LinkedList();
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         if (p1 != null) {
             parms.add(new CompoundVariable(p1));
         }
@@ -98,7 +98,7 @@ public class PackageTest extends JMeterTestCase {
     // Create the SplitFile function and set its parameters.
     private static SplitFunction SplitParams(String p1, String p2, String p3) throws Exception {
         SplitFunction split = new SplitFunction();
-        Collection parms = new LinkedList();
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         parms.add(new CompoundVariable(p1));
         if (p2 != null) {
             parms.add(new CompoundVariable(p2));
@@ -117,8 +117,8 @@ public class PackageTest extends JMeterTestCase {
         return bsh;
     }
 
-    private static Collection MakeParams(String p1, String p2, String p3) {
-        Collection parms = new LinkedList();
+    private static Collection<CompoundVariable> MakeParams(String p1, String p2, String p3) {
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         if (p1 != null) {
             parms.add(new CompoundVariable(p1));
         }
@@ -220,6 +220,7 @@ public class PackageTest extends JMeterTestCase {
 
     private JMeterVariables vars = null;
 
+    @Override
     public void setUp() {
         jmctx = JMeterContextService.getContext();
         jmctx.setVariables(new JMeterVariables());
@@ -822,7 +823,7 @@ public class PackageTest extends JMeterTestCase {
     }
 
     private XPath setupXPath(String file, String expr) throws Exception{
-        Collection parms = new LinkedList();
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         parms.add(new CompoundVariable(file));
         parms.add(new CompoundVariable(expr));
         XPath xp = new XPath();
@@ -834,7 +835,7 @@ public class PackageTest extends JMeterTestCase {
     
     public void randomTest1() throws Exception {
         Random r = new Random();
-        Collection parms = MakeParams("0","10000000000","VAR");
+        Collection<CompoundVariable> parms = MakeParams("0","10000000000","VAR");
         r.setParameters(parms);
         //String s = 
             r.execute(null,null);
@@ -847,7 +848,7 @@ public class PackageTest extends JMeterTestCase {
         vars.put("one","1");
         vars.put("two","2");
         vars.put("V","A");
-        Collection parms;
+        Collection<CompoundVariable> parms;
         String s;
         
         parms = MakeParams("V",null,null);
@@ -891,7 +892,7 @@ public class PackageTest extends JMeterTestCase {
         vars.put("query","select ${column} from ${table}");
         vars.put("column","name");
         vars.put("table","customers");
-        Collection parms;
+        Collection<CompoundVariable> parms;
         String s;
         
         parms = MakeParams("${query}",null,null);
@@ -906,7 +907,7 @@ public class PackageTest extends JMeterTestCase {
         vars.put("query","select ${column} from ${table}");
         vars.put("column","name");
         vars.put("table","customers");
-        Collection parms;
+        Collection<CompoundVariable> parms;
         String s;
         
         parms = MakeParams("query",null,null);
@@ -946,7 +947,7 @@ public class PackageTest extends JMeterTestCase {
     
     // Perform a sum and check the results
     private void checkSum(AbstractFunction func, String value, String [] addends)  throws Exception {
-        Collection parms = new LinkedList();
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         for (int i=0; i< addends.length; i++){
             parms.add(new CompoundVariable(addends[i]));
         }
@@ -957,7 +958,7 @@ public class PackageTest extends JMeterTestCase {
     }
     // Perform a sum and check the results
     private void checkSumNoVar(AbstractFunction func, String value, String [] addends)  throws Exception {
-        Collection parms = new LinkedList();
+        Collection<CompoundVariable> parms = new LinkedList<CompoundVariable>();
         for (int i=0; i< addends.length; i++){
             parms.add(new CompoundVariable(addends[i]));
         }
