@@ -31,6 +31,7 @@ import org.apache.jmeter.protocol.http.control.Header;
 import org.apache.jmeter.protocol.http.control.HeaderManager;
 import org.apache.jmeter.protocol.http.sampler.HTTPSamplerBase;
 import org.apache.jmeter.protocol.http.util.HTTPArgument;
+import org.apache.jmeter.protocol.http.util.HTTPFileArg;
 
 public class TestHttpRequestHdr  extends JMeterTestCase {
     public TestHttpRequestHdr(String name) {
@@ -495,9 +496,10 @@ public class TestHttpRequestHdr  extends JMeterTestCase {
         // Check arguments
         Arguments arguments = s.getArguments();
         assertEquals(0, arguments.getArgumentCount());
-        assertEquals(fileFieldValue, s.getFileField());
-        assertEquals(fileName, s.getFilename());
-        assertEquals(mimeType, s.getMimetype());
+        HTTPFileArg hfa = s.getHTTPFiles()[0]; // Assume there's at least one file
+        assertEquals(fileFieldValue, hfa.getParamName());
+        assertEquals(fileName, hfa.getPath());
+        assertEquals(mimeType, hfa.getMimeType());
     }        
 
     private String createMultipartFormBody(String titleValue, String descriptionValue, String contentEncoding, boolean includeExtraHeaders, String boundary, String endOfLine) {
@@ -562,8 +564,8 @@ public class TestHttpRequestHdr  extends JMeterTestCase {
         }
         req.parse(bis);
         bis.close();
-        Map pageEncodings = Collections.synchronizedMap(new HashMap());
-        Map formEncodings = Collections.synchronizedMap(new HashMap());
+        Map<String, String> pageEncodings = Collections.synchronizedMap(new HashMap<String, String>());
+        Map<String, String> formEncodings = Collections.synchronizedMap(new HashMap<String, String>());
         if(url != null && contentEncoding != null) {
             pageEncodings.put(url, contentEncoding);
         }
@@ -597,7 +599,7 @@ public class TestHttpRequestHdr  extends JMeterTestCase {
         }
         else {
             // Most browsers use ISO-8859-1 as default encoding, even if spec says UTF-8
-            return postBody.getBytes().length;
+            return postBody.getBytes().length; // TODO - charset?
         }
     }
 }
