@@ -57,6 +57,7 @@ import junit.extensions.TestSetup;
 public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
     private final static int HTTP_SAMPLER = 0;
     private final static int HTTP_SAMPLER2 = 1;
+    private final static int HTTP_SAMPLER3 = 2;
     
     /** The encodings used for http headers and control information */
     private final static String ISO_8859_1 = "ISO-8859-1"; // $NON-NLS-1$
@@ -79,7 +80,7 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
             protected void setUp() throws Exception {
                     httpServer = TestHTTPMirrorThread.startHttpMirror(MIRROR_PORT);
                     // Create the test file content
-                    TEST_FILE_CONTENT = new String("some foo content &?=01234+56789-\u007c\u2aa1\u266a\u0153\u20a1\u0115\u0364\u00c5\u2052\uc385%C3%85").getBytes("UTF-8");
+                    TEST_FILE_CONTENT = "some foo content &?=01234+56789-\u007c\u2aa1\u266a\u0153\u20a1\u0115\u0364\u00c5\u2052\uc385%C3%85".getBytes("UTF-8");
 
                     // create a temporary file to make sure we always have a file to give to the PostWriter 
                     // Whereever we are or Whatever the current path is.
@@ -110,6 +111,10 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
         testPostRequest_UrlEncoded(HTTP_SAMPLER2, US_ASCII);
     }
 
+    public void testPostRequest_UrlEncoded3() throws Exception {
+        testPostRequest_UrlEncoded(HTTP_SAMPLER3, US_ASCII);
+    }
+
     public void testPostRequest_FormMultipart() throws Exception {
         testPostRequest_FormMultipart(HTTP_SAMPLER, ISO_8859_1);
     }
@@ -118,6 +123,10 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
         testPostRequest_FormMultipart(HTTP_SAMPLER2, US_ASCII);
     }
 
+    public void testPostRequest_FormMultipart3() throws Exception {
+        testPostRequest_FormMultipart(HTTP_SAMPLER3, US_ASCII);
+    }
+
     public void testPostRequest_FileUpload() throws Exception {
         testPostRequest_FileUpload(HTTP_SAMPLER, ISO_8859_1);
     }
@@ -126,6 +135,10 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
         testPostRequest_FileUpload(HTTP_SAMPLER2, US_ASCII);
     }
 
+    public void testPostRequest_FileUpload3() throws Exception {        
+        testPostRequest_FileUpload(HTTP_SAMPLER3, US_ASCII);
+    }
+
     public void testPostRequest_BodyFromParameterValues() throws Exception {
         testPostRequest_BodyFromParameterValues(HTTP_SAMPLER, ISO_8859_1);
     }
@@ -134,6 +147,10 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
         testPostRequest_BodyFromParameterValues(HTTP_SAMPLER2, US_ASCII);
     }
 
+    public void testPostRequest_BodyFromParameterValues3() throws Exception {
+        testPostRequest_BodyFromParameterValues(HTTP_SAMPLER3, US_ASCII);
+    }
+
     public void testGetRequest() throws Exception {
         testGetRequest(HTTP_SAMPLER);
     }
@@ -142,6 +159,10 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
         testGetRequest(HTTP_SAMPLER2);
     }
     
+    public void testGetRequest3() throws Exception {
+        testGetRequest(HTTP_SAMPLER3);
+    }
+    
     public void testGetRequest_Parameters() throws Exception {
         testGetRequest_Parameters(HTTP_SAMPLER);
     }
@@ -150,6 +171,10 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
         testGetRequest_Parameters(HTTP_SAMPLER2);
     }   
 
+    public void testGetRequest_Parameters3() throws Exception {
+        testGetRequest_Parameters(HTTP_SAMPLER3);
+    }   
+
     private void testPostRequest_UrlEncoded(int samplerType, String samplerDefaultEncoding) throws Exception {
         String titleField = "title";
         String titleValue = "mytitle";
@@ -1004,13 +1029,19 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
     private boolean isInRequestHeaders(String requestHeaders, String headerName, String headerValue) {
         return checkRegularExpression(requestHeaders, headerName + ": " + headerValue);
     }
-    
+  
+    // Java 1.6.0_22+ no longer allows Content-Length to be set, so don't check it.
+    // See: http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6996110
+    // TODO any point in checking the other headers?
     private void checkHeaderTypeLength(String requestHeaders, String contentType, int contentLen) {
         boolean typeOK = isInRequestHeaders(requestHeaders, HTTPSamplerBase.HEADER_CONTENT_TYPE, contentType);
-        boolean lengOK = isInRequestHeaders(requestHeaders, HTTPSamplerBase.HEADER_CONTENT_LENGTH, Integer.toString(contentLen));
-        if (!typeOK || !lengOK){
-            fail("Expected type:" + contentType + " & length: " +contentLen + " in:\n"+ requestHeaders);
+//        boolean lengOK = isInRequestHeaders(requestHeaders, HTTPSamplerBase.HEADER_CONTENT_LENGTH, Integer.toString(contentLen));
+        if (!typeOK){
+            fail("Expected type:" + contentType + " in:\n"+ requestHeaders);
         }
+//        if (!lengOK){
+//            fail("Expected & length: " +contentLen + " in:\n"+requestHeaders);
+//        }
     }
    
     private String getSentRequestHeaderValue(String requestHeaders, String headerName) {
@@ -1131,9 +1162,9 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
                 for(int i = 0; i < expected.length; i++) {
                     if(expected[i] != actual[i]) {
                         System.out.println(">>>>>>>>>>>>>>>>>>>>");
-                        System.out.println(new String(expected,0,i+1));
+                        System.out.println(new String(expected,0,i+1,"UTF-8"));
                         System.out.println("====================");
-                        System.out.println(new String(actual,0,i+1));
+                        System.out.println(new String(actual,0,i+1,"UTF-8"));
                         System.out.println("<<<<<<<<<<<<<<<<<<<<");
 /*                        
                         // Useful to when debugging
@@ -1173,7 +1204,7 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
             boolean firstMultipart,
             boolean lastMultipart) throws IOException {
         // The encoding used for http headers and control information
-        final byte[] DASH_DASH = new String("--").getBytes(ISO_8859_1);
+        final byte[] DASH_DASH = "--".getBytes(ISO_8859_1);
 
         final ByteArrayOutputStream output = new ByteArrayOutputStream();
         if(firstMultipart) {
@@ -1250,7 +1281,7 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
             byte[] fileContent,
             boolean firstMultipart,
             boolean lastMultipart) throws IOException {
-        final byte[] DASH_DASH = new String("--").getBytes(ISO_8859_1);
+        final byte[] DASH_DASH = "--".getBytes(ISO_8859_1);
         
         final ByteArrayOutputStream output = new ByteArrayOutputStream();
         if(firstMultipart) {
@@ -1316,11 +1347,14 @@ public class TestHTTPSamplersAgainstHttpMirrorServer extends JMeterTestCase {
     }
     
     private HTTPSamplerBase createHttpSampler(int samplerType) {
-        if(samplerType == HTTP_SAMPLER2) {
-            return new HTTPSampler2();
-        }
-        else {
-            return new HTTPSampler();
+        switch(samplerType) {
+            case HTTP_SAMPLER:
+                return new HTTPSampler();
+            case HTTP_SAMPLER2:
+                return new HTTPSampler2();
+            case HTTP_SAMPLER3:
+                return new HTTPSampler3();
         }
+        throw new IllegalArgumentException("Unexpected type: "+samplerType);
     }
 }
