@@ -35,8 +35,8 @@ public class TestSampleResult extends TestCase {
             super(name);
         }
 
-        public void testElapsed() throws Exception {
-            SampleResult res = new SampleResult();
+        public void testElapsedTrue() throws Exception {
+            SampleResult res = new SampleResult(true);
 
             // Check sample increments OK
             res.sampleStart();
@@ -48,8 +48,21 @@ public class TestSampleResult extends TestCase {
             }
         }
 
-        public void testPause() throws Exception {
-            SampleResult res = new SampleResult();
+        public void testElapsedFalse() throws Exception {
+            SampleResult res = new SampleResult(false);
+
+            // Check sample increments OK
+            res.sampleStart();
+            Thread.sleep(110); // Needs to be greater than the minimum to allow for boundary errors
+            res.sampleEnd();
+            long time = res.getTime();
+            if(time < 100){
+                fail("Sample time should be >=100, actual "+time);
+            }
+        }
+
+        public void testPauseFalse() throws Exception {
+            SampleResult res = new SampleResult(false);
             // Check sample increments OK
             res.sampleStart();
             Thread.sleep(100);
@@ -62,8 +75,27 @@ public class TestSampleResult extends TestCase {
             Thread.sleep(100);
             res.sampleEnd();
             long sampleTime = res.getTime();
-            if ((sampleTime < 198) || (sampleTime > 290)) {
-                fail("Accumulated time (" + sampleTime + ") was not between 198 and 290 ms");
+            if ((sampleTime < 180) || (sampleTime > 290)) {
+                fail("Accumulated time (" + sampleTime + ") was not between 180 and 290 ms");
+            }
+        }
+
+        public void testPauseTrue() throws Exception {
+            SampleResult res = new SampleResult(true);
+            // Check sample increments OK
+            res.sampleStart();
+            Thread.sleep(100);
+            res.samplePause();
+
+            Thread.sleep(200);
+
+            // Re-increment
+            res.sampleResume();
+            Thread.sleep(100);
+            res.sampleEnd();
+            long sampleTime = res.getTime();
+            if ((sampleTime < 180) || (sampleTime > 290)) {
+                fail("Accumulated time (" + sampleTime + ") was not between 180 and 290 ms");
             }
         }
 
@@ -77,9 +109,19 @@ public class TestSampleResult extends TestCase {
             SampleResult.log.setLogTargets(lt);
         }
 
-        public void testPause2() throws Exception {
+        public void testPause2True() throws Exception {
             divertLog();
-            SampleResult res = new SampleResult();
+            SampleResult res = new SampleResult(true);
+            res.sampleStart();
+            res.samplePause();
+            assertEquals(0, wr.toString().length());
+            res.samplePause();
+            assertFalse(wr.toString().length() == 0);
+        }
+
+        public void testPause2False() throws Exception {
+            divertLog();
+            SampleResult res = new SampleResult(false);
             res.sampleStart();
             res.samplePause();
             assertEquals(0, wr.toString().length());
@@ -98,89 +140,132 @@ public class TestSampleResult extends TestCase {
             assertEquals("sample of size 100 bytes", res.getSampleLabel());
         }
 
-        private static long sampleClock() {
-            return SampleResult.currentTimeInMs();
+        public void testSubResultsTrue() throws Exception {
+            testSubResults(true, 0);
         }
 
-        public void testSubResults() throws Exception {
+        public void testSubResultsFalse() throws Exception {
+            testSubResults(false, 0);
+        }
+
+        public void testSubResultsTruePause() throws Exception {
+            testSubResults(true, 100);
+        }
+
+        public void testSubResultsFalsePause() throws Exception {
+            testSubResults(false, 100);
+        }
+
+        // temp test case for exploring settings
+        public void xtestUntilFail() throws Exception {
+            while(true) {
+                testSubResultsTruePause();
+                testSubResultsFalsePause();
+            }
+        }
+
+        private void testSubResults(boolean nanoTime, long pause) throws Exception {
             // This test tries to emulate a http sample, with two
             // subsamples, representing images that are downloaded for the
             // page representing the first sample.
-            
+
             // Sample that will get two sub results, simulates a web page load 
-            SampleResult resWithSubResults = new SampleResult();            
+            SampleResult parent = new SampleResult(nanoTime);            
 
-            long beginTest = sampleClock();
+            long beginTest = parent.currentTimeInMillis();
 
-            resWithSubResults.sampleStart();
+            parent.sampleStart();
             Thread.sleep(100);
-            resWithSubResults.setBytes(300);
-            resWithSubResults.setSampleLabel("sample with two subresults");
-            resWithSubResults.setSuccessful(true);
-            resWithSubResults.sampleEnd();
-            long sampleWithSubResultsTime = resWithSubResults.getTime();
-            
+            parent.setBytes(300);
+            parent.setSampleLabel("Parent Sample");
+            parent.setSuccessful(true);
+            parent.sampleEnd();
+            long parentElapsed = parent.getTime();
+
             // Sample with no sub results, simulates an image download
-            SampleResult resNoSubResults1 = new SampleResult();            
-            resNoSubResults1.sampleStart();
+            SampleResult child1 = new SampleResult(nanoTime);            
+            child1.sampleStart();
             Thread.sleep(100);
-            resNoSubResults1.setBytes(100);
-            resNoSubResults1.setSampleLabel("sample with no subresults");
-            resNoSubResults1.setSuccessful(true);
-            resNoSubResults1.sampleEnd();
-            long sample1Time = resNoSubResults1.getTime();
+            child1.setBytes(100);
+            child1.setSampleLabel("Child1 Sample");
+            child1.setSuccessful(true);
+            child1.sampleEnd();
+            long child1Elapsed = child1.getTime();
+
+            assertTrue(child1.isSuccessful());
+            assertEquals(100, child1.getBytes());
+            assertEquals("Child1 Sample", child1.getSampleLabel());
+            assertEquals(1, child1.getSampleCount());
+            assertEquals(0, child1.getSubResults().length);
+
+            long actualPause = 0;
+            if (pause > 0) {
+                long t1 = parent.currentTimeInMillis();
+                Thread.sleep(pause);
+                actualPause = parent.currentTimeInMillis() - t1;
+            }
 
-            assertTrue(resNoSubResults1.isSuccessful());
-            assertEquals(100, resNoSubResults1.getBytes());
-            assertEquals("sample with no subresults", resNoSubResults1.getSampleLabel());
-            assertEquals(1, resNoSubResults1.getSampleCount());
-            assertEquals(0, resNoSubResults1.getSubResults().length);
-            
             // Sample with no sub results, simulates an image download 
-            SampleResult resNoSubResults2 = new SampleResult();            
-            resNoSubResults2.sampleStart();
+            SampleResult child2 = new SampleResult(nanoTime);            
+            child2.sampleStart();
             Thread.sleep(100);
-            resNoSubResults2.setBytes(200);
-            resNoSubResults2.setSampleLabel("sample with no subresults");
-            resNoSubResults2.setSuccessful(true);
-            resNoSubResults2.sampleEnd();
-            long sample2Time = resNoSubResults2.getTime();
+            child2.setBytes(200);
+            child2.setSampleLabel("Child2 Sample");
+            child2.setSuccessful(true);
+            child2.sampleEnd();
+            long child2Elapsed = child2.getTime();
 
-            long overallTime = sampleClock() - beginTest;
-
-            assertTrue(resNoSubResults2.isSuccessful());
-            assertEquals(200, resNoSubResults2.getBytes());
-            assertEquals("sample with no subresults", resNoSubResults2.getSampleLabel());
-            assertEquals(1, resNoSubResults2.getSampleCount());
-            assertEquals(0, resNoSubResults2.getSubResults().length);
+            assertTrue(child2.isSuccessful());
+            assertEquals(200, child2.getBytes());
+            assertEquals("Child2 Sample", child2.getSampleLabel());
+            assertEquals(1, child2.getSampleCount());
+            assertEquals(0, child2.getSubResults().length);
             
             // Now add the subsamples to the sample
-            resWithSubResults.addSubResult(resNoSubResults1);
-            resWithSubResults.addSubResult(resNoSubResults2);
-            assertTrue(resWithSubResults.isSuccessful());
-            assertEquals(600, resWithSubResults.getBytes());
-            assertEquals("sample with two subresults", resWithSubResults.getSampleLabel());
-            assertEquals(1, resWithSubResults.getSampleCount());
-            assertEquals(2, resWithSubResults.getSubResults().length);
-            long totalTime = resWithSubResults.getTime();
+            parent.addSubResult(child1);
+            parent.addSubResult(child2);
+            assertTrue(parent.isSuccessful());
+            assertEquals(600, parent.getBytes());
+            assertEquals("Parent Sample", parent.getSampleLabel());
+            assertEquals(1, parent.getSampleCount());
+            assertEquals(2, parent.getSubResults().length);
+            long parentElapsedTotal = parent.getTime();
             
-            // Check the sample times
-            long allsamplesTime = sampleWithSubResultsTime + sample1Time + sample2Time;
-            if (totalTime < allsamplesTime) {
-                fail("Total: "+totalTime+" < sum(samples): "+ allsamplesTime);
+            long overallTime = parent.currentTimeInMillis() - beginTest;
+
+            long sumSamplesTimes = parentElapsed + child1Elapsed + actualPause + child2Elapsed;
+            
+            /*
+             * Parent elapsed total should be no smaller than the sum of the individual samples.
+             * It may be greater by the timer granularity.
+             */
+            
+            long diff = parentElapsedTotal - sumSamplesTimes;
+            long maxDiff = nanoTime ? 2 : 16; // TimeMillis has granularity of 10-20
+            if (diff < 0 || diff > maxDiff) {
+                fail("ParentElapsed: " + parentElapsedTotal + " - " + " sum(samples): " + sumSamplesTimes
+                        + " = " + diff + " not in [0," + maxDiff + "]; nanotime=" + nanoTime);
             }
-            if (totalTime > overallTime) {
-                fail("Total: "+totalTime+" > overall time: "+ overallTime);
+
+            /**
+             * The overall time to run the test must be no less than, 
+             * and may be greater (but not much greater) than the parent elapsed time
+             */
+            
+            diff = overallTime - parentElapsedTotal;
+            if (diff < 0 || diff > maxDiff) {
+                fail("TestElapsed: " + overallTime + " - " + " ParentElapsed: " + parentElapsedTotal
+                        + " = " + diff + " not in [0," + maxDiff + "]; nanotime="+nanoTime);
             }
             
             // Check that calculator gets the correct statistics from the sample
             Calculator calculator = new Calculator();
-            calculator.addSample(resWithSubResults);
+            calculator.addSample(parent);
             assertEquals(600, calculator.getTotalBytes());
             assertEquals(1, calculator.getCount());
-            assertEquals(1d / (totalTime / 1000d), calculator.getRate(),0.0001d); // Allow for some margin of error
+            assertEquals(1d / (parentElapsedTotal / 1000d), calculator.getRate(),0.0001d); // Allow for some margin of error
             // Check that the throughput uses the time elapsed for the sub results
-            assertFalse(1d / (sampleWithSubResultsTime / 1000d) <= calculator.getRate());
+            assertFalse(1d / (parentElapsed / 1000d) <= calculator.getRate());
         }
 
         // TODO some more invalid sequence tests needed
