@@ -22,6 +22,7 @@
      
 package org.apache.jmeter.services;
 
+import java.io.File;
 import java.io.IOException;
 
 import org.apache.jmeter.junit.JMeterTestCase;
@@ -38,10 +39,14 @@ public class TestFileServer extends JMeterTestCase {
         super(arg0);
     }
 
+    @Override
+    public void setUp() throws IOException {
+        FS.resetBase();        
+    }
+
     @Override
     public void tearDown() throws IOException{
         FS.closeFiles();
-        FS.resetBase();
     }
     
     public void testopen() throws Exception {
@@ -58,7 +63,7 @@ public class TestFileServer extends JMeterTestCase {
         assertFalse("Should not have any files open",FS.filesOpen());
         FS.closeFile("xxx"); // Unrecognised files are ignored
         assertFalse("Should not have any files open",FS.filesOpen());
-        String infile="testfiles/test.csv";
+        String infile=findTestPath("testfiles/test.csv");
         FS.reserveFile(infile); // Does not open file
         assertFalse("Should not have any files open",FS.filesOpen());
         assertEquals("a1,b1,c1,d1",FS.readLine(infile));
@@ -84,8 +89,7 @@ public class TestFileServer extends JMeterTestCase {
             fail("Expected IOException");
         } catch (IOException ignored){
         }
-        String base=FS.getBaseDir();
-        infile=base+"/testfiles/test.csv";
+        infile=findTestPath("testfiles/test.csv");
         FS.reserveFile(infile); // Does not open file
         assertFalse("Should not have any files open",FS.filesOpen());
         assertEquals("a1,b1,c1,d1",FS.readLine(infile));
@@ -97,6 +101,19 @@ public class TestFileServer extends JMeterTestCase {
         FS.closeFile(infile);
         FS.setBasedir("y");
         FS.closeFiles();
-        FS.setBasedir(System.getProperty("user.dir"));
+    }
+    
+    public void testRelative() throws Exception {
+        final String base = FileServer.getDefaultBase();
+        final File basefile = new File(base);
+        FS.setBaseForScript(basefile);
+        assertEquals(".",FS.getBaseDirRelative().toString());
+        FS.setBaseForScript(basefile.getParentFile());
+        assertEquals(".",FS.getBaseDirRelative().toString());
+        FS.setBaseForScript(new File(basefile.getParentFile(),"abcd/defg.jmx"));
+        assertEquals(".",FS.getBaseDirRelative().toString());
+        File file = new File(basefile,"abcd/defg.jmx");
+        FS.setBaseForScript(file);
+        assertEquals("abcd",FS.getBaseDirRelative().toString());
     }
 }
