@@ -23,6 +23,7 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.lang.reflect.Method;
+import java.nio.charset.Charset;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
@@ -30,6 +31,7 @@ import java.util.Properties;
 
 import junit.framework.Test;
 import junit.framework.TestCase;
+import junit.framework.TestResult;
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
@@ -129,7 +131,7 @@ public final class AllTests {
     public static void main(String[] args) {
         if (args.length < 1) {
             System.out.println("You must specify a comma-delimited list of paths to search " + "for unit tests");
-            System.exit(1);
+            return;
         }
         String home=new File(System.getProperty("user.dir")).getParent();
         System.out.println("Setting JMeterHome: "+home);
@@ -137,11 +139,18 @@ public final class AllTests {
         initializeLogging(args);
         initializeManager(args);
 
-        log.info("JMeterVersion="+JMeterUtils.getJMeterVersion());
+        String version = "JMeterVersion="+JMeterUtils.getJMeterVersion();
+        log.info(version);
+        System.out.println(version);
         logprop("java.version", true);
         logprop("java.vm.name");
         logprop("java.vendor");
         logprop("java.home", true);
+        logprop("file.encoding", true);
+        // Display actual encoding used (will differ if file.encoding is not recognised)
+        String msg = "default encoding="+Charset.defaultCharset();
+        System.out.println(msg);
+        log.info(msg);
         logprop("user.home");
         logprop("user.dir", true);
         logprop("user.language");
@@ -221,7 +230,7 @@ public final class AllTests {
         // the code to not attempt to write to a file, so it will continue
         // behaving as it did before. It would be simple to make it write
         // to a file instead if that is the desired behavior.
-        TestRunner.run(suite);
+        TestResult result = TestRunner.run(suite);
         // ++
         // Recheck settings:
         //System.out.println("+++++++++++");
@@ -241,7 +250,7 @@ public final class AllTests {
         // }
         //System.out.println("------------");
         // --
-        System.exit(0); // this is needed because the test may start the AWT EventQueue thread which is not a daemon.
+        System.exit(result.wasSuccessful() ? 0 : 1); // this is needed because the test may start the AWT EventQueue thread which is not a daemon.
     }
 
     /**
